@@ -33,9 +33,9 @@ OC.L10N.register(
     "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizou o evento {event} no calendario {calendar}",
     "You updated event {event} in calendar {calendar}" : "Vde. actualizou o evento {event} no calendario {calendar}",
     "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendario {sourceCalendar} ao calendario {targetCalendar}",
-    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Moveu o evento {evento} do calendario {sourceCalendar} ao calendario {targetCalendar}",
-    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {evento} do calendario {calendar}",
-    "You restored event {event} of calendar {calendar}" : "Restaurou o evento {evento} do calendario {calendar}",
+    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Moveu o evento {event} do calendario {sourceCalendar} ao calendario {targetCalendar}",
+    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} do calendario {calendar}",
+    "You restored event {event} of calendar {calendar}" : "Restaurou o evento {event} do calendario {calendar}",
     "Busy" : "Ocupado",
     "{actor} created to-do {todo} in list {calendar}" : "{actor} creou a tarefa pendente {todo} na lista {calendar}",
     "You created to-do {todo} in list {calendar}" : "Creou a tarefa pendente {todo} na lista {calendar}",
@@ -72,6 +72,53 @@ OC.L10N.register(
     "Description: %s" : "Descrición: %s",
     "Where: %s" : "Onde: %s",
     "%1$s via %2$s" : "%1$s mediante %2$s",
+    "In a %1$s on %2$s for the entire day" : "Nun/ha %1$s o %2$s durante todo o día",
+    "In a %1$s on %2$s between %3$s - %4$s" : "Nun/ha %1$s o %2$s entre %3$s e %4$s",
+    "In %1$s %2$s on %3$s for the entire day" : "En %1$s %2$s o %3$s durante todo o día",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "En %1$s %2$s o %3$s entre %4$s e %5$s",
+    "Could not generate when statement" : "Non foi posíbel xerar a declaración when (cando)",
+    "Every Day for the entire day" : "Todos os días durante todo o día",
+    "Every Day for the entire day until %1$s" : "Todos os días durante todo o día ata o %1$s",
+    "Every Day between %1$s - %2$s" : "Todos os días entre %1$s e %2$s",
+    "Every Day between %1$s - %2$s until %3$s" : " Todos os días entre %1$s e %2$s ata o %3$s",
+    "Every %1$d Days for the entire day" : "Cada %1$d días durante todo o día",
+    "Every %1$d Days for the entire day until %2$s" : "Cada %1$d días durante todo o día ata o %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Cada %1$d días entre %2$s e %3$s",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "Cada %1$d días entre %2$s e %3$s ata o %4$s",
+    "Could not generate event recurrence statement" : "Non foi posíbel xerar a declaración de recorrencia do evento",
+    "Every Week on %1$s for the entire day" : "Todas as semanas o %1$s durante todo o día",
+    "Every Week on %1$s for the entire day until %2$s" : "Todas as semanas o %1$s durante todo o día ata o %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "Todas as semanas o %1$s entre %2$s e %3$s",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Todas as semanas o %1$s entre %2$s e %3$s ata o %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "Cada %1$d semanas o %2$s durante todo o día",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Cada %1$d semanas o %2$s durante todo o día ata o %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Cada %1$d semanas o %2$s entre %3$s e %4$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Cada %1$d semanas o %2$s entre %3$s e %4$s ata o %5$s",
+    "Every Month on the %1$s for the entire day" : "Todos os meses o %1$s durante todo o día",
+    "Every Month on the %1$s for the entire day until %2$s" : "Todos os meses o %1$s durante todo o día ata o %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "Todos os meses o %1$s entre %2$s e %3$s",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Todos os meses o %1$s entre %2$s e %3$s ata o %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "Cada %1$d meses o %2$s durante todo o día",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Cada %1$d meses o %2$s durante todo o día ata o %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Cada %1$d meses o %2$s entre %3$s e %4$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Cada %1$d meses o %2$s entre %3$s e %4$s ata o %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "Todos os anos en %1$s, o %2$s durante todo o día",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Todos os anos en %1$s, o %2$s durante todo o día ata o %3$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Todos os anos en %1$s, o %2$s entre %3$s e %4$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Todos os anos en %1$s, o %2$s entre %3$s e %4$s ata o %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Cada %1$d anos en %2$s, o %3$s durante todo o día",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Cada %1$d anos en %2$s, o %3$s durante todo o día ata o %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Cada %1$d anos en %2$s, o %3$s entre %4$s e %5$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Cada %1$d anos en %2$s, o %3$s entre %4$s e %5$s ata o %6$s",
+    "On specific dates for the entire day until %1$s" : "En datas concretas durante todo o día ata o %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "En datas concretas entre %1$s e %2$s ata o %3$s",
+    "In a %1$s on %2$s" : "Nun/ha %1$s o %2$s",
+    "In a %1$s on %2$s then on %3$s" : "Nun/ha %1$s o %2$s após o %3$s",
+    "In a %1$s on %2$s then on %3$s and %4$s" : "Nun/ha %1$s o %2$s após o %3$s e o %4$s",
+    "In %1$s %2$s on %3$s" : "En %1$s %2$s o %3$s",
+    "In %1$s %2$s on %3$s then on %4$s" : "En %1$s %2$s o %3$s, após o %4$s",
+    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "En %1$s %2$s o %3$s, após o %4$s e o %5$s",
+    "Could not generate next recurrence statement" : "Non foi posíbel xerar a seguinte declaración de recorrencia",
     "Cancelled: %1$s" : "Cancelado: %1$s",
     "\"%1$s\" has been canceled" : "Cancelouse «%1$s»",
     "Re: %1$s" : "Re: %1$s",
@@ -86,13 +133,43 @@ OC.L10N.register(
     "Organizer:" : "Organizador:",
     "Attendees:" : "Asistentes:",
     "Title:" : "Título:",
-    "Time:" : "Hora:",
+    "When:" : "Cando:",
     "Location:" : "Lugar:",
     "Link:" : "Ligazón:",
+    "Occurring:" : "Acaecendo:",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "More options …" : "Máis opcións…",
     "More options at %s" : "Máis opcións en %s",
+    "Monday" : "luns",
+    "Tuesday" : "martes",
+    "Wednesday" : "mércores",
+    "Thursday" : "xoves",
+    "Friday" : "venres",
+    "Saturday" : "sábado",
+    "Sunday" : "domingo",
+    "January" : "xaneiro",
+    "February" : "febreiro",
+    "March" : "marzo",
+    "April" : "abril",
+    "May" : "maio",
+    "June" : "xuño",
+    "July" : "xullo",
+    "August" : "agosto",
+    "September" : "setembro",
+    "October" : "outubro",
+    "November" : "novembro",
+    "December" : "decembro",
+    "First" : "Primeiro",
+    "Second" : "Segundo",
+    "Third" : "Terceiro",
+    "Fourth" : "Cuarto",
+    "Fifty" : "Quinto",
+    "Last" : "Último",
+    "Second Last" : "Penúltimo",
+    "Third Last" : "Antepenúltimo",
+    "Fourth Last" : "Trasantepenúltimo",
+    "Fifty Last" : "Quinto dende o final",
     "Contacts" : "Contactos",
     "{actor} created address book {addressbook}" : "{actor} creou o caderno de enderezos {addressbook}",
     "You created address book {addressbook}" : "Vde. creou o caderno de enderezos {addressbook}",
@@ -133,10 +210,9 @@ OC.L10N.register(
     "Encryption not ready: %1$s" : "O cifrado non está preparado: %1$s",
     "Failed to open file: %1$s" : "Produciuse un erro ao abrir o ficheiro: %1$s",
     "Failed to unlink: %1$s" : "Produciuse un erro ao desligar: %1$s",
-    "Invalid chunk name" : "O nome do fragmento non é válido",
-    "Could not rename part file assembled from chunks" : "Non foi posíbel cambiar o nome do ficheiro de pezas ensamblados a partir de fragmentos",
     "Failed to write file contents: %1$s" : "Produciuse un erro ao escribir o contido do ficheiro: %1$s",
     "File not found: %1$s" : "Non se atopou o ficheiro: %1$s",
+    "Invalid target path" : "A ruta de destino non é correcta",
     "System is in maintenance mode." : "O sistema está en modo de mantemento.",
     "Upgrade needed" : "É necesario anovar",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
@@ -150,8 +226,8 @@ OC.L10N.register(
     "DAV system address book" : "Caderno de enderezos do sistema DAV",
     "No outstanding DAV system address book sync." : "Non hai sincronización pendente do caderno de enderezos do sistema DAV.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "A sincronización do caderno de enderezos do sistema DAV aínda non foi executada aínda porque a súa instancia ten máis de 1000 usuarios ou porque se produciu un erro. Execútea manualmente con occ dav:sync-system-addressbook.",
-    "WebDAV endpoint" : "Terminación WebDAV",
-    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Non se puido comprobar que o seu servidor web estea configurado correctamente para permitir a sincronización de ficheiros a través de WebDAV. Por favor, verifíqueo manualmente.",
+    "WebDAV endpoint" : "Punto final WebDAV",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Non foi posíbel comprobar que o seu servidor web estea configurado correctamente para permitir a sincronización de ficheiros a través de WebDAV. Compróbeo manualmente.",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O servidor non foi configurado correctamente para permitir a sincronización de ficheiros, semella que a interface WebDAV non está a funcionar.",
     "Your web server is properly set up to allow file synchronization over WebDAV." : "O seu servidor web está configurado correctamente para permitir a sincronización de ficheiros a través de WebDAV.",
     "Migrated calendar (%1$s)" : "Calendario migrado (%1$s)",
@@ -160,6 +236,10 @@ OC.L10N.register(
     "WebDAV" : "WebDAV",
     "First day" : "Primeiro día",
     "Last day (inclusive)" : "Último día (inclusive)",
+    "Out of office replacement (optional)" : "Substitución fóra da oficina (opcional)",
+    "Name of the replacement" : "Nome do substituto",
+    "No results." : "Sen resultados",
+    "Start typing." : "Comece a escribir.",
     "Short absence status" : "Estado de ausencia breve",
     "Long absence Message" : "Mensaxe de ausencia longa",
     "Save" : "Gardar",
@@ -174,21 +254,14 @@ OC.L10N.register(
     "No working hours set" : "Sen horario de traballo estabelecido",
     "Add slot" : "Engadir franxa horaria",
     "Weekdays" : "Días laborábeis",
-    "Monday" : "luns",
-    "Tuesday" : "martes",
-    "Wednesday" : "mércores",
-    "Thursday" : "xoves",
-    "Friday" : "venres",
-    "Saturday" : "sábado",
-    "Sunday" : "domingo",
     "Pick a start time for {dayName}" : "Escolla unha hora de inicio para {dayName}",
     "Pick a end time for {dayName}" : "Escolla unha hora de finalización para {dayName}",
-    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Estabelecer automaticamente o estado do usuario en «Non molestar» fóra de dispoñibilidade para silenciar todas as notificacións.",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Definir automaticamente o estado do usuario en «Non molestar» fóra de dispoñibilidade para enmudecer todas as notificacións.",
     "Failed to load availability" : "Produciuse un erro ao cargar a dispoñibilidade",
     "Saved availability" : "Dispoñibilidade gardada",
     "Failed to save availability" : "Produciuse un erro ao gardar a dispoñibilidade",
     "Availability" : "Dispoñibilidade",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se configuras o teu horario de traballo, outras persoas verán cando estás fóra da oficina cando reserven unha reunión.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se configura o seu horario de traballo, outras persoas verán cando está fóra da oficina cando reserven unha xuntanza.",
     "Absence" : "Ausencia",
     "Configure your next absence period." : "Configurar o próximo período de ausencia.",
     "Calendar server" : "Servidor do calendario",
@@ -209,6 +282,9 @@ OC.L10N.register(
     "Tentative" : "Provisional",
     "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
     "To-dos" : "Tarefas pendentes",
+    "Time:" : "Hora:",
+    "Invalid chunk name" : "O nome do fragmento non é válido",
+    "Could not rename part file assembled from chunks" : "Non foi posíbel cambiar o nome do ficheiro de pezas ensamblados a partir de fragmentos",
     "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se configura o seu horario de traballo, outros usuarios verán cando está fóra da oficina cando reserven unha xuntanza."
 },
 "nplurals=2; plural=(n != 1);");
