@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalender",
-    "To-dos" : "Uppgifter",
+    "Tasks" : "Uppgifter",
     "Personal" : "Privat",
     "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
     "You created calendar {calendar}" : "Du skapade kalender {calendar}",
@@ -50,9 +50,9 @@ OC.L10N.register(
     "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
     "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
     "Calendar, contacts and tasks" : "Kalender, kontakter och uppgifter",
-    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
-    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
-    "A calendar <strong>to-do</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
+    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ändrades",
+    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> ändrades",
+    "A calendar <strong>to-do</strong> was modified" : "En kalender <strong>uppgift</strong> ändrades",
     "Contact birthdays" : "Födelsedagar",
     "Death of %s" : "%ss död ",
     "Untitled calendar" : "Namnlös kalender",
@@ -82,17 +82,38 @@ OC.L10N.register(
     "Invitation updated: %1$s" : "Inbjudan uppdaterad: %1$s",
     "%1$s updated the event \"%2$s\"" : "%1$s uppdaterade händelse \"%2$s\"",
     "Invitation: %1$s" : "Inbjudan: %1$s",
-    "%1$s would like to invite you to \"%2$s\"" : "%1$s skulle vilja bjuda in dig till \"%2$s\"",
+    "%1$s would like to invite you to \"%2$s\"" : "%1$s har bjudit in dig till \"%2$s\"",
     "Organizer:" : "Arrangör:",
     "Attendees:" : "Deltagare:",
     "Title:" : "Titel:",
-    "Time:" : "Tid:",
+    "When:" : "När",
     "Location:" : "Ort:",
     "Link:" : "Länk:",
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
     "More options …" : "Fler alternativ ...",
     "More options at %s" : "Fler alternativ på %s",
+    "Monday" : "Måndag",
+    "Tuesday" : "Tisdag",
+    "Wednesday" : "Onsdag",
+    "Thursday" : "Torsdag",
+    "Friday" : "Fredag",
+    "Saturday" : "Lördag",
+    "Sunday" : "Söndag",
+    "January" : "Januari",
+    "February" : "Februari",
+    "March" : "Mars",
+    "April" : "April",
+    "May" : "Maj",
+    "June" : "Juni",
+    "July" : "Juli",
+    "August" : "Augusti",
+    "September" : "September",
+    "October" : "Oktober",
+    "November" : "November",
+    "December" : "December",
+    "First" : "Första",
+    "Last" : "Sista",
     "Contacts" : "Kontakter",
     "{actor} created address book {addressbook}" : "{actor} skapade adressboken {addressbook}",
     "You created address book {addressbook}" : "Du skapade adressboken {addressbook}",
@@ -114,7 +135,7 @@ OC.L10N.register(
     "{actor} created contact {card} in address book {addressbook}" : "{actor} skapade kontakten {card} i adressboken {addressbook}",
     "You created contact {card} in address book {addressbook}" : "Du skapade kontakten {card} i adressboken {addressbook}",
     "{actor} deleted contact {card} from address book {addressbook}" : "{actor} tog bort kontakten {card} från adressboken {addressbook}",
-    "You deleted contact {card} from address book {addressbook}" : "Du tog bort kontakten {©ard} från adressboken {addressbook}",
+    "You deleted contact {card} from address book {addressbook}" : "Du tog bort kontakten {card} från adressboken {addressbook}",
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} uppdaterade kontakten {card} i adressboken {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Du uppdaterade kontakten {card} i adressboken {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressbok</strong> ändrades",
@@ -133,8 +154,6 @@ OC.L10N.register(
     "Encryption not ready: %1$s" : "Kryptering ej redo: %1$s",
     "Failed to open file: %1$s" : "Kunde inte öppna fil: %1$s",
     "Failed to unlink: %1$s" : "Kunde inte ta bort: %1$s",
-    "Invalid chunk name" : "Ogiltigt delnamn",
-    "Could not rename part file assembled from chunks" : "Kunde inte ändra namn på temporära filen ihopsatt från delar",
     "Failed to write file contents: %1$s" : "Kunde inte skriva filinnehåll: %1$s",
     "File not found: %1$s" : "Filen hittades inte: %1$s",
     "System is in maintenance mode." : "Systemet är i underhållsläge.",
@@ -143,7 +162,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
     "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
     "Events" : "Händelser",
-    "Tasks" : "Uppgifter",
     "Untitled task" : "Namnlös uppgift",
     "Completed on %s" : "Slutförd %s",
     "Due on %s by %s" : "Slutar den %s vid %s",
@@ -151,15 +169,21 @@ OC.L10N.register(
     "DAV system address book" : "DAV-systemets adressbok",
     "No outstanding DAV system address book sync." : "Ingen utestående synkronisering för DAV-systemets adressbok.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressbokssynkronisering har inte körts ännu eftersom din instans har fler än 1000 användare eller för att ett fel uppstod. Kör det manuellt genom att anropa \"occ dav:sync-system-addressbook\".",
+    "WebDAV endpoint" : "WebDAV endpoint",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Det gick inte att kontrollera att din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV. Kontrollera manuellt.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webbserver är ännu inte korrekt inställd för att tillåta filsynkronisering, eftersom WebDAV-gränssnittet verkar vara trasigt.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV.",
     "Migrated calendar (%1$s)" : "Migrerade kalender (%1$s)",
     "Calendars including events, details and attendees" : "Kalendrar inklusive händelser, detaljer och deltagare",
     "Contacts and groups" : "Kontakter och grupper",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "WebDAV endpoint",
     "First day" : "Första dagen",
     "Last day (inclusive)" : "Sista dagen (inklusive)",
-    "Short absence status" : "Kort frånvarostatus",
-    "Long absence Message" : "Långt frånvaromeddelande",
+    "Name of the replacement" : "Namn på ersättaren",
+    "No results." : "Inga resultat.",
+    "Start typing." : "Börja skriva.",
+    "Short absence status" : "Meddelande om kort frånvaro",
+    "Long absence Message" : "Meddelande om långvarig frånvaro",
     "Save" : "Spara",
     "Disable absence" : "Inaktivera frånvaro",
     "Absence saved" : "Frånvaro sparad",
@@ -171,21 +195,15 @@ OC.L10N.register(
     "Delete slot" : "Radera lucka",
     "No working hours set" : "Inga arbetstimmar satta",
     "Add slot" : "Lägg till lucka",
-    "Monday" : "Måndag",
-    "Tuesday" : "Tisdag",
-    "Wednesday" : "Onsdag",
-    "Thursday" : "Torsdag",
-    "Friday" : "Fredag",
-    "Saturday" : "Lördag",
-    "Sunday" : "Söndag",
+    "Weekdays" : "Vardagar",
     "Pick a start time for {dayName}" : "Välj en starttid för {dayName}",
     "Pick a end time for {dayName}" : "Välj en sluttid för {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sätt automatiskt användarstatus till \"Stör ej\" utanför tillgängliga tider för att tysta alla notifikationer.",
     "Failed to load availability" : "Misslyckades med att ladda tidsluckor",
     "Saved availability" : "Sparade tidslucka",
     "Failed to save availability" : "Misslyckades med att spara tidslucka",
-    "Availability" : "Tillgänglighet",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstimmar kan andra användare se när du inte är på jobbet när de bokar ett möte.",
+    "Availability" : "Din tillgänglighet",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstider kommer andra att se när du är frånvarande när de bokar ett möte.",
     "Absence" : "Frånvaro",
     "Configure your next absence period." : "Konfigurera din nästa frånvaroperiod.",
     "Calendar server" : "Kalenderserver",
@@ -193,17 +211,22 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
     "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
-    "Send notifications for events" : "Skicka aviseringar för händelser",
-    "Notifications are sent via background jobs, so these must occur often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
+    "Send notifications for events" : "Skicka notiser för händelser",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Notiser skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
     "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
     "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
-    "Enable notifications for events via push" : "Aktivera aviseringar för händelser via push",
+    "Enable notifications for events via push" : "Aktivera notiser för händelser via push",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}Kalender-app{linkclose}, eller {calendardocopen}anslut din dator & mobil för synkronisering ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Verifiera och säkerställ inställningar för {emailopen}e-postserver{linkclose}.",
     "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
     "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
     "Are you accepting the invitation?" : "Acceptera inbjudan?",
     "Tentative" : "Preliminärt",
-    "Your attendance was updated successfully." : "Dina närvaro uppdaterades."
+    "Your attendance was updated successfully." : "Dina närvaro uppdaterades.",
+    "To-dos" : "Uppgifter",
+    "Time:" : "Tid:",
+    "Invalid chunk name" : "Ogiltigt delnamn",
+    "Could not rename part file assembled from chunks" : "Kunde inte ändra namn på temporära filen ihopsatt från delar",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstimmar kan andra användare se när du inte är på jobbet när de bokar ett möte."
 },
 "nplurals=2; plural=(n != 1);");
