@@ -72,6 +72,53 @@ OC.L10N.register(
     "Description: %s" : "描述：%s",
     "Where: %s" : "地點：%s",
     "%1$s via %2$s" : "%1$s 由 %2$s",
+    "In a %1$s on %2$s for the entire day" : "%1$s 的 %2$s 整天",
+    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s 的 %2$s 於 %3$s - %4$s 之間",
+    "In %1$s %2$s on %3$s for the entire day" : "%1$s %2$s 的 %3$s 整天",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s 的 %3$s 於 %4$s - %5$s 之間",
+    "Could not generate when statement" : "無法產生 when 陳述",
+    "Every Day for the entire day" : "每天一整天",
+    "Every Day for the entire day until %1$s" : "每天一整天，直至 %1$s",
+    "Every Day between %1$s - %2$s" : "每天於 %1$s - %2$s 之間",
+    "Every Day between %1$s - %2$s until %3$s" : "每天於 %1$s - %2$s 之間，直至 %3$s",
+    "Every %1$d Days for the entire day" : "每 %1$d 天整天",
+    "Every %1$d Days for the entire day until %2$s" : "每 %1$d 天整天，直至 %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "每 %1$d 天於 %2$s - %3$s 之間",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "每 %1$d 天於 %2$s - %3$s 之間，直至 %4$s",
+    "Could not generate event recurrence statement" : "無法產生事件重複陳述",
+    "Every Week on %1$s for the entire day" : "每週於 %1$s 整天",
+    "Every Week on %1$s for the entire day until %2$s" : "每週於 %1$s 整天，直到 %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "每週於 %1$s，在  %2$s - %3$s 之間",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "每週於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "每 %1$d 週於 %2$s 整天",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "每 %1$d 週於 %2$s 整天，直至 %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
+    "Every Month on the %1$s for the entire day" : "每個月於 %1$s 整天",
+    "Every Month on the %1$s for the entire day until %2$s" : "每個月於 %1$s 整天，直至 %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "每個月於 %1$s，在  %2$s - %3$s 之間",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "每個月於 %1$s，在  %2$s - %3$s 之間，直至 %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "每 %1$d 個月於 %2$s 整天",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "每 %1$d 個月於 %2$s 整天，直至 %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "每年於 %1$s 的 %2$s 整天",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "每年於 %1$s 的 %2$s 整天，直至 %3$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "每 %1$d 年於 %2$s 的 %3$s 整天",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "每 %1$d 年於 %2$s 的 %3$s 整天，直至 %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間，直至 %6$s",
+    "On specific dates for the entire day until %1$s" : "在特定日期的整天，直至 %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直至 %3$s",
+    "In a %1$s on %2$s" : "在 %1$s 的 %2$s",
+    "In a %1$s on %2$s then on %3$s" : "在 %1$s 的 %2$s，然後 %3$s",
+    "In a %1$s on %2$s then on %3$s and %4$s" : "在 %1$s 的 %2$s，然後 %3$s 與 %4$s",
+    "In %1$s %2$s on %3$s" : "在 %1$s %2$s 的 %3$s",
+    "In %1$s %2$s on %3$s then on %4$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s",
+    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s 與 %5$s",
+    "Could not generate next recurrence statement" : "無法產生下一個重複語句",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" 已被取消",
     "Re: %1$s" : "關於: %1$s",
@@ -86,13 +133,43 @@ OC.L10N.register(
     "Organizer:" : "主辦單位：",
     "Attendees:" : "參加者：",
     "Title:" : "標題：",
-    "Time:" : "時間：",
+    "When:" : "時間：",
     "Location:" : "位置：",
     "Link:" : "連結：",
+    "Occurring:" : "發生：",
     "Accept" : "接受",
     "Decline" : "拒絕",
     "More options …" : "更多選項 ...",
     "More options at %s" : "%s有更多選項",
+    "Monday" : "星期一",
+    "Tuesday" : "星期二",
+    "Wednesday" : "星期三",
+    "Thursday" : "星期四",
+    "Friday" : "星期五",
+    "Saturday" : "星期六",
+    "Sunday" : "星期日",
+    "January" : "一月",
+    "February" : "二月",
+    "March" : "三月",
+    "April" : "四月",
+    "May" : "五月",
+    "June" : "六月",
+    "July" : "七月",
+    "August" : "八月",
+    "September" : "九月",
+    "October" : "十月",
+    "November" : "十一月",
+    "December" : "十二月",
+    "First" : "首頁",
+    "Second" : "第二",
+    "Third" : "第三",
+    "Fourth" : "第四",
+    "Fifty" : "五十",
+    "Last" : "最後",
+    "Second Last" : "尾二",
+    "Third Last" : "尾三",
+    "Fourth Last" : "尾四",
+    "Fifty Last" : "尾五",
     "Contacts" : "聯絡人",
     "{actor} created address book {addressbook}" : "{actor} 創建了通訊錄 {addressbook} ",
     "You created address book {addressbook}" : "您創建了通訊錄 {addressbook} ",
@@ -133,10 +210,9 @@ OC.L10N.register(
     "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
     "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
     "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
-    "Invalid chunk name" : "無效的區塊名稱",
-    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
     "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
     "File not found: %1$s" : "找不到檔案：%1$s",
+    "Invalid target path" : "無效的目標路徑",
     "System is in maintenance mode." : "系統處於維護模式。",
     "Upgrade needed" : "需要升級",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV",
@@ -160,6 +236,10 @@ OC.L10N.register(
     "WebDAV" : "WebDAV",
     "First day" : "第一天",
     "Last day (inclusive)" : "最後一天（含）",
+    "Out of office replacement (optional)" : "外出時的替代人員（非強制的）",
+    "Name of the replacement" : "替代人員姓名",
+    "No results." : "沒有結果。",
+    "Start typing." : "開始輸入。",
     "Short absence status" : "短暫缺席狀態",
     "Long absence Message" : "長期缺席訊息",
     "Save" : "保存",
@@ -174,13 +254,6 @@ OC.L10N.register(
     "No working hours set" : "尚未設置工作時間",
     "Add slot" : "新增欄位",
     "Weekdays" : "平日",
-    "Monday" : "星期一",
-    "Tuesday" : "星期二",
-    "Wednesday" : "星期三",
-    "Thursday" : "星期四",
-    "Friday" : "星期五",
-    "Saturday" : "星期六",
-    "Sunday" : "星期日",
     "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
     "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將用戶狀態設定為「請勿打擾」以靜音所有通知。",
@@ -209,6 +282,9 @@ OC.L10N.register(
     "Tentative" : "暫定",
     "Your attendance was updated successfully." : "您的參與狀況成功更新",
     "To-dos" : "待辦事項",
+    "Time:" : "時間：",
+    "Invalid chunk name" : "無效的區塊名稱",
+    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
     "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他用戶在預約會議時就會知道您何時不在辦公室。"
 },
 "nplurals=1; plural=0;");
