@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "日曆",
-    "To-dos" : "待辦事項",
+    "Tasks" : "工作項目",
     "Personal" : "個人",
     "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
     "You created calendar {calendar}" : "您建立了日曆 {calendar}",
@@ -72,6 +72,53 @@ OC.L10N.register(
     "Description: %s" : "描述：%s",
     "Where: %s" : "地點：%s",
     "%1$s via %2$s" : "%1$s 由 %2$s",
+    "In a %1$s on %2$s for the entire day" : "%1$s 的 %2$s 整天",
+    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s 的 %2$s 於 %3$s - %4$s 之間",
+    "In %1$s %2$s on %3$s for the entire day" : "%1$s %2$s 的 %3$s 整天",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s 的 %3$s 於 %4$s - %5$s 之間",
+    "Could not generate when statement" : "無法產生 when 陳述",
+    "Every Day for the entire day" : "每天一整天",
+    "Every Day for the entire day until %1$s" : "每天一整天，直到 %1$s",
+    "Every Day between %1$s - %2$s" : "每天於 %1$s - %2$s 之間",
+    "Every Day between %1$s - %2$s until %3$s" : "每天於 %1$s - %2$s 之間，直到 %3$s",
+    "Every %1$d Days for the entire day" : "每 %1$d 天整天",
+    "Every %1$d Days for the entire day until %2$s" : "每 %1$d 天整天，直到 %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "每 %1$d 天於 %2$s - %3$s 之間",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "每 %1$d 天於 %2$s - %3$s 之間，直到 %4$s",
+    "Could not generate event recurrence statement" : "無法產生事件重複陳述",
+    "Every Week on %1$s for the entire day" : "每週於 %1$s 整天",
+    "Every Week on %1$s for the entire day until %2$s" : "每週於 %1$s 整天，直到 %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "每週於 %1$s，在  %2$s - %3$s 之間",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "每週於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "每 %1$d 週於 %2$s 整天",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "每 %1$d 週於 %2$s 整天，直到 %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
+    "Every Month on the %1$s for the entire day" : "每個月於 %1$s 整天",
+    "Every Month on the %1$s for the entire day until %2$s" : "每個月於 %1$s 整天，直到 %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "每個月於 %1$s，在  %2$s - %3$s 之間",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "每個月於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "每 %1$d 個月於 %2$s 整天",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "每 %1$d 個月於 %2$s 整天，直到 %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "每年於 %1$s 的 %2$s 整天",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "每年於 %1$s 的 %2$s 整天，直到 %3$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "每 %1$d 年於 %2$s 的 %3$s 整天",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "每 %1$d 年於 %2$s 的 %3$s 整天，直到 %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間，直到 %6$s",
+    "On specific dates for the entire day until %1$s" : "在特定日期的整天，直到 %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直到 %3$s",
+    "In a %1$s on %2$s" : "在 %1$s 的 %2$s",
+    "In a %1$s on %2$s then on %3$s" : "在 %1$s 的 %2$s，然後 %3$s",
+    "In a %1$s on %2$s then on %3$s and %4$s" : "在 %1$s 的 %2$s，然後 %3$s 與 %4$s",
+    "In %1$s %2$s on %3$s" : "在 %1$s %2$s 的 %3$s",
+    "In %1$s %2$s on %3$s then on %4$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s",
+    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s 與 %5$s",
+    "Could not generate next recurrence statement" : "無法產生下一個重複陳述",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "「%1$s」已取消",
     "Re: %1$s" : "回覆：%1$s",
@@ -86,13 +133,43 @@ OC.L10N.register(
     "Organizer:" : "組織者：",
     "Attendees:" : "參與者：",
     "Title:" : "標題：",
-    "Time:" : "時間：",
+    "When:" : "時間：",
     "Location:" : "地點：",
     "Link:" : "連結：",
+    "Occurring:" : "發生：",
     "Accept" : "接受",
     "Decline" : "拒絕",
     "More options …" : "更多選項……",
     "More options at %s" : "%s 有更多選項",
+    "Monday" : "週一",
+    "Tuesday" : "週二",
+    "Wednesday" : "週三",
+    "Thursday" : "週四",
+    "Friday" : "週五",
+    "Saturday" : "週六",
+    "Sunday" : "週日",
+    "January" : "一月",
+    "February" : "二月",
+    "March" : "三月",
+    "April" : "四月",
+    "May" : "五月",
+    "June" : "六月",
+    "July" : "七月",
+    "August" : "八月",
+    "September" : "九月",
+    "October" : "十月",
+    "November" : "十一月",
+    "December" : "十二月",
+    "First" : "第一個",
+    "Second" : "第二",
+    "Third" : "第三",
+    "Fourth" : "第四",
+    "Fifty" : "五十",
+    "Last" : "最後",
+    "Second Last" : "倒數第二",
+    "Third Last" : "倒數第三",
+    "Fourth Last" : "倒數第四",
+    "Fifty Last" : "倒數五十",
     "Contacts" : "聯絡人",
     "{actor} created address book {addressbook}" : "{actor} 建立了通訊錄 {addressbook}",
     "You created address book {addressbook}" : "您建立了通訊錄 {addressbook}",
@@ -133,45 +210,60 @@ OC.L10N.register(
     "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
     "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
     "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
-    "Invalid chunk name" : "無效的區塊名稱",
-    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
     "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
     "File not found: %1$s" : "找不到檔案：%1$s",
+    "Invalid target path" : "無效目標路徑",
     "System is in maintenance mode." : "系統處於維護模式。",
     "Upgrade needed" : "需要升級",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV。",
     "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
     "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
     "Events" : "活動",
-    "Tasks" : "工作項目",
     "Untitled task" : "未命名工作項目",
     "Completed on %s" : "完成於 %s",
     "Due on %s by %s" : "到期於 %s 由 %s",
     "Due on %s" : "到期於 %s",
+    "DAV system address book" : "DAV 系統通訊錄",
+    "No outstanding DAV system address book sync." : "沒有未完成的 DAV 系統通訊錄同步。",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系統通訊錄同步尚未執行，因為您的站台有超過 1000 個使用者，或是因為遇到錯誤。請透過呼叫「occ dav:sync-system-addressbook」手動執行。",
+    "WebDAV endpoint" : "WebDAV 端點",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "無法檢查您的網路伺服器是否已正確設定以允許透過 WebDAV 進行檔案同步。請手動檢查。",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 介面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "您的網路伺服器已正確設定為允許透過 WebDAV 進行檔案同步。",
     "Migrated calendar (%1$s)" : "已導入的行事曆 (%1$s)",
     "Calendars including events, details and attendees" : "行事曆，包含事件、詳細資訊及參與者",
     "Contacts and groups" : "聯絡人與群組",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "WebDAV 端點",
-    "Availability" : "可用性",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
+    "First day" : "第一天",
+    "Last day (inclusive)" : "最後一天（含）",
+    "Out of office replacement (optional)" : "不在辦公室取代（選擇性）",
+    "Name of the replacement" : "取代名稱",
+    "No results." : "沒有結果。",
+    "Start typing." : "開始輸入。",
+    "Short absence status" : "短暫缺席狀態",
+    "Long absence Message" : "長期缺席訊息",
+    "Save" : "儲存",
+    "Disable absence" : "停用缺席",
+    "Absence saved" : "缺席時段已儲存",
+    "Failed to save your absence settings" : "儲存您的缺席設定失敗",
+    "Absence cleared" : "缺席時段已清除",
+    "Failed to clear your absence settings" : "清除您的缺席設定失敗",
     "Time zone:" : "時區：",
     "to" : "到",
     "Delete slot" : "刪除欄位",
     "No working hours set" : "未設定工作時間",
     "Add slot" : "新增欄位",
-    "Monday" : "週一",
-    "Tuesday" : "週二",
-    "Wednesday" : "週三",
-    "Thursday" : "週四",
-    "Friday" : "週五",
-    "Saturday" : "週六",
-    "Sunday" : "週日",
+    "Weekdays" : "週間",
+    "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
+    "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將使用者狀態設定為「請勿打擾」以靜音所有通知。",
-    "Save" : "儲存",
     "Failed to load availability" : "載入可用性失敗",
     "Saved availability" : "已儲存可用性",
     "Failed to save availability" : "儲存可用性失敗",
+    "Availability" : "可用性",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
+    "Absence" : "缺席",
+    "Configure your next absence period." : "設定您的下一個缺席時段。",
     "Calendar server" : "日曆伺服器",
     "Send invitations to attendees" : "發送邀請函給參加者",
     "Automatically generate a birthday calendar" : "自動生成生日日曆",
@@ -189,6 +281,10 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "您接受邀請嗎？",
     "Tentative" : "暫定",
     "Your attendance was updated successfully." : "您的參與狀態成功更新。",
-    "%1$s has responded your invitation" : "%1$s 已回應您的邀請"
+    "To-dos" : "待辦事項",
+    "Time:" : "時間：",
+    "Invalid chunk name" : "無效的區塊名稱",
+    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。"
 },
 "nplurals=1; plural=0;");
