@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "S'ha produït un error desconegut",
     "File could not be uploaded" : "No s'ha pogut pujar el fitxer",
     "Uploading …" : "S'està pujant…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "S'està pujant… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "No s'admet la pujada aquest element",
     "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Mou",
     "Copy" : "Copia",
     "Choose target folder" : "Trieu la carpeta de destinació",
+    "Set reminder" : "Defineix un recordatori",
     "Edit locally" : "Edita localment",
     "Open" : "Obre",
     "Delete file" : "Suprimeix el fitxer",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
     "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
+    "New" : "Crea",
     "New file/folder menu" : "Menú de fitxer o carpeta nova",
     "Select file range" : "Selecciona un interval de fitxers",
     "{used}%" : "{used}%",
@@ -97,18 +101,16 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "L'emmagatzematge està gairebé ple ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincideix amb «{filter}»","coincideixen amb «{filter}»"],
     "View in folder" : "Visualitza-ho en la carpeta",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per als usuaris que tenen accés a aquest fitxer o carpeta)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per a les persones que tenen accés a aquest fitxer o carpeta)",
     "Path" : "Camí",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "En els preferits",
     "Favorite" : "En els preferits",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per als usuaris que tinguin accés a aquest fitxer o carpeta)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per a les persones que tinguin accés a aquest fitxer o carpeta)",
     "New folder" : "Carpeta nova",
     "Create new folder" : "Crea una carpeta",
     "Upload file" : "Puja un fitxer",
     "Recent" : "Recents",
-    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}",
     "Not favorited" : "No s'inclou en els preferits",
     "Remove from favorites" : "Suprimeix dels preferits",
     "Add to favorites" : "Afegeix als preferits",
@@ -125,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} l'ha restaurat",
     "Renamed by {user}" : "{user} n'ha canviat el nom",
     "Moved by {user}" : "{user} l'ha desplaçat",
-    "\"remote user\"" : "«usuari remot»",
+    "\"remote account\"" : "«compte remot»",
     "You created {file}" : "Heu creat {file}",
     "You created an encrypted file in {file}" : "Heu creat el fitxer xifrat {file}",
     "{user} created {file}" : "{user} ha creat {file}",
@@ -154,12 +156,13 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "S'ha afegit o suprimit un fitxer dels <strong>preferits</strong>",
     "A file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta",
     "A favorite file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta dels preferits",
-    "All files" : "Tots els fitxers",
     "Upload (max. %s)" : "Puja (màx. %s)",
     "Accept" : "Accepta",
     "Reject" : "Rebutja",
     "Incoming ownership transfer from {user}" : "{user} us ha enviat una transferència de propietat",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voleu acceptar {path}?\n\nNota: el procés de transferència després de l'acceptació pot durar fins a 1 hora.",
+    "Ownership transfer denied" : "S'ha denegat la transferència de la propietat",
+    "Your ownership transfer of {path} was denied by {user}." : "{user} ha denegat la transferència de la propietat de {path}.",
     "Ownership transfer failed" : "S'ha produït un error en transferir la propietat",
     "Your ownership transfer of {path} to {user} failed." : "S'ha produït un error en transferir la propietat de {path} a {user}.",
     "The ownership transfer of {path} from {user} failed." : "S'ha produït un error en transferir la propietat de {path} de {user}.",
@@ -167,38 +170,44 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "S'ha completat la transferència de propietat de {path} a {user}.",
     "The ownership transfer of {path} from {user} has completed." : "S'ha completat la transferència de propietat de {path} de {user}.",
     "in %s" : "%s",
+    "Transferred from %1$s on %2$s" : "S'ha transferit de %1$s a %2$s",
     "File Management" : "Gestió de fitxers",
+    "Current directory path" : "Camí de la carpeta actual",
     "Reload current directory" : "Torna a carregar la carpeta actual",
     "Go to the \"{dir}\" directory" : "Ves a la carpeta «{dir}»",
-    "Select the row for {displayName}" : "Selecciona la fila per a {displayName}",
-    "Rename file" : "Canvia el nom del fitxer",
-    "File name" : "Nom del fitxer",
-    "A long time ago" : "Fa molt de temps",
-    "Download file {name}" : "Baixa el fitxer {name}",
+    "Drag and drop files here to upload" : "Arrossegueu i deixeu anar fitxers aquí per a pujar-los",
+    "Your have used your space quota and cannot upload files anymore" : "Heu utilitzat la quota d'espai i ja no podeu pujar fitxers",
+    "You don’t have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "\"{displayName}\" action executed successfully" : "L'acció «{displayName}» s'ha executat correctament",
     "\"{displayName}\" action failed" : "S'ha produït un error en l'acció «{displayName}»",
-    "\"{name}\" is not an allowed filetype." : "«{name}» no és un tipus de fitxer permès.",
-    "{newName} already exists." : "{newName} ja existeix.",
-    "Name cannot be empty" : "El nom no pot estar buit",
-    "Another entry with the same name already exists" : "Ja existeix una altra entrada amb aquest nom",
+    "Toggle selection for file \"{displayName}\"" : "Canvia la selecció per al fitxer «{displayName}»",
+    "Toggle selection for folder \"{displayName}\"" : "Canvia la selecció per a la carpeta «{displayName}»",
+    "Rename file" : "Canvia el nom del fitxer",
+    "Filename" : "Nom del fitxer",
+    "Folder name" : "Nom de la carpeta",
+    "This node is unavailable" : "Aquest node no està disponible",
     "Renamed \"{oldName}\" to \"{newName}\"" : "S'ha canviat el nom de «{oldName}» a «{newName}»",
     "Could not rename \"{oldName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{oldName}», ja no existeix",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{newName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{newName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
     "Could not rename \"{oldName}\"" : "No s'ha pogut canviar el nom de «{oldName}»",
+    "Clear filter" : "Esborra el filtre",
+    "Type" : "Tipus",
+    "Active filters" : "Filtres actius",
     "Total rows summary" : "Resum de totes les files",
-    "Select all" : "Selecciona-ho tot",
-    "Unselect all" : "Anul·la tota la selecció",
+    "Toggle selection for all files and folders" : "Canvia la selecció per a tots els fitxers i carpetes",
     "\"{displayName}\" failed on some elements " : "S'ha produït un error en l'acció «{displayName}» per a alguns elements",
     "\"{displayName}\" batch action executed successfully" : "L'acció per lots «{displayName}» s'ha executat correctament",
-    "ascending" : "ascendent",
-    "descending" : "descendent",
-    "Sort list by {column} ({direction})" : "Ordena la llista per {column} ({direction})",
+    "{count} selected" : "Selecció: {count}",
     "List of files and folders." : "Llista de fitxers i carpetes.",
+    "Column headers with buttons are sortable." : "Les capçaleres de columna amb botons es poder ordenar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Aquesta llista no es mostra completament per raons de rendiment. Es mostraran els fitxers a mesura que navegueu per la llista.",
-    "Storage informations" : "Informació d'emmagatzematge",
+    "File not found" : "No s'ha trobat el fitxer",
     "{usedQuotaByte} used" : "{usedQuotaByte} en ús",
     "{relative}% used" : "{relative}% en ús",
     "Could not refresh storage stats" : "No s'han pogut actualitzar les estadístiques d'emmagatzematge",
+    "Your storage is full, files can not be updated or synced anymore!" : "L'emmagatzematge està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
+    "Create" : "Crea",
+    "Submit" : "Envia",
     "Transfer ownership of a file or folder" : "Transferència de la propietat d'un fitxer o carpeta",
     "Choose file or folder to transfer" : "Tria el fitxer o carpeta que voleu transferir",
     "Change" : "Canvia",
@@ -211,20 +220,36 @@ OC.L10N.register(
     "Ownership transfer request sent" : "S'ha enviat la sol·licitud de transferència de propietat",
     "Cannot transfer ownership of a file or folder you do not own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
     "Select file or folder to link to" : "Seleccioneu el fitxer o la carpeta que voleu enllaçar",
+    "Choose file" : "Tria el fitxer",
+    "Choose {file}" : "Tria {file}",
     "Loading current folder" : "S'està carregant la carpeta actual",
     "No files in here" : "No hi ha cap fitxer aquí",
     "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
     "Go to the previous folder" : "Torna a la carpeta anterior",
     "Go back" : "Torna",
-    "Open the files app settings" : "Obriu els paràmetres de l'aplicació Fitxers",
+    "Share" : "Comparteix",
+    "Shared by link" : "S'ha compartit amb un enllaç",
+    "Shared" : "S'ha compartit",
+    "Switch to list view" : "Canvia a la visualització de llista",
+    "Switch to grid view" : "Canvia a la visualització de quadrícula",
+    "Upload was cancelled by user" : "L'usuari ha cancel·lat la pujada",
+    "Error during upload: {message}" : "S'ha produït un error durant la pujada: {message}",
+    "Error during upload, status code {status}" : "S'ha produït un error durant la pujada, el codi d'estat és {status}",
+    "Unknown error during upload" : "S'ha produït un error desconegut durant la pujada",
+    "Views" : "Vistes",
     "Files settings" : "Paràmetres de Fitxers",
     "File cannot be accessed" : "No es pot accedir al fitxer",
-    "You might not have have permissions to view it, ask the sender to share it" : "És possible que no tingueu permisos per a visualitzar-lo; demaneu al remitent que el comparteixi",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "No s'ha trobat el fitxer o no teniu permisos per a visualitzar-lo. Demaneu al remitent que el comparteixi.",
+    "Your files" : "Els vostres fitxers",
+    "Open in files" : "Obre a Fitxers",
     "Sort favorites first" : "Ordena primer els preferits",
+    "Sort folders before files" : "Ordena les carpetes abans dels fitxers",
     "Show hidden files" : "Mostra els fitxers ocults",
     "Crop image previews" : "Retalla les previsualitzacions de les imatges",
+    "Enable the grid view" : "Habilita la visualització de quadrícula",
     "Additional settings" : "Paràmetres addicionals",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL de WebDAV",
     "Copy to clipboard" : "Copia-ho al porta-retalls",
     "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si heu habilitat l'autenticació de doble factor, podeu crear i utilitzar una nova contrasenya d'aplicació fent clic aquí.",
@@ -233,50 +258,98 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
     "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
     "Pick a template for {name}" : "Trieu una plantilla per a {name}",
-    "Create" : "Crea",
     "Create a new file with the selected template" : "Crea un fitxer amb la plantilla seleccionada",
     "Creating file" : "S'està creant el fitxer",
     "Blank" : "En blanc",
     "Unable to create new file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
+    "Deletion cancelled" : "S'ha cancel·lat la supressió",
     "Delete permanently" : "Suprimeix permanentment",
+    "Delete and unshare" : "Suprimeix i deixa de compartir",
+    "Leave these shares" : "Abandona aquests elements compartits",
+    "Disconnect storages" : "Desconnecta els emmagatzematges",
+    "Delete files" : "Suprimeix els fitxers",
+    "Delete folders" : "Suprimeix les carpetes",
+    "Confirm deletion" : "Confirma la supressió",
+    "Cancel" : "Cancel·la",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Ara el fitxer hauria d'obrir-se localment. Si no veieu que això passa, assegureu-vos que el client d'escriptori estigui instal·lat al vostre sistema.",
+    "Destination is not a folder" : "La destinació no és una carpeta",
+    "This file/folder is already in that directory" : "Aquest fitxer o carpeta ja existeix en aquesta carpeta",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "No podeu moure un fitxer o carpeta a la mateixa carpeta o a una subcarpeta de la mateixa carpeta",
+    "(copy)" : "(còpia)",
+    "(copy %n)" : "(còpia %n)",
+    "Move cancelled" : "S'ha cancel·lat el desplaçament",
+    "A file or folder with that name already exists in this folder" : "Ja existeix un fitxer o carpeta amb aquest nom en aquesta carpeta",
+    "The files are locked" : "Els fitxers estan blocats",
+    "The file does not exist anymore" : "El fitxer ja no existeix",
+    "Choose destination" : "Trieu una destinació",
+    "Copy to {target}" : "Copia a {target}",
+    "Move to {target}" : "Mou a {target}",
+    "Move or copy operation failed" : "Error en l'operació de desplaçament o còpia",
+    "Cancelled move or copy operation" : "S'ha cancel·lat l'operació de desplaçament o còpia",
     "Open folder {displayName}" : "Obre la carpeta {displayName}",
     "Open in Files" : "Obre a Fitxers",
     "Open details" : "Obre els detalls",
-    "Set up templates folder" : "Configura la carpeta de plantilles",
-    "Templates" : "Plantilles",
-    "Create new templates folder" : "Crea la carpeta de plantilles",
+    "Today" : "Avui",
+    "Last 7 days" : "Últims 7 dies",
+    "Last 30 days" : "Últims 30 dies",
+    "Documents" : "Documents",
+    "Folders" : "Carpetes",
+    "Audio" : "Àudio",
+    "Videos" : "Vídeos",
+    "Created new folder \"{name}\"" : "S'ha creat la carpeta nova «{name}»",
     "Unable to initialize the templates directory" : "No s'ha pogut inicialitzar la carpeta de plantilles",
+    "Templates" : "Plantilles",
+    "New template folder" : "Carpeta de plantilles nova",
+    "In folder" : "En la carpeta",
+    "Search in folder: {folder}" : "Cerca en la carpeta: {folder}",
+    "One of the dropped files could not be processed" : "No s'ha pogut processar un dels fitxers que heu deixat anar.",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "El vostre navegador no és compatible amb l'API FileSystem. No es pujaran les carpetes.",
+    "No files to upload" : "No hi ha cap fitxer per pujar",
+    "Unable to create the directory {directory}" : "No s'ha pogut crear la carpeta {directory}",
+    "Some files could not be uploaded" : "No s'han pogut pujar alguns fitxers",
+    "Files uploaded successfully" : "Els fitxers s'han pujat correctament",
+    "No files to process" : "No hi ha cap fitxer per processar",
+    "Some files could not be copied" : "No s'han pogut copiar alguns fitxers",
+    "Some files could not be moved" : "No s'han pogut moure alguns fitxers",
+    "Files copied successfully" : "Els fitxers s'han copiat correctament",
+    "Files moved successfully" : "Els fitxers s'han mogut correctament",
+    "Conflicts resolution skipped" : "S'ha omès la resolució de conflictes",
+    "Upload cancelled" : "S'ha cancel·lat la pujada",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
     "List of favorites files and folders." : "Llista de fitxers i carpetes preferits.",
     "No favorites yet" : "Encara no teniu preferits",
     "Files and folders you mark as favorite will show up here" : "Els fitxers i les carpetes que marqueu com a preferits es mostraran aquí",
+    "All files" : "Tots els fitxers",
+    "List of your files and folders." : "Llista dels vostres fitxers i carpetes.",
+    "All folders" : "Totes les carpetes",
+    "Personal Files" : "FItxers personals",
+    "List of your files and folders that are not shared." : "Llista dels vostres fitxers i carpetes que no compartiu.",
+    "No personal files found" : "No s'ha trobat cap fitxer personal",
+    "Files that are not shared will show up here." : "Els fitxers que no compartiu es mostraran aquí.",
     "List of recently modified files and folders." : "Llista de fitxers i carpetes modificats recentment.",
     "No recently modified files" : "No hi ha cap fitxer modificat recentment",
     "Files and folders you recently modified will show up here." : "Els fitxers i les carpetes que heu modificat recentment es mostraran aquí",
-    "Toggle %1$s sublist" : "Canvia la subllista de %1$s",
-    "Toggle grid view" : "Canvia la visualització de quadrícula",
     "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
+    "Select all" : "Selecciona-ho tot",
     "Upload too large" : "La pujada és massa gran",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que intenteu pujar superen la mida màxima de pujada de fitxers del servidor.",
     "Text file" : "Fitxer de text",
     "New text file.txt" : "Fitxer de text nou.txt",
-    "Storage invalid" : "L'emmagatzematge no és vàlid",
-    "You can only favorite a single file or folder at a time" : "Només podeu afegir als preferits un fitxer o carpeta alhora",
-    "Unlimited" : "Il·limitat",
-    "Search users" : "Cerqueu usuaris",
-    "Cancel" : "Cancel·la",
-    "%s used" : "%s en ús",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s de %2$s en ús",
-    "Deleted files" : "Fitxers suprimits",
-    "Shares" : "Elements compartits",
-    "Shared with others" : "Compartit amb altres usuaris",
-    "Shared with you" : "Compartit amb vós",
-    "Shared by link" : "Compartit amb un enllaç",
-    "Deleted shares" : "Suprimit",
-    "Pending shares" : "Pendent",
-    "Open folder {name}" : "Obre la carpeta {name}",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Aquesta llista no es mostra completament per raons de rendiment. Es mostraran els fitxers a mesura que navegueu per la llista.",
-    "Search for an account" : "Cerqueu un compte",
-    "No files or folders have been deleted yet" : "Encara no s'ha suprimit cap fitxer o carpeta"
+    "Direct link was copied (only works for users who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per als usuaris que tenen accés a aquest fitxer o carpeta)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per als usuaris que tinguin accés a aquest fitxer o carpeta)",
+    "\"remote user\"" : "«usuari remot»",
+    "{newName} already exists." : "{newName} ja existeix.",
+    "Name cannot be empty" : "El nom no pot estar buit",
+    "Another entry with the same name already exists" : "Ja existeix una altra entrada amb aquest nom",
+    "Storage informations" : "Informació d'emmagatzematge",
+    "Open the files app settings" : "Obre els paràmetres de l'aplicació Fitxers",
+    "You might not have have permissions to view it, ask the sender to share it" : "És possible que no tingueu permisos per a visualitzar-lo; demaneu al remitent que el comparteixi",
+    "The files is locked" : "El fitxer està blocat",
+    "Create new templates folder" : "Crea la carpeta de plantilles",
+    "Toggle %1$s sublist" : "Canvia la subllista de %1$s"
 },
 "nplurals=2; plural=(n != 1);");
