@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde Ihren <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
+    "Failed to authorize" : "Autorisierung fehlgeschlagen",
+    "Invalid folder path" : "Ungültiger Order-Pfad",
+    "Folder not found" : "Ordner nicht gefunden",
     "Upload (max. %s)" : "Hochladen (max. %s)",
+    "Files compatibility" : "Dateikompatibilität",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
+    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
     "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
+    "Ownership transfer denied" : "Besitzübertragung abgelehnt",
+    "Your ownership transfer of {path} was denied by {user}." : "Die Besitzübertragung von {path} wurde von {user} abgelehnt.",
     "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
     "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
     "The ownership transfer of {path} from {user} failed." : "Die Besitzübertragung von {path} vom Benutzer {user} ist fehlgeschlagen.",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
+    "Transferred from %1$s on %2$s" : "Übertragen von %1$s an %2$s",
     "File Management" : "Dateiverwaltung",
     "Current directory path" : "Aktueller Verzeichnispfad",
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
@@ -179,23 +189,25 @@ OC.L10N.register(
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
     "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
+    "File is loading" : "Datei wird geladen",
+    "Folder is loading" : "Ordner wird geladen",
     "Rename file" : "Datei umbenennen",
-    "File name" : "Dateiname",
+    "Filename" : "Dateiname",
     "Folder name" : "Ordnername",
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar",
-    "Download file {name}" : "Datei {name} herunterladen",
-    "Invalid file name" : "Ungültiger Dateiname",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" ist kein zulässiger Dateityp.",
-    "{newName} already exists." : "{newName} existiert bereits.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
-    "Name cannot be empty" : "Der Name darf nicht leer sein",
-    "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits",
+    "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
+    "Invalid filename." : "Ungültiger Dateiname.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wählen Sie einen anderen Namen.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden",
+    "Clear filter" : "Filter zurücksetzen",
+    "Type" : "Typ",
+    "Active filters" : "Aktive Filter",
+    "Remove filter" : "Filter entfernen",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
+    "(selected)" : "(ausgewählt)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
     "{count} selected" : "{count} ausgewählt",
@@ -203,13 +215,17 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
     "File not found" : "Datei nicht gefunden",
-    "Storage informations" : "Speicherinformationen",
+    "Storage information" : "Speicherinformation",
+    "Storage quota" : "Speicherkontingent",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{relative}% used" : "{relative}% verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
     "Create" : "Erstellen",
-    "A file or folder with that name already exists." : "Eine Datei oder ein Ordner mit diesem Namen existiert bereits.",
+    "This name is already in use." : "Dieser Name wird bereits verwendet.",
+    "Fill template fields" : "Vorlagenfelder ausfüllen",
+    "Submitting fields…" : "Felder werden übermittelt…",
+    "Submit" : "Übermitteln",
     "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
@@ -234,10 +250,12 @@ OC.L10N.register(
     "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Kachelansicht wechseln",
+    "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen",
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
-    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
+    "Filter filenames…" : "Dateinamen filtern…",
+    "Views" : "Ansichten",
     "Files settings" : "Dateien-Einstellungen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Sie haben keine Berechtigungen, um sie anzuzeigen. Bitten Sie den Absender, die Datei zu teilen.",
@@ -248,6 +266,7 @@ OC.L10N.register(
     "Show hidden files" : "Versteckte Dateien anzeigen",
     "Crop image previews" : "Bildvorschauen zuschneiden",
     "Enable the grid view" : "Kachelansicht aktivieren",
+    "Enable folder tree" : "Ordnerstruktur aktivieren",
     "Additional settings" : "Zusätzliche Einstellungen",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV-URL",
@@ -263,16 +282,21 @@ OC.L10N.register(
     "Creating file" : "Datei erstellen",
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei kann nicht aus Vorlage erstellt werden",
+    "Deletion cancelled" : "Löschen abgebrochen",
     "Delete permanently" : "Endgültig löschen",
     "Delete and unshare" : "Löschen und nicht mehr teilen",
     "Leave these shares" : "Diese Freigaben verlassen",
     "Disconnect storages" : "Speicher trennen",
     "Delete files" : "Dateien löschen",
     "Delete folders" : "Ordner löschen",
-    "You are about to delete {count} items." : "Sie sind dabei, {count} Elemente zu löschen.",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Sie sind dabei, {count} Elemente endgültig zu löschen"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Sie sind dabei, {count} Elemente zu löschen"],
     "Confirm deletion" : "Löschen bestätigen",
     "Cancel" : "Abbrechen",
-    "Deletion cancelled" : "Löschen abgebrochen",
+    "Edit file locally" : "Datei lokal bearbeiten",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Die Datei sollte nun lokal geöffnet werden. Wenn dies nicht der Fall ist, stellen Sie sicher, dass der Desktop-Client auf Ihrem System installiert ist.",
+    "Retry local edit" : "Lokale Bearbeitung erneut versuchen",
+    "Edit online" : "Online bearbeiten",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
@@ -285,15 +309,29 @@ OC.L10N.register(
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
     "Move to {target}" : "Nach {target} verschieben",
-    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
+    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
+    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In Dateien öffnen",
     "Open details" : "Details öffnen",
+    "Today" : "Heute",
+    "Last 7 days" : "Die letzten 7 Tage",
+    "Last 30 days" : "Die letzten 30 Tage",
+    "This year ({year})" : "Dieses Jahr ({year})",
+    "Last year ({year})" : "Letztes Jahr ({year})",
+    "Documents" : "Dokumente",
+    "Spreadsheets" : "Tabellenkalkulationen",
+    "Presentations" : "Präsentationen",
+    "PDFs" : "PDFs",
+    "Folders" : "Ordner",
+    "Audio" : "Audio",
+    "Photos and images" : "Fotos und Bilder",
+    "Videos" : "Videos",
+    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
     "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
-    "Filename" : "Dateiname",
     "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
-    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
+    "Create templates folder" : "Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
     "New template folder" : "Neuer Vorlagenordner",
     "In folder" : "Im Ordner",
@@ -316,11 +354,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
+    "Filename must not be empty." : "Dateiname darf nicht leer sein.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ist kein zulässiger Dateityp.",
+    "Filenames must not end with \"{extension}\"." : "Dateinamen dürfen nicht mit \"{extension}\" enden.",
     "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien.",
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
     "All files" : "Alle Dateien",
     "List of your files and folders." : "Liste Ihrer Dateien und Ordner.",
+    "All folders" : "Alle Ordner",
     "Personal Files" : "Persönliche Dateien",
     "List of your files and folders that are not shared." : "Liste Ihrer Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
@@ -336,29 +380,19 @@ OC.L10N.register(
     "New text file.txt" : "Neue Textdatei file.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
     "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
-    "You can only favorite a single file or folder at a time" : "Sie können gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
-    "This file has the tag {tag}" : "Diese Datei trägt das Schlagwort {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Diese Datei trägt die Schlagworte {firstTags} und {lastTag}",
     "\"remote user\"" : "„Externer Benutzer“",
-    "Select the row for {displayName}" : "Zeile für {displayName} auswählen",
-    "Open folder {name}" : "Ordner {name} öffnen",
-    "Unselect all" : "Auswahl aufheben",
-    "ascending" : "Aufsteigend",
-    "descending" : "Absteigend",
-    "Sort list by {column} ({direction})" : "Liste sortieren nach {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
-    "Search for an account" : "Nach einem Konto suchen",
-    "Choose" : "Auswählen",
-    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht",
+    "{newName} already exists." : "{newName} existiert bereits.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" ist in einem Dateinamen unzulässig.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" ist ein unzulässiger Datei- oder Ordnername.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" ist kein zulässiger Dateityp.",
+    "Filenames must not end with \"{segment}\"." : "Dateinamen dürfen nicht mit \"{segment}\" enden.",
+    "Name cannot be empty" : "Der Name darf nicht leer sein",
+    "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits",
+    "Storage informations" : "Speicherinformationen",
+    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
     "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise haben Sie nicht die Berechtigung zur Anzeige. Bitten Sie den Absender, die Datei freizugeben.",
-    "Set up templates folder" : "Vorlagenordner einrichten",
-    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
-    "Toggle grid view" : "Kachelansicht umschalten",
-    "Shares" : "Freigaben",
-    "Shared with others" : "Mit anderen geteilt",
-    "Shared with you" : "Mit Ihnen geteilt",
-    "Deleted shares" : "Gelöschte Freigaben",
-    "Pending shares" : "Ausstehende Freigaben",
-    "The files is locked" : "Die Datei ist gesperrt"
+    "The files is locked" : "Die Datei ist gesperrt",
+    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
+    "Toggle %1$s sublist" : "Unterliste %1$s umschalten"
 },
 "nplurals=2; plural=(n != 1);");
