@@ -34,7 +34,7 @@ OC.L10N.register(
     "Move" : "Mugitu",
     "Copy" : "Kopiatu",
     "Choose target folder" : "Aukeratu helburuko karpeta",
-    "Set reminder" : "Ezarri abisua",
+    "Set reminder" : "Ezarri gogorarazpena",
     "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
     "Delete file" : "Fitxategia ezabatu",
@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
     "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Gogoko fitxategi edo karpeta bat <strong>aldatu</strong> egin da.",
+    "Failed to authorize" : "Ezin izan da baimendu",
+    "Invalid folder path" : "Karpeta bide baliogabea",
+    "Folder not found" : "Ez da karpeta aurkitu",
     "Upload (max. %s)" : "Igo (%s gehienez)",
+    "Files compatibility" : "Fitxategien bateragarritasuna",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
+    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
     "Incoming ownership transfer from {user}" : "{user}(r)en jabetza-transferentzia",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} onartu nahi duzu?\n\nOharra: onarpenaren ondoren transferentzia prozesuak ordu 1 iraun dezake.",
+    "Ownership transfer denied" : "Jabetza transferentzia ukatu egin da",
+    "Your ownership transfer of {path} was denied by {user}." : "{path}-ren zure jabetza-transferentzia {user} erabiltzaileak ukatu du",
     "Ownership transfer failed" : "Jabetzaren transferentziak huts egin du",
     "Your ownership transfer of {path} to {user} failed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzeak huts egin du.",
     "The ownership transfer of {path} from {user} failed." : "{path}(r)ren jabetza {user} erabiltzailetik transferitzeak huts egin du.",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzea osatu da.",
     "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
     "in %s" : "%s(e)n",
+    "Transferred from %1$s on %2$s" : "%1$s(e)tik %2$s(e)n transferitua",
     "File Management" : "Fitxategi-kudeaketa",
     "Current directory path" : "Uneko direktorio-bidea",
     "Reload current directory" : "Birkargatu uneko direktorioa",
@@ -180,34 +190,40 @@ OC.L10N.register(
     "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
     "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
     "Rename file" : "Berrizendatu fitxategia",
-    "File name" : "Fitxategi izena",
+    "Filename" : "Fitxategi-izena",
     "Folder name" : "Karpetaren izena",
     "This node is unavailable" : "Nodo hori ez dago erabilgarri",
-    "Download file {name}" : "Deskargatu {name} fitxategia ",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" fitxategi-mota ez da onartzen.",
-    "{newName} already exists." : "{newName} badago aurretik.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" ez da onartze fitxategi-izenen barnean.",
-    "Name cannot be empty" : "Izena ezin da hutsik egon",
-    "Another entry with the same name already exists" : "Badago izen hori duen beste sarrera bat",
+    "Another entry with the same name already exists." : "Izen bereko beste sarrera bat badago jada.",
+    "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
     "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
     "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
+    "Clear filter" : "Garbitu iragazkia",
+    "Type" : "Mota",
+    "Active filters" : "Iragazki aktiboak",
+    "Remove filter" : "Kendu iragazkia",
     "Total rows summary" : "Errenkaden guztirako laburpena",
     "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
+    "(selected)" : "(hautatuta)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
+    "{count} selected" : "{count} hautatuta",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
-    "Storage informations" : "Biltegiaren informazioak",
+    "Storage information" : "Biltegiaren informazioa",
+    "Storage quota" : "Biltegiratze-kuota",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{relative}% used" : "%{relative} erabilita",
     "Could not refresh storage stats" : "Ezin izan da biltegiratze maila freskatu",
     "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
     "Create" : "Sortu",
-    "A file or folder with that name already exists." : "Badago izen hori duen fitxategi edo karpeta.",
+    "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
+    "Fill template fields" : "Bete txantiloien eremuak",
+    "Submitting fields…" : "Eremuak bidaltzen…",
+    "Submit" : "Bidali",
     "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
     "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
     "Change" : "Aldatu",
@@ -232,10 +248,12 @@ OC.L10N.register(
     "Shared" : "Partekatuta",
     "Switch to list view" : "Aldatu zerrenda ikuspegira",
     "Switch to grid view" : "Aldatu sareta ikuspegira",
+    "Upload was cancelled by user" : "Igoera bertan behera utzi du erabiltzaileak",
     "Error during upload: {message}" : "Errorea igotzean: {message}",
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
-    "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
+    "Filter filenames…" : "Iragazi fitxategi-izenak...",
+    "Views" : "Ikuspegiak",
     "Files settings" : "FItxategien ezarpenak",
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
@@ -246,6 +264,7 @@ OC.L10N.register(
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
     "Crop image previews" : "Moztu irudien aurrebistak",
     "Enable the grid view" : "Gaitu sareta ikuspegira",
+    "Enable folder tree" : "Gaitu karpeta-zuhaitza",
     "Additional settings" : "Ezarpen gehiago",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URLa",
@@ -261,16 +280,21 @@ OC.L10N.register(
     "Creating file" : "Fitxategia sortzen",
     "Blank" : "Hutsik",
     "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
+    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
     "Delete permanently" : "Ezabatu betirako",
     "Delete and unshare" : "Ezabatu eta kendu partekatzea",
     "Leave these shares" : "Utzi partekatze hauek",
     "Disconnect storages" : "Deskonektatu biltegiak",
     "Delete files" : "Ezabatu fitxategiak",
     "Delete folders" : "Ezabatu karpetak",
-    "You are about to delete {count} items." : "{count} elementu ezabatzera zoaz.",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Elementu {count} betiko ezabatzera zoaz","{count} elementu betiko ezabatzera zoaz"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Elementu {count} ezabatzera zoaz"," {count}  elementu ezabatzera zoaz"],
     "Confirm deletion" : "Berretsi ezabaketa",
     "Cancel" : "Utzi",
-    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Edit file locally" : "Editatu fitxategia lokalean",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Orain fitxategiak modu lokalean ireki behar luke. Ez bada hori gertatzen, ziurta ezazu mahaigaineko bezeroa instalatuta daukazula zure sisteman.",
+    "Retry local edit" : "Saiatu berriro tokiko edizioa",
+    "Edit online" : "Editatu sarean",
     "Destination is not a folder" : "Helburua ez da karpeta bat",
     "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
@@ -283,15 +307,28 @@ OC.L10N.register(
     "Choose destination" : "Aukeratu helburua",
     "Copy to {target}" : "Kopiatu hona: {target}",
     "Move to {target}" : "Mugitu hona: {target}",
-    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
+    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
     "Open details" : "Ireki xehetasunak",
+    "Today" : "Gaur",
+    "Last 7 days" : "Azken 7 egunetan",
+    "Last 30 days" : "Azken 30 egunetan",
+    "This year ({year})" : "Aurten ({year})",
+    "Last year ({year})" : "Iaz ({year})",
+    "Documents" : "Dokumentuak",
+    "Spreadsheets" : "kalkulu-orriak",
+    "Presentations" : "Aurkezpenak",
+    "PDFs" : "PDFak",
+    "Folders" : "Karpetak",
+    "Audio" : "Audio",
+    "Videos" : "Bideoak",
+    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
     "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
-    "Filename" : "Fitxategi-izena",
     "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
-    "Create new templates folder" : "Sortu txantiloi karpeta berria",
+    "Create templates folder" : "Sortu txantiloien karpeta",
     "Templates" : "Txantiloiak",
     "New template folder" : "Txantiloien karpeta berria",
     "In folder" : "Karpetan",
@@ -314,11 +351,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
+    "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan..",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" fitxategi mota ez dago baimenduta.",
+    "Filenames must not end with \"{extension}\"." : "Fitxategi-izenak ez dira \"{extension}\"rekin amaitu behar..",
     "List of favorites files and folders." : "Fitxategi eta karpeta gogokoen zerrenda.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
     "All files" : "Fitxategi guztiak",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
+    "All folders" : "Karpeta guztiak",
     "Personal Files" : "Fitxategi pertsonalak",
     "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
     "No personal files found" : "Ez dago fitxategi pertsonalik",
@@ -334,29 +377,15 @@ OC.L10N.register(
     "New text file.txt" : "Testu-fitxategi berria.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
-    "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra markatu dezakezu gogoko gisa aldiko",
-    "This file has the tag {tag}" : "Fitxategi honek {tag} etiketa dauka",
-    "This file has the tags {firstTags} and {lastTag}" : "Fitxategi honek {firstTags} eta {lastTag} etiketak ditu",
     "\"remote user\"" : "\"urruneko erabiltzailea\"",
-    "Select the row for {displayName}" : "Hautatu {displayName} errenkada",
-    "Open folder {name}" : "Ireki {name} karpeta",
-    "Unselect all" : "Desautatu dena",
-    "ascending" : "goranzkoa",
-    "descending" : "beheranzkoa",
-    "Sort list by {column} ({direction})" : "Ordenatu zerrenda {zutabea} ({norabidea}) arabera",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
-    "Search for an account" : "Bilatu kontu bat",
-    "Choose" : "Aukeratu",
-    "No files or folders have been deleted yet" : "Oraindik ez da ezabatu fitxategirik edo karpetarik",
+    "{newName} already exists." : "{newName} badago aurretik.",
+    "Name cannot be empty" : "Izena ezin da hutsik egon",
+    "Another entry with the same name already exists" : "Badago izen hori duen beste sarrera bat",
+    "Storage informations" : "Biltegiaren informazioak",
+    "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
     "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
-    "Set up templates folder" : "Konfiguratu txantiloien karpeta",
-    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
-    "Toggle grid view" : "Txandakatu sareta ikuspegia",
-    "Shares" : "Partekatzeak",
-    "Shared with others" : "Besteekin partekatuta",
-    "Shared with you" : "Zurekin partekatuta",
-    "Deleted shares" : "Ezabatutako partekatzeak",
-    "Pending shares" : "Zain dauden partekatzeak",
-    "The files is locked" : "Fixategiak blokeatuta dago"
+    "The files is locked" : "Fixategiak blokeatuta dago",
+    "Create new templates folder" : "Sortu txantiloi karpeta berria",
+    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda"
 },
 "nplurals=2; plural=(n != 1);");
