@@ -38,6 +38,7 @@ OC.L10N.register(
     "Edit locally" : "ویرایش محلی",
     "Open" : "باز کردن",
     "Delete file" : "حذف پرونده",
+    "Delete folder" : "حذف پوشه",
     "Disconnect storage" : "فضای ذخیره را جدا کنید",
     "Leave this share" : "ترک این اشتراک",
     "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
@@ -172,31 +173,29 @@ OC.L10N.register(
     "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
     "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
     "Rename file" : "تغییر نام فایل",
-    "File name" : "نام فایل",
+    "Filename" : "نام پرونده",
     "Folder name" : "نام پوشه",
     "This node is unavailable" : "گره شما در دسترس نیست",
-    "Download file {name}" : "دانلود فایل {name}",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" یک نوع فایل مجاز نیست.",
-    "{newName} already exists." : "{newName} از قبل وجود دارد.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\"در نام فایل مجاز نیست.",
-    "Name cannot be empty" : "نام نمی‌تواند خالی باشد",
-    "Another entry with the same name already exists" : "ورودی دیگری با همین نام در حال حاضر وجود دارد",
     "Renamed \"{oldName}\" to \"{newName}\"" : "تغییر نام \"{oldName}\" به \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "نمی‌توان نام «{oldName}» را تغییر داد، دیگر وجود ندارد",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "نام \"{newName}\" در پوشه \"{dir}\" به کار رفته است.\nلطفا نام دیگری برگزینید.",
     "Could not rename \"{oldName}\"" : "تغییر نام \"{oldName}\" ممکن نیست",
+    "Clear filter" : "پاک کردن پالایه",
+    "Type" : "نوع",
+    "Active filters" : "Active filters",
+    "Remove filter" : "Remove filter",
     "Total rows summary" : "خلاصه کل ردیف ها",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" در برخی از عناصر ناموفق بود",
     "\"{displayName}\" batch action executed successfully" : "عملکرد دسته‌ای \"{displayName}\" با موفقیت اجرا شد",
     "List of files and folders." : "لیست فایل ها و پوشه ها",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "این لیست به دلایل عملکرد به طور کامل ارائه نشده است. در حین حرکت در لیست، فایل ها ارائه می شوند.",
     "File not found" : "فایل یافت نشد",
-    "Storage informations" : "ذخیره سازی اطلاعات ",
     "{usedQuotaByte} used" : "{usedQuotaByte} استفاده شده است",
     "{relative}% used" : "{نسبی}% استفاده شده است",
     "Could not refresh storage stats" : "نمی‌توان آمار ذخیره‌سازی را بازخوانی کرد",
     "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
     "Create" : "ساخت",
+    "Submit" : "ارسال",
     "Transfer ownership of a file or folder" : "انتقال مالکیت یک فایل یا پوشه",
     "Choose file or folder to transfer" : "فایل یا پوشه را برای انتقال انتخاب کنید",
     "Change" : "تغییر",
@@ -219,7 +218,8 @@ OC.L10N.register(
     "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
     "Shared" : "به اشتراک گذاشته شده ",
     "Switch to list view" : "Switch to list view",
-    "Open the files app settings" : "تنظیمات برنامه فایل ها را باز کنید",
+    "Upload was cancelled by user" : "آپلود توسط کاربر لغو شد",
+    "Views" : "بازدیدها",
     "Files settings" : "تنظیمات پرونده‌ها",
     "File cannot be accessed" : "فایل قابل دسترسی نیست",
     "Open in files" : "Open in files",
@@ -248,9 +248,13 @@ OC.L10N.register(
     "Open folder {displayName}" : "باز کردن پوشه {displayName}",
     "Open in Files" : "در فایل باز کنید",
     "Open details" : "باز کردن جزئیات",
-    "Filename" : "نام پرونده",
+    "Today" : "امروز",
+    "Last 7 days" : "۷ روز گذشته",
+    "Last 30 days" : "۳۰ روز گذشته",
+    "Documents" : "سندها",
+    "Audio" : "صدا",
+    "Videos" : "فیلم ها ",
     "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
-    "Create new templates folder" : "پوشه قالب های جدید ایجاد کنید",
     "Templates" : "قالب‌ها",
     "Some files could not be moved" : "برخی از پرونده‌ها قابل انتقال نیستند",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} پوشه","{folderCount} پوشه"],
@@ -270,28 +274,14 @@ OC.L10N.register(
     "New text file.txt" : "پروندهٔ متنی جدید با پسوند txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "پیوند مستقیم کپی شد (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
     "Copy direct link (only works for users who have access to this file/folder)" : "کپی لینک مستقیم (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
-    "You can only favorite a single file or folder at a time" : "در هر زمان فقط می توانید یک فایل یا پوشه را مورد علاقه خود قرار دهید",
-    "This file has the tag {tag}" : "این فایل دارای تگ {tag} است",
-    "This file has the tags {firstTags} and {lastTag}" : "این فایل دارای تگ‌های {firstTags} و {lastTag} است.",
     "\"remote user\"" : "\"کاربران از راه‌ دور\"",
-    "Select the row for {displayName}" : "ردیف {displayName} را انتخاب کنید",
-    "Open folder {name}" : "باز کردن پوشه {name}",
-    "Unselect all" : "همه را لغو انتخاب کنید",
-    "ascending" : "صعودی",
-    "descending" : "نزولی",
-    "Sort list by {column} ({direction})" : "مرتب سازی لیست بر اساس {ستون} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "این لیست به دلایل اجرایی به طور کامل ارائه نشده است. در حین حرکت در لیست، فایل ها ارائه می شوند.",
-    "Search for an account" : "جستجو برای یک حساب کاربری",
-    "Choose" : "انتخاب کنید",
-    "No files or folders have been deleted yet" : "هنوز هیچ فایل یا پوشه ای حذف نشده است",
+    "{newName} already exists." : "{newName} از قبل وجود دارد.",
+    "Name cannot be empty" : "نام نمی‌تواند خالی باشد",
+    "Another entry with the same name already exists" : "ورودی دیگری با همین نام در حال حاضر وجود دارد",
+    "Storage informations" : "ذخیره سازی اطلاعات ",
+    "Open the files app settings" : "تنظیمات برنامه فایل ها را باز کنید",
     "You might not have have permissions to view it, ask the sender to share it" : "ممکن است مجوز مشاهده آن را نداشته باشید، از فرستنده بخواهید آن را به اشتراک بگذارد",
-    "Set up templates folder" : "پوشه قالب ها را تنظیم کنید",
-    "Toggle %1$s sublist" : "تغییر%1$s فهرست فرعی",
-    "Toggle grid view" : "نمای شبکه را تغییر دهید",
-    "Shares" : "اشتراک گذاری ها",
-    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
-    "Shared with you" : "به اشتراک گذاشته شده با شما",
-    "Deleted shares" : "اشتراک گذاری های حذف شده",
-    "Pending shares" : "اشتراک در حال انتظار "
+    "Create new templates folder" : "پوشه قالب های جدید ایجاد کنید",
+    "Toggle %1$s sublist" : "تغییر%1$s فهرست فرعی"
 },
 "nplurals=2; plural=(n > 1);");
