@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "Definir lembrete",
     "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
-    "Delete file" : "Excluir arquivo",
+    "Delete file" : "Deletar arquivo",
     "Delete folder" : "Excluir pasta",
     "Disconnect storage" : "Desconectar armazenamento",
-    "Leave this share" : "Sair deste compartilhamento",
+    "Leave this share" : "Deixe esses compartilhamentos",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
     "Files" : "Arquivos",
     "Details" : "Detalhes",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Seu armazenamento está quase cheio ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
     "View in folder" : "Exibir na pasta",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "O link direto foi copiado (funciona apenas para usuários que têm acesso a este arquivo/pasta)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Link direto foi copiado (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
     "Path" : "Caminho",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Favoritado",
     "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar link direto (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
     "New folder" : "Nova pasta",
     "Create new folder" : "Criar nova pasta",
     "Upload file" : "Enviar arquivo",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renomeado por {user}",
     "Moved by {user}" : "Movido por {user}",
-    "\"remote user\"" : "\"usuário remoto\"",
+    "\"remote account\"" : "\"conta remota\"",
     "You created {file}" : "Você criou {file}",
     "You created an encrypted file in {file}" : "Você criou um arquivo criptografado em {file}",
     "{user} created {file}" : "{user} criou {file}",
@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Um arquivo foi adicionado ou removido de seus <strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta foi <strong>modificado</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta favorita foi <strong>modificado</strong>",
+    "Failed to authorize" : "Falha ao autorizar",
+    "Invalid folder path" : "Caminho de pasta inválido",
+    "Folder not found" : "Pasta não encontrada",
     "Upload (max. %s)" : "Envio (max. %s)",
+    "Files compatibility" : "Compatibilidade de arquivos",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restringir nomes de arquivos para garantir que os arquivos possam ser sincronizados com todos os clientes. Por padrão, todos os nomes de arquivos válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
+    "Enforce Windows compatibility" : "Aplicar compatibilidade do Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isso bloqueará nomes de arquivos não válidos em sistemas Windows, como nomes reservados ou caracteres especiais. Mas isso não imporá a compatibilidade da distinção entre maiúsculas e minúsculas.",
     "Accept" : "Aceitar",
     "Reject" : "Rejeitar",
     "Incoming ownership transfer from {user}" : "Transferência de propriedade recebida de {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Deseja aceitar {path}?\n\nObservação: O processo de transferência pode levar até 1 hora.",
+    "Ownership transfer denied" : "Transferência de propriedade negada",
+    "Your ownership transfer of {path} was denied by {user}." : "Sua transferência de propriedade de {caminho} foi negado por {usuário}.",
     "Ownership transfer failed" : "Erro na transferência da propriedade",
     "Your ownership transfer of {path} to {user} failed." : "Erro na transferência da sua propriedade de {path} para {user}.",
     "The ownership transfer of {path} from {user} failed." : "Erro na transferência da propriedade de {path} de {user}.",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "A transferência da sua propriedade de {path} para {user} foi concluída.",
     "The ownership transfer of {path} from {user} has completed." : "A transferência da propriedade de {path} de {user} foi concluída.",
     "in %s" : "em %s",
+    "Transferred from %1$s on %2$s" : "Transferido de %1$s para %2$s",
     "File Management" : "Gerenciamento de Arquivos",
     "Current directory path" : "Caminho do diretório atual",
     "Reload current directory" : "Recarregar diretório atual",
@@ -175,40 +185,46 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Arraste e solte os arquivos aqui para fazer upload",
     "Your have used your space quota and cannot upload files anymore" : "Você usou sua cota de espaço e não pode mais fazer upload de arquivos",
     "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
-    "Upload successful" : "Carregamento bem-sucedido",
     "\"{displayName}\" action executed successfully" : "Ação \"{displayName}\" executada com sucesso",
     "\"{displayName}\" action failed" : "A ação \"{displayName}\" falhou",
     "Toggle selection for file \"{displayName}\"" : "Alternar seleção do arquivo \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Alternar seleção da pasta \"{displayName}\"",
+    "File is loading" : "O arquivo está carregando",
+    "Folder is loading" : "A pasta está carregando",
     "Rename file" : "Renomear arquivo",
-    "File name" : "Nome do arquivo",
+    "Filename" : "Nome do arquivo",
     "Folder name" : "Nome da pasta",
     "This node is unavailable" : "Este nó está indisponível",
-    "Download file {name}" : "Baixe o arquivo {name}",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" não é um tipo de arquivo permitido.",
-    "{newName} already exists." : "{newName} já existe.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" não é permitido dentro de um nome de arquivo.",
-    "Name cannot be empty" : "O nome não pode ficar em branco",
-    "Another entry with the same name already exists" : "Já existe outra entrada com o mesmo nome",
+    "Another entry with the same name already exists." : "Outra entrada com o mesmo nome já existe.",
+    "Invalid filename." : "Nome de arquivo inválido.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear \"{oldName}\", ele não existe mais",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{newName}\" já é utilizado na pasta \"{dir}\". Escolha um nome diferente.",
     "Could not rename \"{oldName}\"" : "Não foi possível renomear \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Não foi possível copiar {file}. {message}",
-    "Could not move {file}. {message}" : "Não foi possível mover {file}. {message}",
+    "Clear filter" : "Limpar filtro",
+    "Type" : "Tipo",
+    "Active filters" : "Filtros ativos",
+    "Remove filter" : "Remover filtro",
     "Total rows summary" : "Resumo total de linhas",
     "Toggle selection for all files and folders" : "Alternar seleção para todos os arquivos e pastas",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" falhou em alguns elementos",
     "\"{displayName}\" batch action executed successfully" : "Ação em lote \"{displayName}\" executada com sucesso",
+    "{count} selected" : "{count} selecionados",
     "List of files and folders." : "Lista de arquivos e pastas.",
     "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são classificáveis.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Essa lista não é totalmente renderizada por motivos de desempenho. Os arquivos serão renderizados conforme você navega pela lista.",
     "File not found" : "Arquivo não encontrado",
-    "Storage informations" : "Informações de armazenamento",
+    "Storage information" : "Informações do armazenamento",
+    "Storage quota" : "Quantidade de armazenamento",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{relative}% used" : "{relative}% usado",
     "Could not refresh storage stats" : "Não foi possível atualizar as estatísticas de armazenamento",
     "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio e arquivos não podem mais ser atualizados ou sincronizados!",
+    "Create" : "Criar",
+    "This name is already in use." : "Este nome já está em uso.",
+    "Fill template fields" : "Preencher campos do template",
+    "Submitting fields…" : "Enviando arquivos…",
+    "Submit" : "Enviar",
     "Transfer ownership of a file or folder" : "Transferir a propriedade de um arquivo ou pasta",
     "Choose file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
     "Change" : "Mudar",
@@ -223,7 +239,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Selecione o arquivo ou pasta para vincular",
     "Choose file" : "Escolher arquivo",
     "Choose {file}" : "Escolher {file}",
-    "Add" : "Adicionar",
     "Loading current folder" : "Carregando a pasta atual",
     "No files in here" : "Nenhum arquivo aqui",
     "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
@@ -234,18 +249,23 @@ OC.L10N.register(
     "Shared" : "Compartilhado",
     "Switch to list view" : "Mudar para a visualizar lista",
     "Switch to grid view" : "Mudar para visualização em grade",
+    "Upload was cancelled by user" : "O upload foi cancelado pelo usuário",
     "Error during upload: {message}" : "Erro durante o upload: {message}",
     "Error during upload, status code {status}" : "Erro durante o upload, código de status {status}",
     "Unknown error during upload" : "Erro desconhecido durante o upload",
-    "Open the files app settings" : "Abra as configurações do aplicativo de arquivos",
+    "Filter filenames…" : "Filtrar nomes de arquivos...",
+    "Views" : "Visualizações",
     "Files settings" : "Configurações de arquivos",
     "File cannot be accessed" : "File cannot be accessed",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "O arquivo não foi encontrado ou você não tem permissão para visualizá-lo. Peça ao remetente para compartilhá-lo.",
+    "Your files" : "Seus arquivos",
+    "Open in files" : "Abrir em arquivos",
     "Sort favorites first" : "Ordenar favoritos primeiro",
     "Sort folders before files" : "Classifique as pastas antes dos arquivos",
     "Show hidden files" : "Mostrar arquivos ocultos",
     "Crop image previews" : "Cortar visualizações de imagem",
     "Enable the grid view" : "Habilite a visualização em grade",
+    "Enable folder tree" : "Habilitar árvore de pastas",
     "Additional settings" : "Configurações adicionais",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -257,44 +277,97 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
     "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
     "Pick a template for {name}" : "Escolha um modelo para {name}",
-    "Create" : "Criar",
     "Create a new file with the selected template" : "Crie um novo arquivo com o modelo selecionado",
     "Creating file" : "Criando arquivo",
     "Blank" : "Em branco",
     "Unable to create new file from template" : "Incapaz de criar novo arquivo a partir do modelo",
+    "Deletion cancelled" : "Operação de exclusão cancelada",
     "Delete permanently" : "Remover permanentemente",
+    "Delete and unshare" : "Excluir e descompartilhar",
+    "Leave these shares" : "Deixe esses compartilhamentos",
+    "Disconnect storages" : "Desconectar armazenamentos",
+    "Delete files" : "Deletar arquivos",
+    "Delete folders" : "Excluir pastas",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Você está prestes a excluir permanentemente {count} itens","Você está prestes a excluir permanentemente {count} itens","Você está prestes a excluir permanentemente {count} itens"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Você está prestes a excluir {count} itens","Você está prestes a excluir {count} itens","Você está prestes a excluir {count} itens"],
+    "Confirm deletion" : "Confirmar exclusão",
+    "Cancel" : "Cancelar",
+    "Edit file locally" : "Editar arquivo localmente",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "O arquivo agora deve abrir localmente. Se isso não acontecer, certifique-se de que o cliente de desktop esteja instalado em seu sistema.",
+    "Retry local edit" : "Tentar novamente a edição local",
+    "Edit online" : "Editar on-line",
     "Destination is not a folder" : "O destino não é uma pasta",
     "This file/folder is already in that directory" : "Este arquivo/pasta já está nesse diretório",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Você não pode mover um arquivo/pasta para si mesmo ou para uma subpasta dele mesmo",
     "(copy)" : "(cópia)",
     "(copy %n)" : "(copiar %n)",
+    "Move cancelled" : "Movimento cancelado",
     "A file or folder with that name already exists in this folder" : "Já existe um arquivo ou pasta com esse nome nesta pasta",
-    "The files is locked" : "Os arquivos estão bloqueados",
+    "The files are locked" : "Os arquivos estão bloqueados",
     "The file does not exist anymore" : "O arquivo não existe mais",
     "Choose destination" : "Escolha o destino",
     "Copy to {target}" : "Copiar para {target}",
     "Move to {target}" : "Mover para {target}",
-    "Cancelled move or copy operation" : "Operação de movimentação ou cópia cancelada",
     "Move or copy operation failed" : "Falha na operação de movimentação ou cópia",
+    "Cancelled move or copy of \"{filename}\"." : "Movimiento cancelado o copia de \"{filename}\".",
+    "Cancelled move or copy operation" : "Operação de movimentação ou cópia cancelada",
     "Open folder {displayName}" : "Abra a pasta {displayName}",
     "Open in Files" : "Abrir em arquivos",
     "Open details" : "Abrir detalhes",
-    "Create new templates folder" : "Criar nova pasta de modelos",
-    "Templates" : "Modelos",
-    "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos",
+    "Today" : "Hoje",
+    "Last 7 days" : "Últimos 7 dias",
+    "Last 30 days" : "Últimos 30 dias",
+    "This year ({year})" : "Este ano ({year})",
+    "Last year ({year})" : "Ano passado  ({year})",
+    "Documents" : "Documentos",
+    "Spreadsheets" : "Planilhas",
+    "Presentations" : "Apresentações",
+    "PDFs" : "PDFs",
+    "Folders" : "Pastas",
+    "Audio" : "Áudio",
+    "Photos and images" : "Fotos e imagens",
+    "Videos" : "Vídeos",
+    "New folder creation cancelled" : "Criação de nova pasta cancelada",
     "Created new folder \"{name}\"" : "Nova pasta criada \"{name}\"",
+    "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos",
+    "Create templates folder" : "Criar pasta de modelos",
+    "Templates" : "Modelos",
+    "New template folder" : "Nova pasta de modelo",
+    "In folder" : "Na pasta",
+    "Search in folder: {folder}" : "Pesquisar na pasta: {folder}",
     "One of the dropped files could not be processed" : "Um dos arquivos descartados não pôde ser processado",
-    "Uploading \"{filename}\" failed" : "O upload de \"{filename}\" falhou",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Seu navegador não oferece suporte à API Filesystem. Os diretórios não serão carregados",
+    "No files to upload" : "Não há arquivos para enviar",
+    "Unable to create the directory {directory}" : "Não foi possível criar o diretório {directory}",
+    "Some files could not be uploaded" : "Alguns arquivos não puderam ser carregados",
+    "Files uploaded successfully" : "Arquivos enviados com sucesso",
+    "No files to process" : "Nenhum arquivo para processar",
+    "Some files could not be copied" : "Alguns arquivos não puderam ser copiados",
+    "Some files could not be moved" : "Alguns arquivos não puderam ser movidos",
+    "Files copied successfully" : "Arquivos copiados com sucesso",
+    "Files moved successfully" : "Arquivos movidos com sucesso",
+    "Conflicts resolution skipped" : "Resolução de conflitos ignorada",
+    "Upload cancelled" : "Carregamento cancelado",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} pastas","{folderCount} pastas","{folderCount} pastas"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} arquivos","{fileCount} arquivos","{fileCount} arquivos"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 arquivo e {folderCount} pastas","1 arquivo e {folderCount} pastas","1 arquivo e {folderCount} pastas"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} arquivos e 1 pasta","{fileCount} arquivos e 1 pasta","{fileCount} arquivos e 1 pasta"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} arquivos e {folderCount} pastas",
+    "Filename must not be empty." : "O nome do arquivo não pode estar vazio.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" não é permitido dentro de um nome de arquivo.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" é um nome reservado e não é permitido para nomes de arquivos.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" não é um tipo de arquivo permitido.",
+    "Filenames must not end with \"{extension}\"." : "Os nomes de arquivos não podem terminar com \"{extension}\".",
     "List of favorites files and folders." : "Lista de arquivos e pastas favoritos.",
     "No favorites yet" : "Você não possui favoritos!",
     "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
     "All files" : "Todos os arquivos",
     "List of your files and folders." : "Lista de seus arquivos e pastas.",
+    "All folders" : "Todas as pastas",
+    "Personal Files" : "Arquivos pessoais",
+    "List of your files and folders that are not shared." : "Lista dos seus arquivos e pastas que não estão compartilhados.",
+    "No personal files found" : "Nenhum arquivo pessoal encontrado",
+    "Files that are not shared will show up here." : "Arquivos que não estão compartilhados aparecerão aqui.",
     "List of recently modified files and folders." : "Lista de arquivos e pastas modificados recentemente.",
     "No recently modified files" : "Nenhum arquivo modificado recentemente",
     "Files and folders you recently modified will show up here." : "Arquivos e pastas que você modificou recentemente aparecerão aqui.",
@@ -304,30 +377,21 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
     "Text file" : "Arquivo texto",
     "New text file.txt" : "Novo arquivo de texto arquivo.txt",
-    "You can only favorite a single file or folder at a time" : "Você só pode favoritar um único arquivo ou pasta de cada vez",
-    "Search users" : "Procurar usuários",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "O link direto foi copiado (funciona apenas para usuários que têm acesso a este arquivo/pasta)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
+    "\"remote user\"" : "\"usuário remoto\"",
+    "{newName} already exists." : "{newName} já existe.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" não é permitido dentro de um nome de arquivo.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" é um nome de arquivo ou pasta proibido.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" não é um tipo de arquivo permitido.",
+    "Filenames must not end with \"{segment}\"." : "Os nomes de arquivos não devem terminar com \"{segment}\".",
+    "Name cannot be empty" : "O nome não pode ficar em branco",
+    "Another entry with the same name already exists" : "Já existe outra entrada com o mesmo nome",
+    "Storage informations" : "Informações de armazenamento",
+    "Open the files app settings" : "Abra as configurações do aplicativo de arquivos",
     "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
-    "Cancel" : "Cancelar",
-    "Set up templates folder" : "Configurar pasta de modelos",
-    "Toggle %1$s sublist" : "Alternar a sublista %1$s",
-    "Toggle grid view" : "Alternar a visão em grade",
-    "Deleted files" : "Arquivos apagados",
-    "Shares" : "Compartilhamentos",
-    "Shared with others" : "Compartilhado com os outros",
-    "Shared with you" : "Compartilhado com você",
-    "Deleted shares" : "Compartilhamentos apagados",
-    "Pending shares" : "Compartilhamentos pendentes",
-    "This file has the tag {tag}" : "Este arquivo tem a tag {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}",
-    "Select the row for {displayName}" : "Selecione a linha para {displayName}",
-    "Open folder {name}" : "Abra a pasta {nome}",
-    "Unselect all" : "Desmarque todos",
-    "ascending" : "ascendente",
-    "descending" : "descendente",
-    "Sort list by {column} ({direction})" : "Classificar lista por {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista não é totalmente renderizada por motivos de desempenho. Os arquivos serão renderizados conforme você navega pela lista.",
-    "Search for an account" : "Pesquisar uma conta",
-    "Choose" : "Escolher",
-    "No files or folders have been deleted yet" : "Nenhum arquivo ou pasta foi excluído ainda"
+    "The files is locked" : "Os arquivos estão bloqueados",
+    "Create new templates folder" : "Criar nova pasta de modelos",
+    "Toggle %1$s sublist" : "Alternar a sublista %1$s"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
