@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "已將檔案添加到<strong>我的最愛</strong>收藏夾中或從其中刪除",
     "A file or folder has been <strong>changed</strong>" : "檔案或資料夾有所<strong>更改</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "收藏的檔案或資料夾有所<strong>更改</strong>",
+    "Failed to authorize" : "無法授權",
+    "Invalid folder path" : "無效的資料夾路徑",
+    "Folder not found" : "找不到資料夾",
     "Upload (max. %s)" : "上傳（上限 %s）",
+    "Files compatibility" : "檔案兼容性",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
+    "Enforce Windows compatibility" : "實施 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
     "Accept" : "接受",
     "Reject" : "拒絕",
     "Incoming ownership transfer from {user}" : "來自 {user} 的擁有權轉移",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您想要接收 \"{path}\" 嗎？\n\n註：所有權轉移的流程最多需要一小時",
+    "Ownership transfer denied" : "擁有權轉移被拒絕",
+    "Your ownership transfer of {path} was denied by {user}." : "您 \"{path}\" 的擁有權轉移被 {user} 拒絕",
     "Ownership transfer failed" : "擁有權轉讓失敗",
     "Your ownership transfer of {path} to {user} failed." : "您將 \"{path}\" 的擁有權轉移給 {user} 失敗",
     "The ownership transfer of {path} from {user} failed." : "來自 {user} 的 \"{path}\" 擁有權轉移失敗",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "您將 \"{path}\" 的所有權轉移給 {user} 已經完成",
     "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "in %s" : "在 %s",
+    "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
     "File Management" : "檔案管理",
     "Current directory path" : "目前目錄途徑",
     "Reload current directory" : "重新加載目前目錄",
@@ -179,23 +189,25 @@ OC.L10N.register(
     "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
     "Toggle selection for file \"{displayName}\"" : "切換對檔案 \"{displayName}\" 的選擇",
     "Toggle selection for folder \"{displayName}\"" : "切換對資料夾 \"{displayName}\" 的選擇",
+    "File is loading" : "正在加載檔案",
+    "Folder is loading" : "正在加載資料夾",
     "Rename file" : "重新命名檔案",
-    "File name" : "檔案名稱",
+    "Filename" : "檔案名稱",
     "Folder name" : "資料夾名稱",
     "This node is unavailable" : "此節點不可用",
-    "Download file {name}" : "下載檔案 {name}",
-    "Invalid file name" : "檔案名稱無效",
-    "\"{name}\" is not an allowed filetype." : "「{name}」是不允許的檔案類型。",
-    "{newName} already exists." : "{newName} 已經存在。",
-    "\"{char}\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"{char}\"。",
-    "Name cannot be empty" : "名稱不能空白",
-    "Another entry with the same name already exists" : "另一個同名的條目已經存在",
+    "Another entry with the same name already exists." : "另一個同名的條目已經存在。",
+    "Invalid filename." : "檔案名稱無效。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{newName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
     "Could not rename \"{oldName}\"" : "無法重新命名「{oldName}」",
+    "Clear filter" : "清空過濾器",
+    "Type" : "類型",
+    "Active filters" : "有效的過濾器",
+    "Remove filter" : "移除過濾",
     "Total rows summary" : "總列摘要",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選擇",
+    "(selected)" : "（已選擇）",
     "\"{displayName}\" failed on some elements " : "“{displayName}” 在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
     "{count} selected" : "已選擇 {count} 項",
@@ -203,13 +215,17 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "具有按鈕的縱列標題可排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
-    "Storage informations" : "儲存資訊",
+    "Storage information" : "儲存資訊",
+    "Storage quota" : "儲存配額",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
     "{relative}% used" : "已使用 {relative}%",
     "Could not refresh storage stats" : "無法更新儲存統計數據",
     "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
     "Create" : "創建",
-    "A file or folder with that name already exists." : "已存在同名的檔案或資料夾°。",
+    "This name is already in use." : "這個用戶名稱已經有人使用了。",
+    "Fill template fields" : "填寫模板欄位",
+    "Submitting fields…" : "正在遞交欄位 …",
+    "Submit" : "遞交",
     "Transfer ownership of a file or folder" : "轉移檔案或資料夾的擁有權",
     "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Change" : "更改",
@@ -234,10 +250,12 @@ OC.L10N.register(
     "Shared" : "已分享",
     "Switch to list view" : "切換到列表檢視",
     "Switch to grid view" : "切換到網格檢視",
+    "Upload was cancelled by user" : "用戶已取消上傳",
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
-    "Open the files app settings" : "開啟 Files 應用程式設定",
+    "Filter filenames…" : "過濾檔案名 ...",
+    "Views" : "視圖",
     "Files settings" : "檔案設定",
     "File cannot be accessed" : "檔案無法存取",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
@@ -248,6 +266,7 @@ OC.L10N.register(
     "Show hidden files" : "顯示隱藏檔",
     "Crop image previews" : "圖片裁剪預覽",
     "Enable the grid view" : "啟用網格檢視",
+    "Enable folder tree" : "啟用資料夾樹狀結構",
     "Additional settings" : "其他設定",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -263,16 +282,21 @@ OC.L10N.register(
     "Creating file" : "創建檔案中",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從模板創建新檔案",
+    "Deletion cancelled" : "刪除已取消",
     "Delete permanently" : "永久刪除",
     "Delete and unshare" : "刪除並取消分享",
     "Leave these shares" : "保留這些分享",
     "Disconnect storages" : "解除連結儲存空間",
     "Delete files" : "刪除檔案",
     "Delete folders" : "刪除資料夾",
-    "You are about to delete {count} items." : "您即將刪除 {count} 項。",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您即將永久刪除 {count} 個項目"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您即將刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
     "Cancel" : "取消",
-    "Deletion cancelled" : "刪除已取消",
+    "Edit file locally" : "在近端編輯檔案",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "該檔案現在應該在近端打開。如果檔案無法在近端打開，請確保您的系統上安裝了桌面客戶端。",
+    "Retry local edit" : "重試近端編輯",
+    "Edit online" : "在線編輯",
     "Destination is not a folder" : "目標地不是資料夾",
     "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
@@ -285,15 +309,29 @@ OC.L10N.register(
     "Choose destination" : "選擇目標地",
     "Copy to {target}" : "複製到 {target}",
     "Move to {target}" : "移動到 {target}",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Move or copy operation failed" : "移動或複製操作失敗",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Open folder {displayName}" : "打開資料夾 {displayName}",
     "Open in Files" : "在「檔案」應用程式中打開",
     "Open details" : "開啟細節",
+    "Today" : "今日",
+    "Last 7 days" : "過去7日",
+    "Last 30 days" : "過去30日",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Documents" : "文件",
+    "Spreadsheets" : "試算表",
+    "Presentations" : "簡報",
+    "PDFs" : "PDF",
+    "Folders" : "資料夾",
+    "Audio" : "音頻",
+    "Photos and images" : "照片與圖像",
+    "Videos" : "影片",
+    "New folder creation cancelled" : "已取消建立新資料夾",
     "Created new folder \"{name}\"" : "創建了新資料夾 \"{name}\"",
-    "Filename" : "檔案名稱",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
-    "Create new templates folder" : "創建新範本資料夾",
+    "Create templates folder" : "創建模板資料夾",
     "Templates" : "模板",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
@@ -316,11 +354,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "Filename must not be empty." : "檔案名稱不能為空。",
+    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
+    "\"{extension}\" is not an allowed filetype." : "「{extension}」是不允許的檔案類型。",
+    "Filenames must not end with \"{extension}\"." : "檔案名稱不能以「{extension}」結尾。",
     "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
     "No favorites yet" : "尚無最愛",
     "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
     "All files" : "所有檔案",
     "List of your files and folders." : "您的檔案與資料夾清單。",
+    "All folders" : "所有資料夾",
     "Personal Files" : "個人檔案",
     "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
     "No personal files found" : "找不到個人檔案",
@@ -336,29 +380,19 @@ OC.L10N.register(
     "New text file.txt" : "新文字檔.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的用戶）",
     "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（只對能存取的用戶有用）",
-    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
-    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
     "\"remote user\"" : "「遠端用戶」",
-    "Select the row for {displayName}" : "選擇 {displayName} 的行",
-    "Open folder {name}" : "打開資料夾 {name}",
-    "Unselect all" : "取消全選",
-    "ascending" : "升",
-    "descending" : "降",
-    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序清單",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
-    "Search for an account" : "搜尋賬號",
-    "Choose" : "選擇",
-    "No files or folders have been deleted yet" : "尚未刪除任何檔案或資料夾",
+    "{newName} already exists." : "{newName} 已經存在。",
+    "\"{segment}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{segment}」",
+    "\"{segment}\" is a forbidden file or folder name." : "「{segment}」是禁止使用的檔案或資料夾名稱。",
+    "\"{segment}\" is not an allowed filetype." : "「{segment}」是不允許的檔案類型。",
+    "Filenames must not end with \"{segment}\"." : "檔案名稱不能以「{extension}」結尾。",
+    "Name cannot be empty" : "名稱不能空白",
+    "Another entry with the same name already exists" : "另一個同名的條目已經存在",
+    "Storage informations" : "儲存資訊",
+    "Open the files app settings" : "開啟 Files 應用程式設定",
     "You might not have have permissions to view it, ask the sender to share it" : "您可能沒有權限檢視它，請要求寄件者分享它",
-    "Set up templates folder" : "設定範本資料夾",
-    "Toggle %1$s sublist" : "切換 %1$s 子列表",
-    "Toggle grid view" : "切換網格檢視",
-    "Shares" : "分享",
-    "Shared with others" : "與其他人分享",
-    "Shared with you" : "與您分享",
-    "Deleted shares" : "已刪除的分享",
-    "Pending shares" : "等待分享",
-    "The files is locked" : "檔案已被上鎖"
+    "The files is locked" : "檔案已被上鎖",
+    "Create new templates folder" : "創建新範本資料夾",
+    "Toggle %1$s sublist" : "切換 %1$s 子列表"
 },
 "nplurals=1; plural=0;");
