@@ -126,8 +126,6 @@ OC.L10N.register(
     "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" a la taula \"%s\".",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Falten algunes columnes opcionals en la base de dades. Com que afegir columnes a taules grans pot tardar una estona i són opcionals, no s'han afegit automàticament. Podeu executar «occ db:add-missing-columns» per a afegir les columnes que falten manualment amb la instància en funcionament. Després d'afegir les columnes, és possible que millori el temps de resposta o la usabilitat d'algunes característiques.",
     "Database missing indices" : "Falten índexs a la base de dades",
-    "Missing optional index \"%s\" in table \"%s\"." : "Falta l'índex opcional \"%s\" a la taula \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Falten alguns índexs en la base de dades. Com que afegir índexs a taules grans pot tardar una estona, no s'han afegit automàticament. Si executeu «occ db:add-missing-indices», els índexs que falten es podran afegir manualment amb la instància en funcionament. Un cop afegits els índexs, les consultes en les taules solen ser molt més ràpides.",
     "Database missing primary keys" : "Falten les claus primàries a la base de dades",
     "Missing primary key on table \"%s\"." : "Falta la clau primària a la taula \"%s\".",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Falten algunes claus principals en la base de dades. Com que afegir les claus principals a taules grans pot tardar una estona, no s'han afegit automàticament. Podeu executar «occ db:add-missing-primary-keys» per a afegir les claus principals que falten manualment amb la instància en funcionament.",
@@ -183,9 +181,6 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "S'ha habilitat la configuració de només lectura. Això evita establir alguns paràmetres mitjançant la interfície web. A més, a cada actualització cal habilitar l'escriptura del fitxer manualment.",
     "Nextcloud configuration file is writable" : "El fitxer de configuració de Nextcloud es pot escriure",
     "Database version" : "Versió de la base de dades",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MariaDB 10.2 o superior.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MySQL 8.0 o MariaDB 10.2 o superior.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "S'utilitza la versió \"%s\" de PostgreSQL . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen PostgreSQL 9.6 o superior.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "Actualment s'utilitza SQLite com a base de dades de fons. Per a instal·lacions més grans, recomanem que canvieu a un backend de base de dades diferent. Això es recomana especialment quan s'utilitza el client d'escriptori per a la sincronització de fitxers. Per migrar a una altra base de dades, utilitzeu l'eina de línia d'ordres: \"occ db:convert-type\".",
     "Unknown database platform" : "Plataforma de base de dades desconeguda",
     "Architecture" : "Arquitectura",
@@ -197,18 +192,14 @@ OC.L10N.register(
     "Profile information" : "Informació del perfil",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Imatge del perfil, nom complet, correu electrònic, número de telèfon, adreça, lloc web, Twitter, organització, rol, titular, biografia i si el vostre perfil està habilitat",
     "Nextcloud settings" : "Paràmetres del Nextcloud",
+    "Task:" : "Tasca:",
     "Machine translation" : "Traducció automàtica",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traducció automàtica es pot implementar mitjançant diferents aplicacions. Aquí podeu definir la precedència de les aplicacions de traducció automàtica que heu instal·lat en aquest moment.",
-    "Speech-To-Text" : "Conversió de parla a text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "La conversió de parla a text es pot implementar per diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funció de conversió de parla a text",
     "Image generation" : "Generació d'imatges",
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "La generació d'imatges es pot implementar mitjançant diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar.",
     "None of your currently installed apps provide image generation functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funcionalitat de generació d'imatges",
     "Text processing" : "Processament de text",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Les tasques de processament de text es poden implementar mitjançant diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar per a quina tasca.",
-    "Task:" : "Tasca:",
-    "None of your currently installed apps provide Text processing functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funcionalitat de processament de text",
     "Here you can decide which group can access certain sections of the administration settings." : "Aquí podeu decidir quin grup pot accedir a certes seccions dels paràmetres d'administració.",
     "None" : "Cap",
     "Unable to modify setting" : "No es pot modificar el paràmetre",
@@ -234,10 +225,7 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Estableix la data de caducitat per defecte per a les comparticions mitjançant enllaç o correu",
     "Default expiration time of shares in days" : "Temps de caducitat per defecte de les comparticions en dies",
     "Privacy settings for sharing" : "Paràmetres de privadesa per compartir",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Permet l'emplenament automàtic del nom d'usuari al diàleg de compartició i permet l'accés a la llibreta d'adreces del sistema",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si la compleció automàtica \"mateix grup\" i \"integració de números de telèfon\" estan habilitats, n'hi ha prou amb una coincidència per mostrar a l'usuari.",
-    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Permet la compleció automàtica del nom d'usuari als usuaris dels mateixos grups i limita les llibretes d'adreces del sistema als usuaris dels mateixos grups",
-    "Allow username autocompletion to users based on phone number integration" : "Permet la compleció automàtica del nom d'usuari als usuaris en funció de la integració del número de telèfon",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permet l'emplenament automàtic en introduir el nom complet o l'adreça de correu electrònic (ignorant la coincidència de l'agenda i estar al mateix grup)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra el text de descàrrega de responsabilitat a la pàgina de l'enllaç públic de pujada (només es mostra quan la llista de fitxers està oculta).",
     "Disclaimer text" : "Text d'exempció de responsabilitat",
@@ -438,42 +426,27 @@ OC.L10N.register(
     "Common languages" : "Llengües freqüents",
     "Other languages" : "Altres llengües",
     "Password change is disabled because the master key is disabled" : "El canvi de contrasenya està inhabilitat perquè la clau mestra està desactivada",
-    "New user" : "Nou usuari",
+    "New account" : "Nou compte",
     "Display name" : "Nom per mostrar",
     "Either password or email is required" : "Es requereix una contrasenya o un correu electrònic",
     "Password (required)" : "Contrasenya (obligatori)",
     "Email (required)" : "Correu electrònic (obligatori)",
     "Email" : "Correu electrònic",
-    "Groups (required)" : "Grups (obligatori)",
-    "Set user groups" : "Establir grups d'usuaris",
-    "Administered groups" : "Grups administrats",
-    "Set user as admin for …" : "Estableix l'usuari com a administrador de …",
     "Quota" : "Quota",
-    "Set user quota" : "Estableix la quota d'usuari",
     "Language" : "Llengua",
     "Set default language" : "Estableix la llengua predeterminada",
     "Manager" : "Gestor",
-    "Add new user" : "Afegeix un usuari nou",
-    "Set user manager" : "Estableix el gestor d'usuaris",
-    "Username will be autogenerated" : "El nom d'usuari es generarà automàticament",
-    "Username (required)" : "Nom d'usuari (obligatori)",
     "Total rows summary" : "Resum de totes les files",
-    "Loading users …" : "S'estan carregant usuaris …",
     "Scroll to load more rows" : "Desplaceu-vos per carregar més files",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuari …","{userCount} usuaris …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} usuari","{userCount} usuaris"],
     "Avatar" : "Avatar",
-    "Username" : "Nom d'usuari",
     "Group admin for" : "Administrador de grup per",
-    "User backend" : "Rerefons d'usuari",
     "Storage location" : "Ubicació de l'emmagatzematge",
     "Last login" : "Darrer inici de sessió",
-    "User actions" : "Accions de l'usuari",
+    "Account actions" : "Accions del compte",
     "Password or insufficient permissions message" : "Contrasenya o missatge de permisos insuficients",
     "Change display name" : "Canvia el nom de visualització",
     "Set new password" : "Estableix una contrasenya nova",
     "Set new email address" : "Estableix una nova adreça de correu electrònic",
-    "Add user to group" : "Afegeix l'usuari al grup",
     "Set the language" : "Estableix la llengua",
     "{size} used" : "{size} en ús",
     "Delete account" : "Suprimeix el compte",
@@ -514,7 +487,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Com a administrador, podeu afinar els ajustaments per compartir fitxers. Si us plau, per més informació llegiu la documentació.",
     "You need to enable the File sharing App." : "Heu d'habilitar l'aplicació per compartir Fitxers.",
     "Admins" : "Administradors",
-    "New account" : "Nou compte",
     "Create group" : "Crear grup",
     "Group name" : "Nom del grup",
     "Please enter a valid group name" : "Introduïu un nom de grup vàlid",
@@ -560,6 +532,7 @@ OC.L10N.register(
     "Error while updating device token name" : "S'ha produït un error mentre s'actualitzava el nom del testimoni del dispositiu",
     "Error while updating device token scope" : "S'ha produït un error mentre s'actualitzava l’abast de testimonis del dispositiu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hi havia massa sol·licituds de la seva xarxa. Reintentar més tard o contactar amb l'administrador si això és un error.",
+    "Error" : "Error",
     "Account documentation" : "Documentació del compte",
     "Administration documentation" : "Documentació administrativa",
     "Forum" : "Fòrum",
@@ -602,112 +575,79 @@ OC.L10N.register(
     "No user supplied" : "No heu proporcionat cap usuari",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
     "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instal·lació i actualització d'aplicacions a través del magatzem d'aplicacions o el Núvol Federat",
-    "Federated Cloud Sharing" : "Compartició de Núvols Federats",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL està fent servir una versió %1$s antiquada (%2$s). Si us plau, actualitzeu el vostre sistema operatiu o característiques com %3$s no funcionaran amb fiabilitat.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "No s'ha pogut determinar si la versió TLS de cURL està obsoleta o no perquè s'ha produït un error durant la sol·licitud HTTPS contra https://nextcloud.com. Comproveu el fitxer de registre de Nextcloud per obtenir més detalls.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache està inhabilitat. Per a un millor rendiment, es recomana aplicar <code>opcache.enable=1</code> a la configuració de PHP.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache està configurat per suprimir comentaris de codi. Amb OPcache habilitat, s'ha d'establir <code>opcache.save.comments=1</code> perquè Nextcloud funcioni.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no té permís per utilitzar l'API OPcache. Amb OPcache habilitat, us recomanem que inclogueu tots els directoris Nextcloud amb <code>opcache.restrict.api</code> o que desconfigureu aquest paràmetre per inhabilitar les restriccions de l'API OPcache i evitar errors durant les actualitzacions del nucli de Nextcloud o de l'aplicació.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no té permís per utilitzar l'API OPcache. Us recomanem que inclogueu tots els directoris Nextcloud amb <code>1opcache.restrict.api1</code> o que desconfigureu aquest paràmetre per inhabilitar les restriccions de l'API OPcache i evitar errors durant les actualitzacions del nucli de Nextcloud o de l'aplicació.",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "L'OPcache basat en memòria compartida està desactivada. Per obtenir un millor rendiment, es recomana aplicar <code>opcache.file_cache_only=0</code> a la configuració de PHP i utilitzar la memòria cau de fitxers només com a memòria cau de segon nivell.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Gairebé s'ha excedit el nombre màxim de claus d'OPcache. Per assegurar-vos que tots els scripts es puguin mantenir a la memòria cau, us recomanem que s'apliqui <code>opcache.max.accelerated.files</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria intermèdia d'OPcache està gairebé plena. Per garantir que tots els scripts es puguin mantenir a la memòria cau, us recomanem que s'apliqui <code>opcache.memory.consumption</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria cau de cadenes internades OPcache està gairebé plena. Per assegurar-vos que les cadenes que es repeteixen es poden emmagatzemar a la memòria cau de manera efectiva, es recomana que s'apliqui <code>opcache.interned.strings.buffer</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Heu d'establir el correu electrònic d'usuari abans de poder enviar correus de prova. Aneu a %s per fer-ho.",
     "Invalid user" : "Usuari no vàlid",
     "Your username is: %s" : "El vostre nom d'usuari és: %s",
     "Logged in user must be a subadmin" : "L’usuari que ha iniciat la sessió ha de ser un subadministrador",
+    "Old user imported certificates" : "Certificats importats d'usuari antic",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Hi ha un treball en segon pla pendent que de comprovar els certificats SSL importats per l'usuari. Comproveu-ho més tard.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hi ha alguns certificats SSL importats per l'usuari que ja no s'utilitzen amb Nextcloud 21. Es poden importar en la línia d'ordres a través de l'ordre «occ security:certificates:import». A continuació se'n mostren els camins dins del directori de dades.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "S'han trobat UUID no vàlids d'usuaris o grups LDAP. Reviseu els paràmetres de l'\"Anul·lació de detecció d'UUID\" a la part Experta de la configuració LDAP i utilitzeu \"occ ldap:update-uuid\" per actualitzar-los.",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "La sincronització de la llibreta d'adreces del sistema DAV encara no s'ha executat perquè la vostra instància té més de 1000 usuaris o perquè s'ha produït un error. Si us plau, executeu-lo manualment cridant a occ dav:sync-system-addressbook.",
+    "Missing optional index \"%s\" in table \"%s\"." : "Falta l'índex opcional \"%s\" a la taula \"%s\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Falten alguns índexs en la base de dades. Com que afegir índexs a taules grans pot tardar una estona, no s'han afegit automàticament. Si executeu «occ db:add-missing-indices», els índexs que falten es podran afegir manualment amb la instància en funcionament. Un cop afegits els índexs, les consultes en les taules solen ser molt més ràpides.",
+    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Actualment esteu executant PHP %s. PHP 8.0 ara està obsolet a Nextcloud 27. Nextcloud 28 pot requerir almenys PHP 8.1. Si us plau, actualitzeu a una de les versions de PHP amb suport oficial proporcionades pel Grup PHP tan aviat com sigui possible.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MariaDB 10.2 o superior.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MySQL 8.0 o MariaDB 10.2 o superior.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "S'utilitza la versió \"%s\" de PostgreSQL . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen PostgreSQL 9.6 o superior.",
+    "Speech-To-Text" : "Conversió de parla a text",
+    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "La conversió de parla a text es pot implementar per diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar.",
+    "None of your currently installed apps provide Speech-To-Text functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funció de conversió de parla a text",
+    "None of your currently installed apps provide Text processing functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funcionalitat de processament de text",
+    "Exclude groups from sharing" : "Excloure grups de compartició",
+    "These groups will still be able to receive shares, but not to initiate them." : "Aquests grups encara podran rebre comparticions, però no en podran iniciar.",
+    "Allow username autocompletion in share dialog and allow access to the system address book" : "Permet l'emplenament automàtic del nom d'usuari al diàleg de compartició i permet l'accés a la llibreta d'adreces del sistema",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L’autenticació de doble factor pot ser forçada per a tots els usuaris i grups específics. Si no tenen un proveïdor de doble factor configurat, no podran accedir en el sistema.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està habilitat per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
-    "Enable all" : "Habilita tot",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Client de sincronització - {os}",
-    "Error while deleting the token" : "S'ha produït un error mentre se suprimia el testimoni",
-    "Use the credentials below to configure your app or device." : "Utilitzeu les credencials de sota per configurar la vostra aplicació o dispositiu.",
-    "For security reasons this password will only be shown once." : "Per raons de seguretat aquesta contrasenya només es mostrarà una vegada.",
-    "Copied!" : "S'ha copiat!",
-    "Copy" : "Copia",
+    "{license}-licensed" : "sota la llicència - {license}",
+    "Rating: {score}/10" : "Valoració: {score}/10",
+    "Username" : "Nom d'usuari",
     "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per cridar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Per executar això es necessita l'extensió POSIX de PHP. Per més detalls, vegeu {linkstart}documentació de PHP{linkend}.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utilitzeu el servei cron del sistema per a cridar el fitxer cron.php cada 5 minuts. Recomanat per a totes les instàncies.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
     "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil per defecte per als usuaris nous.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Esteu a punt de suprimir el grup {group}. Els usuaris NO seran suprimits.",
-    "Please confirm the group removal " : "Confirmeu la supressió del grup ",
-    "Your profile information" : "La vostra informació de perfil",
-    "Your email address" : "El vostre correu electrònic",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Esteu a punt de suprimir el grup \"{group}\". Els usuaris NO s'eliminaran.",
     "Additional emails" : "Adreces de correu electrònic addicionals",
     "Enable Profile" : "Habilita el perfil",
-    "Your Twitter handle" : "El teu identificador de Twitter",
+    "No users" : "Cap usuari",
+    "Loading users …" : "S'estan carregant usuaris …",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Llista d'usuaris. Aquesta llista no es presenta completament per motius de rendiment. Els usuaris es mostraran mentre navegueu per la llista.",
+    "New user" : "Nou usuari",
+    "Groups (required)" : "Grups (obligatori)",
+    "Set user groups" : "Establir grups d'usuaris",
+    "Administered groups" : "Grups administrats",
+    "Set user as admin for …" : "Estableix l'usuari com a administrador de …",
+    "Set user quota" : "Estableix la quota d'usuari",
+    "Add new user" : "Afegeix un usuari nou",
+    "Set user manager" : "Estableix el gestor d'usuaris",
+    "Username will be autogenerated" : "El nom d'usuari es generarà automàticament",
+    "Username (required)" : "Nom d'usuari (obligatori)",
+    "User backend" : "Rerefons d'usuari",
+    "User actions" : "Accions de l'usuari",
+    "Loading user …" : "S'està carregant l'usuari …",
     "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
-    "Edit display name" : "Edició del nom a mostrar",
-    "Add new password" : "Afegeix una nova contrasenya",
-    "Add new email address" : "Afegeix una nova adreça de correu electrònic",
+    "Add user to group" : "Afegeix l'usuari al grup",
     "Set user as admin for" : "Posa l'usuari com a administrador per",
     "Select user quota" : "Selecciona la quota d'usuari",
-    "Select manager" : "Seleccioneu el gestor",
-    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
     "Delete user" : "Suprimeix l'usuari",
     "Wipe all devices" : "Esborra tots els dispositius",
     "Disable user" : "Inhabilita l'usuari",
     "Enable user" : "Habilita l'usuari",
-    "Edit User" : "Edita Usuari",
-    "User's table" : "Taula d'usuaris",
-    "Will be autogenerated" : "Serà auto-generat",
-    "Select user manager" : "Seleccioneu el gestor d'usuaris",
-    "Add a new user" : "Afegeix un nou usuari",
-    "No users in here" : "No hi ha usuaris aquí dins",
+    "Failed to update user manager" : "No s'ha pogut actualitzar el gestor d'usuaris",
+    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
+    "User management settings" : "Paràmetres de gestió d'usuaris",
+    "Show user backend" : "Mostra el rerefons d'usuari",
+    "Send welcome email to new users" : "Envieu un correu electrònic de benvinguda als nous usuaris",
     "Name your device" : "Anomeneu el vostre dispositiu",
     "Server error while trying to add WebAuthn device" : "Error del servidor mentre s'intentava afegir un dispositiu WebAuthn",
-    "{license}-licensed" : "sota la llicència - {license}",
     "by {author}\n{license}" : "{author}\n{license}",
-    "Enter group name" : "Introduïu el nom del grup",
-    "Add group" : "Afegeix un grup",
+    "User management" : "Gestió d'usuaris",
     "Active users" : "Usuaris actius",
     "Disabled users" : "Usuaris inhabilitats",
-    "Default quota:" : "Quota per defecte:",
-    "Show Languages" : "Mostra els idiomes",
-    "Show user backend" : "Mostra el rerefons d'usuari",
-    "Send email to new user" : "Enviar correu electrònic al nou usuari",
-    "Not saved" : "No s'ha desat",
-    "Twitter" : "Twitter",
+    "Creating group …" : "S'està creant un grup …",
+    "User group: {group}" : "Grup d'usuaris: {group}",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No està disponible perquè la federació s'ha inhabilitat per al vostre compte, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No està disponible perquè no es permet la publicació de dades específiques de l'usuari al servidor de cerca, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
     "Show to logged in users only" : "Mostra només als usuaris connectats",
-    "Enable untested app" : "Habilita aplicacions no provades",
-    "SMTP Username" : "Nom d'usuari SMTP",
-    "Expire after" : "Caduca després",
-    "day(s)" : "dies",
-    "Exclude groups from password requirements:" : "Excloure grups dels requisits de contrasenya:",
-    "Set default expiration date" : "Estableix la data de caducitat per defecte",
-    "Exclude groups from creating link shares:" : "Excloure grups de la creació d'enllaços compartits:",
-    "Exclude groups from sharing" : "Excloure grups de compartició",
-    "These groups will still be able to receive shares, but not to initiate them." : "Aquests grups encara podran rebre comparticions, però no en podran iniciar.",
-    "Old user imported certificates" : "Certificats importats d'usuari antic",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Actualment esteu executant PHP %s. PHP 8.0 ara està obsolet a Nextcloud 27. Nextcloud 28 pot requerir almenys PHP 8.1. Si us plau, actualitzeu a una de les versions de PHP amb suport oficial proporcionades pel Grup PHP tan aviat com sigui possible.",
-    "Rating: {score}/10" : "Valoració: {score}/10",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Esteu a punt de suprimir el grup \"{group}\". Els usuaris NO s'eliminaran.",
-    "No users" : "Cap usuari",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Llista d'usuaris. Aquesta llista no es presenta completament per motius de rendiment. Els usuaris es mostraran mentre navegueu per la llista.",
-    "Loading user …" : "S'està carregant l'usuari …",
-    "Failed to update user manager" : "No s'ha pogut actualitzar el gestor d'usuaris",
-    "User management settings" : "Paràmetres de gestió d'usuaris",
-    "Send welcome email to new users" : "Envieu un correu electrònic de benvinguda als nous usuaris",
-    "User management" : "Gestió d'usuaris",
-    "Creating group …" : "S'està creant un grup …",
-    "User group: {group}" : "Grup d'usuaris: {group}",
-    "Nextcloud help resources" : "Recursos d'ajuda de Nextcloud"
+    "Nextcloud help resources" : "Recursos d'ajuda de Nextcloud",
+    "SMTP Username" : "Nom d'usuari SMTP"
 },
 "nplurals=2; plural=(n != 1);");
