@@ -168,11 +168,10 @@ OC.L10N.register(
     "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
-    "Username" : "Usuario",
     "Group admin for" : "Administrador del grupo para",
-    "User backend" : "Backend del usuario",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
+    "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
     "Done" : "Terminado",
     "Edit" : "Editar",
@@ -223,33 +222,14 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
     "No user supplied" : "No se proporcionó usuario alguno",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
     "Invalid user" : "Usuario inválido",
     "Your username is: %s" : "Tu Usuario es: %s",
-    "Enable all" : "Habilitar todo",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Sync client - {os}" : "Sync client - {os}",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Copied!" : "¡Copiado!",
-    "Copy" : "Copiar",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
-    "Your email address" : "Tu dirección de correo electrónico",
-    "Your Twitter handle" : "Tu cuenta de Twitter",
-    "Add group" : "Agregar grupo",
-    "Active users" : "Usuarios activos",
-    "Show user backend" : "Mostrar backend del usuario",
-    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Not saved" : "No guardado",
-    "Twitter" : "Twitter",
-    "SMTP Username" : "Usuario SMTP",
-    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
     "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar."
+    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
+    "Username" : "Usuario",
+    "User backend" : "Backend del usuario",
+    "Show user backend" : "Mostrar backend del usuario",
+    "Active users" : "Usuarios activos",
+    "SMTP Username" : "Usuario SMTP"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
