@@ -110,7 +110,6 @@ OC.L10N.register(
     "Unlimited" : "Neograničeno",
     "Verifying" : "Provjeravanje",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "U bazi podataka nedostaju određeni neobavezni stupci. Zbog činjenice da bi dodavanje stupaca u velikim tablicama moglo potrajati neko duže vrijeme, stupci se ne dodaju automatski, već je njihovo dodavanje neobavezno. Izvršenjem „occ db:add-missing-columns” ti se stupci mogu ručno dodati dok instanca radi. Nakon dodavanja stupaca može se poboljšati odaziv ili uporabljivost određenih značajki.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "U bazi podataka nedostaju određeni primarni ključevi. Zbog činjenice da bi dodavanje primarnih ključeva moglo potrajati neko duže vrijeme u velikim tablicama, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-primary-keys” ti se primarni ključevi mogu ručno dodati dok instanca radi.",
     "Disabled" : "Onemogućeno",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Omogućen je stari format šifriranja na strani poslužitelja. Preporučujemo da ga onemogućite.",
@@ -136,7 +135,6 @@ OC.L10N.register(
     "Enforce expiration date" : "Primijeni datum isteka",
     "Set default expiration date for shares to other servers" : "Postavi zadani datum isteka dijeljenja na druge poslužitelje",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
-    "Allow username autocompletion to users based on phone number integration" : "Omogući korisnicima automatsko dovršavanje korisničkog imena na temelju integracije telefonskog broja",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Ovaj će tekst biti prikazan na stranici za otpremanje javnih poveznica kad je popis datoteka skriven.",
     "Default share permissions" : "Zadana dopuštenja za dijeljenje",
@@ -268,18 +266,16 @@ OC.L10N.register(
     "Common languages" : "Česti jezici",
     "Other languages" : "Drugi jezici",
     "Password change is disabled because the master key is disabled" : "Onemogućeno je mijenjanje zaporke jer je onemogućen glavni ključ",
-    "New user" : "Novi korisnik",
+    "New account" : "Novi račun",
     "Display name" : "Ime za prikaz",
     "Email" : "E-pošta",
     "Quota" : "Kvota",
     "Language" : "Jezik",
     "Avatar" : "Avatar",
-    "Username" : "Korisničko ime",
     "Group admin for" : "Administrator grupe za",
-    "User backend" : "Korisnički pozadinski sustav",
     "Storage location" : "Mjesto pohrane",
     "Last login" : "Posljednja prijava",
-    "Add user to group" : "Dodaj korisnika u grupu",
+    "Account actions" : "Radnje računa",
     "{size} used" : "Iskorišteno {size}",
     "Delete account" : "Izbriši račun",
     "Resend welcome email" : "Ponovno pošalji poruku dobrodošlice",
@@ -312,7 +308,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
     "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
     "Admins" : "Administratori",
-    "New account" : "Novi račun",
     "Group name" : "Naziv grupe",
     "Sending…" : "Slanje…",
     "Email sent" : "E-pošta je poslana",
@@ -349,6 +344,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Pogreška pri ažuriranju naziva tokena za uređaja",
     "Error while updating device token scope" : "Pogreška pri ažuriranju raspona tokena za uređaj",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
+    "Error" : "Pogreška",
     "Forum" : "Forum",
     "Legal notice" : "Pravna obavijest",
     "Privacy policy" : "Pravila o privatnosti",
@@ -385,73 +381,39 @@ OC.L10N.register(
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
     "No user supplied" : "Nijedan korisnik nije podnesen",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Unesite administratorsku zaporku za oporavak; u protivnom će svi podaci korisnika biti izgubljeni.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instaliranje i ažuriranje aplikacija putem trgovine aplikacijama ili dijeljenja putem udruženog oblaka",
-    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL upotrebljava zastarjelu inačicu %1$s (%2$s). Ažurirajte svoj operacijski sustav kako bi značajke, kao što je %3$s, pouzdano radile.",
     "Invalid user" : "Nevažeći korisnik",
     "Your username is: %s" : "Vaše korisničko ime je: %s",
     "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
+    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
+    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvofaktorska autentifikacija može se primijeniti na sve korisnike i određene grupe. Ako nisu konfigurirali davatelje usluge dvofaktorske autentifikacije, neće se moći prijaviti u sustav.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Nakon odabira grupa koje će biti obuhvaćene/izuzete, primjenjuje se sljedeća logika za utvrđivanje je li 2FA omogućen za određenog korisnika: ako nije odabrana nijedna grupa, 2FA je omogućen za sve osim za članove izuzetih grupa. Ako su odabrane određene grupe, 2FA je omogućen samo za sve članove tih grupa. Ako je korisnik član odabrane i izuzete grupe, odabrana grupa ima prednost i 2FA se primjenjuje.",
-    "Enable all" : "Omogući sve",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sinkroniziraj klijenta – {os}",
-    "Error while deleting the token" : "Pogreška pri brisanju tokena",
-    "Use the credentials below to configure your app or device." : "Upotrijebite vjerodajnice navedene u nastavku za konfiguriranje aplikacije ili uređaja.",
-    "For security reasons this password will only be shown once." : "Iz sigurnosnih razloga ta će se zaporka prikazati samo jednom.",
-    "Copied!" : "Kopirano!",
-    "Copy" : "Kopiraj",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za izvršavanje navedenog postupka potrebno je proširenje PHP POSIX. Pogledajte {linkstart}dokumentaciju PHP-a{linkend} za više informacija.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
-    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
-    "Your email address" : "Vaša adresa e-pošte",
+    "{license}-licensed" : "Licencirano prema {license}",
+    "Username" : "Korisničko ime",
     "Additional emails" : "Dodatne adrese e-pošte",
     "Enable Profile" : "Omogući profil",
+    "New user" : "Novi korisnik",
+    "User backend" : "Korisnički pozadinski sustav",
     "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
-    "Add new password" : "Dodaj novu zaporku",
-    "Add new email address" : "Dodaj novu adresu e-pošte",
+    "Add user to group" : "Dodaj korisnika u grupu",
     "Set user as admin for" : "Postavi korisnika kao administratora za",
     "Select user quota" : "Odaberi kvotu korisnika",
-    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
     "Delete user" : "Izbriši korisnika",
     "Wipe all devices" : "Izbriši podatke sa svih uređaja",
     "Disable user" : "Onemogući korisnika",
     "Enable user" : "Omogući korisnika",
-    "Edit User" : "Uredi korisnika",
-    "Will be autogenerated" : "Automatski će se generirati",
-    "Add a new user" : "Dodaj novog korisnika",
-    "No users in here" : "Ovdje nema korisnika",
+    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
+    "Show user backend" : "Prikaži korisnički pozadinski sustav",
     "Name your device" : "Dodijelite naziv svom uređaju",
     "Server error while trying to add WebAuthn device" : "Pogreška poslužitelja pri dodavanju WebAuthn uređaja",
-    "{license}-licensed" : "Licencirano prema {license}",
     "by {author}\n{license}" : "{autor}\n{licenca}",
-    "Enter group name" : "Unesite naziv grupe",
-    "Add group" : "Dodaj grupu",
     "Active users" : "Aktivni korisnici",
     "Disabled users" : "Onemogućeni korisnici",
-    "Default quota:" : "Zadana kvota:",
-    "Show Languages" : "Prikaži jezike",
-    "Show user backend" : "Prikaži korisnički pozadinski sustav",
-    "Send email to new user" : "Pošalji poruku e-pošte novom korisniku",
-    "Not saved" : "Nije spremljeno",
-    "Twitter" : "Twitter",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
     "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
-    "Enable untested app" : "Omogući neprovjerenu aplikaciju",
-    "SMTP Username" : "Korisničko ime za SMTP",
-    "Expire after" : "Istek nakon",
-    "day(s)" : "dan/dana",
-    "Set default expiration date" : "Postavi zadani datum isteka",
-    "Exclude groups from creating link shares:" : "Izuzmite grupe iz stvaranja dijeljenja poveznice:",
-    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
-    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti."
+    "SMTP Username" : "Korisničko ime za SMTP"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
