@@ -120,8 +120,6 @@ OC.L10N.register(
     "Database missing columns" : "Gagnagrunn vantar dálka",
     "Missing optional column \"%s\" in table \"%s\"." : "Vantar valkvæða dálkinn \"%s\" í töflunni \"%s\".",
     "Database missing indices" : "Gagnagrunn vantar vísa",
-    "Missing optional index \"%s\" in table \"%s\"." : "Vantar valkvæða vísinn \"s\" í töflunni \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
     "Database missing primary keys" : "Gagnagrunn vantar aðallykla",
     "Missing primary key on table \"%s\"." : "Vantar aðallykilinn í töflunni \"%s\".",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Gagnagrunninn vantar nokkra aðallykla (primary keys). Vegna þess að það að bæta aðallyklum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-primary-keys\" væri hægt að bæta inn þessum aðallyklum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum aðallyklum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
@@ -171,11 +169,10 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
     "Profile information" : "Persónuupplýsingar",
     "Nextcloud settings" : "Stillingar Nextcloud",
+    "Task:" : "Verk:",
     "Machine translation" : "Vélræn þýðing",
-    "Speech-To-Text" : "Tal-í-texta",
     "Image generation" : "Gerð mynda",
     "Text processing" : "Textavinnsla",
-    "Task:" : "Verk:",
     "None" : "Ekkert",
     "Unable to modify setting" : "Ekki gekk að breyta stillingu",
     "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
@@ -200,9 +197,6 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Setja sjálfgefinn gildistíma fyrir sameignir sem deilt er með tengli eða tölvupósti",
     "Default expiration time of shares in days" : "Sjálfgefinn gildistími fyrir sameignir í dögum",
     "Privacy settings for sharing" : "Stillingar á friðhelgi deilingar",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
-    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Leyfa sjálfklárun notandanafns á notendum innan sömu hópa og takmarka kerfisnafnaskrár við notendur innan sömu hópa",
-    "Allow username autocompletion to users based on phone number integration" : "Leyfa sjálfklárun notandanafns á notendum byggt á samþættingu símanúmera",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Birta fyrirvara á opinberu innsendingasíðunni (birtist einungis þegar listi yfir skrár er falinn)",
     "Disclaimer text" : "Texti fyrirvara",
     "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
@@ -390,42 +384,26 @@ OC.L10N.register(
     "Common languages" : "Algeng tungumál",
     "Other languages" : "Önnur tungumál",
     "Password change is disabled because the master key is disabled" : "Lykilorðabreyting er óvirk vegna þess að aðallykill er óvirkur",
-    "New user" : "Nýr notandi",
     "Display name" : "Birtingarnafn",
     "Either password or email is required" : "Annað hvort lykilorð eða tölvupóstfang eru nauðsynleg",
     "Password (required)" : "Lykilorð (nauðsynlegt)",
     "Email (required)" : "Tölvupóstfang (nauðsynlegt)",
     "Email" : "Netfang",
-    "Groups (required)" : "Hópar (nauðsynlegt)",
-    "Set user groups" : "Setja notendahópa",
-    "Administered groups" : "Stýrðir hópar",
-    "Set user as admin for …" : "Setja notanda sem stjórnanda fyrir …",
     "Quota" : "Kvóti",
-    "Set user quota" : "Settu kvóta notandans",
     "Language" : "Tungumál",
     "Set default language" : "Settu sjálfgefið tungumál",
     "Manager" : "Stjórnandi",
-    "Add new user" : "Bæta við nýjum notanda",
-    "Set user manager" : "Settu stjórnanda notenda",
-    "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
-    "Username (required)" : "Notandanafn (nauðsynlegt)",
     "Total rows summary" : "Samantek á fjölda raða",
-    "Loading users …" : "Hleð inn notendum …",
     "Scroll to load more rows" : "Skrunaðu til að hlaða inn fleiri röðum",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} notandi …","{userCount} notendur …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} notandi","{userCount} notendur"],
     "Avatar" : "Auðkennismynd",
-    "Username" : "Notandanafn",
     "Group admin for" : "Hópstjóri fyrir",
-    "User backend" : "Bakendi notanda",
     "Storage location" : "Staðsetning gagnageymslu",
     "Last login" : "Síðasta innskráning",
-    "User actions" : "Aðgerðir notanda",
+    "Account actions" : "Aðgerðir fyrir aðgang",
     "Password or insufficient permissions message" : "Skilaboð um lykilorð eða ekki nægar heimildir",
     "Change display name" : "Breyta birtingarnafni",
     "Set new password" : "Stilla nýtt lykilorð",
     "Set new email address" : "Stilla nýtt tölvupóstfang",
-    "Add user to group" : "Bæta notanda í hóp",
     "Set the language" : "Settu tungumálið",
     "{size} used" : "{size} notað",
     "Resend welcome email" : "Endursenda kveðjupóst",
@@ -509,6 +487,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Villa við að uppfæra nafn fyrir teikn tækisins",
     "Error while updating device token scope" : "Villa við að uppfæra gildissvið fyrir teikn tækisins",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
+    "Error" : "Villa",
     "Account documentation" : "Hjálparskjöl fyrir notendaaðganga",
     "Administration documentation" : "Hjálparskjöl fyrir stjórnendur",
     "Forum" : "Vefspjall",
@@ -551,99 +530,68 @@ OC.L10N.register(
     "No user supplied" : "Enginn notandi gefinn",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
     "Backend does not support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
-    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "PHP Opcache er ekki virkt. Fyrir betri afköst mælum við með að setja <code>opcache.enable=1</code> inn í PHP-uppsetninguna þína.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Þú verður að gefa upp tölvupóstfangið þitt svo að þú getir sent prófunarpósta. Farðu á %s til þess.",
     "Invalid user" : "Ógildur notandi",
     "Your username is: %s" : "Notandanafnið þitt er: %s",
     "Logged in user must be a subadmin" : "Innskráður notandi verður að vera undirstjórnandi (subadmin)",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Fann ógild UUIDs á LDAP-notendum eða hópum. Yfirfarðu stillingar í \"Override UUID detection\" í Sérfræðinga/Expert hluta LDAP-uppsetningarinnar og notaðu \"occ ldap:update-uuid\" til að uppfæra þær.",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "Samstilling á DAV-nafnaskrá kerfisins hefur ekki enn verið keyrð, þar sem tilvikið þitt er með fleiri en 1000 notendur eða að villa hefur komið upp. Heyrðu samstillinguna handvirkt með því að kalla á occ dav:sync-system-addressbook.",
+    "Old user imported certificates" : "Gömul skilríki sem notandi hefur flutt inn",
+    "Missing optional index \"%s\" in table \"%s\"." : "Vantar valkvæða vísinn \"s\" í töflunni \"%s\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
+    "Speech-To-Text" : "Tal-í-texta",
+    "Exclude groups from sharing" : "Undanskilja hópa frá því að deila",
+    "These groups will still be able to receive shares, but not to initiate them." : "Þessir hópar munu samt geta tekið við deildum sameignum, en ekki geta útbúið þær.",
+    "Allow username autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Hægt er að þvinga fram tveggja-þrepa auðkenningu fyrir alla notendur og/eða tiltekna hópa. Ef þeir eru ekki með tveggja-þrepa auðkenningarþjónustu uppsetta, munu þeir ekki geta skráð sig inn á kerfið.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandi sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenningvirk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
-    "Enable all" : "Virkja allt",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Samstilla biðlara - {os}",
-    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
-    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
-    "For security reasons this password will only be shown once." : "Af öryggisástæðum er þetta lykilorð einungis birt einu sinni.",
-    "Copied!" : "Afritað!",
-    "Copy" : "Afrita",
+    "{license}-licensed" : "{license}-notkunarleyfi",
+    "Rating: {score}/10" : "Einkunn: {score}/10",
+    "Username" : "Notandanafn",
     "Execute one task with each page loaded. Use case: Single user instance." : "Framkvæma eitt verk með hverri innhlaðinni síðu. Dæmi um notkun: Tilvik fyrir einn notanda.",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP. Dæmi um notkun: Mjög lítil tilvik (1–5 notendur eða eftir notkun).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti. Mælt með þessu á öllum tilvikum.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"{user}\".",
     "Enable or disable profile by default for new users." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendur.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn {group}. Notendunum verður EKKI eytt.",
-    "Please confirm the group removal " : "Staðfestu fjarlægingu hópsins",
-    "Your profile information" : "Persónuupplýsingar þínar",
-    "Your email address" : "Netfangið þitt",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendunum verður EKKI eytt.",
     "Additional emails" : "Viðbótartölvupóstföng",
     "Enable Profile" : "Virkja notandasnið",
-    "Your Twitter handle" : "Twitter notandanafnið þitt",
+    "No users" : "Engir notendur",
+    "Loading users …" : "Hleð inn notendum …",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Listi yfir notendur. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendur munu birtast eftir því sem farið er í gegnum listann.",
+    "New user" : "Nýr notandi",
+    "Groups (required)" : "Hópar (nauðsynlegt)",
+    "Set user groups" : "Setja notendahópa",
+    "Administered groups" : "Stýrðir hópar",
+    "Set user as admin for …" : "Setja notanda sem stjórnanda fyrir …",
+    "Set user quota" : "Settu kvóta notandans",
+    "Add new user" : "Bæta við nýjum notanda",
+    "Set user manager" : "Settu stjórnanda notenda",
+    "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
+    "Username (required)" : "Notandanafn (nauðsynlegt)",
+    "User backend" : "Bakendi notanda",
+    "User actions" : "Aðgerðir notanda",
+    "Loading user …" : "Hleð inn notanda...",
     "You do not have permissions to see the details of this user" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notanda",
-    "Edit display name" : "Breyta birtingarnafni",
-    "Add new password" : "Bæta við nýju lykilorði",
-    "Add new email address" : "Bæta við nýju tölvupóstfangi",
+    "Add user to group" : "Bæta notanda í hóp",
     "Set user as admin for" : "Setja notanda sem stjórnanda fyrir",
     "Select user quota" : "Veldu kvóta notandans",
-    "Select manager" : "Veldu stýringu",
-    "Toggle user actions menu" : "Víxla af/á valmynd fyrir aðgerðir notanda",
     "Delete user" : "Eyða notanda",
     "Wipe all devices" : "Þurrka út af öllum tækjum",
     "Disable user" : "Gera notanda óvirkan",
     "Enable user" : "Virkja notanda",
-    "Edit User" : "Breyta notanda",
-    "User's table" : "Tafla notandans",
-    "Will be autogenerated" : "Verður útbúið sjálfvirkt",
-    "Select user manager" : "Veldu notendastýringu",
-    "Add a new user" : "Bæta við nýjum notanda",
-    "No users in here" : "Engir notendur hér",
+    "Failed to update user manager" : "Mistókst að uppfæra notendastýringu",
+    "Toggle user actions menu" : "Víxla af/á valmynd fyrir aðgerðir notanda",
+    "User management settings" : "Stillingar notendastýringar",
+    "Show user backend" : "Birta bakenda notanda",
+    "Send welcome email to new users" : "Senda tölvupóst sem býður notanda velkominn",
     "Name your device" : "Gefðu tækinu þínu nafn",
     "Server error while trying to add WebAuthn device" : "Villa á þjóni við að bæta við WebAuthn-tæki",
-    "{license}-licensed" : "{license}-notkunarleyfi",
     "by {author}\n{license}" : "frá {author}\n{license}",
-    "Enter group name" : "Settu hér inn heiti á hópi",
-    "Add group" : "Bæta við hópi",
     "Active users" : "Virkir notendur",
     "Disabled users" : "Óvirkir notendur",
-    "Default quota:" : "Sjálfgefinn kvóti:",
-    "Show Languages" : "Birta tungumál",
-    "Show user backend" : "Birta bakenda notanda",
-    "Send email to new user" : "Senda tölvupóst til nýs notanda",
-    "Not saved" : "Ekki vistað",
-    "Twitter" : "Twitter",
+    "Creating group …" : "Bý til hóp …",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
     "Show to logged in users only" : "Birta einungis innskráðum notendum",
-    "Enable untested app" : "Virkja óprófað forrit",
-    "SMTP Username" : "SMTP-notandanafn",
-    "Expire after" : "Rennur út eftir",
-    "day(s)" : "dag(ar)",
-    "Exclude groups from password requirements:" : "Undanskilja hópa frá kröfum um lykilorð:",
-    "Set default expiration date" : "Setja sjálfgefinn gildistíma",
-    "Exclude groups from creating link shares:" : "Undanskilja hópa frá því að búa til sameignartengla:",
-    "Exclude groups from sharing" : "Undanskilja hópa frá því að deila",
-    "These groups will still be able to receive shares, but not to initiate them." : "Þessir hópar munu samt geta tekið við deildum sameignum, en ekki geta útbúið þær.",
-    "Old user imported certificates" : "Gömul skilríki sem notandi hefur flutt inn",
-    "Rating: {score}/10" : "Einkunn: {score}/10",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendunum verður EKKI eytt.",
-    "No users" : "Engir notendur",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Listi yfir notendur. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendur munu birtast eftir því sem farið er í gegnum listann.",
-    "Loading user …" : "Hleð inn notanda...",
-    "Failed to update user manager" : "Mistókst að uppfæra notendastýringu",
-    "User management settings" : "Stillingar notendastýringar",
-    "Send welcome email to new users" : "Senda tölvupóst sem býður notanda velkominn",
-    "Creating group …" : "Bý til hóp …",
-    "Nextcloud help resources" : "Aðstoðartilföng Nextcloud"
+    "Nextcloud help resources" : "Aðstoðartilföng Nextcloud",
+    "SMTP Username" : "SMTP-notandanafn"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
