@@ -71,6 +71,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
     "You need to set your account email before being able to send test emails. Go to %s for that." : "이메일 발송 테스트를 진행하기 앞서 계정 이메일을 설정해야 합니다. 설정을 위해 %s(으)로 가십시오.",
+    "Disabled accounts" : "비활성화된 계정",
     "Invalid account" : "잘못된 계정",
     "Invalid mail address" : "잘못된 이메일 주소",
     "Settings saved" : "설정 저장됨",
@@ -148,8 +149,6 @@ OC.L10N.register(
     "Missing optional column \"%s\" in table \"%s\"." : "표 \"%s\"의 optional column \"%s\"이(가) 사라졌습니다",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "데이터베이스에 일부 선택적 열이 누락되었습니다. 큰 테이블에 열을 추가하는 데 시간이 걸릴 수 있기 때문에 선택 사항일 수 있는 열이 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-columns\"를 실행하면 누락된 열을 인스턴스를 실행되는 동안 수동으로 추가할 수 있습니다. 열이 추가되면 일부 기능의 응답성이나 사용성이 향상될 수 있습니다.",
     "Database missing indices" : "데이터베이스의 색인이 사라졌습니다",
-    "Missing optional index \"%s\" in table \"%s\"." : "표 \"%s\"의 optional index \"%s\"이(가) 사라졌습니다",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
     "Database missing primary keys" : "데이터베이스의 기본 키가 사라졌습니다",
     "Missing primary key on table \"%s\"." : "표 \"%s\"의 기본키가 사라졌습니다",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "데이터베이스에 일부 기본 키가 누락되었습니다. 큰 테이블에 기본 키를 추가하는 데 시간이 걸릴 수 있기 때문에 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-primary-keys\"를 실행하면 인스턴스가 계속 실행되는 동안 누락된 기본 키를 수동으로 추가할 수 있습니다.",
@@ -184,8 +183,6 @@ OC.L10N.register(
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "서버 유지관리 창의 시작 시간이 설정되지 않았습니다. 많은 사용자가 접속하는 시간대에 자원 집약적인 작업이 실행될 수 있습니다. 부하가 큰 작업에 의해 사용자가 불편을 겪지 않도록, 유지관리 창의 시작 시간을 사용량이 적은 시간대로 설정하십시오.",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "유지 보수 창이 부하가 큰 백그라운드 작업을 수행하기 위해 {start}:00 UTC에서 {end}:00 UTC에 동작합니다",
     "Memcache" : "Memcache",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\"." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 \"memcache\"가 설치되어 있습니다. \\OC\\Memcache\\Memcached는 \"memcached\"만 지원하고 \"memcache\"는 지원하지 않습니다.",
-    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed." : "Memcached가 분산 캐시로 구성되어 있지만 PHP 모듈 \"memcached\"가 설치되지 않았습니다.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "메모리 캐시가 설정되지 않았습니다. 성능 향상을 위해, 가능한 경우 memcache를 설정하십시오.",
     "Configured" : "설정됨",
     "MySQL Unicode support" : "MySQL 유니코드 지원",
@@ -241,12 +238,8 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
     "Nextcloud configuration file is writable" : "Nextcloud 설정 파일이 쓰기가능한 상태입니다",
     "Database version" : "데이터베이스 버전",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "현재 MariaDB \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MariaDB 10.2 이상을 사용하십시오.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "현재 MySQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MySQL 8.0 혹은 MariaDB 10.2 이상을 사용하십시오.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "현재 PostgreSQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. PostgreSQL 9.6 이상을 사용하십시오.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite가 현재 백엔드 데이터베이스로 사용중입니다. 더 큰 규모의 인스턴스에는 다른 데이터베이스 백엔드를 사용하는 것이 좋습니다. 이는 특히 데스크탑 클라이언트를 통한 파일 동기화를 사용할 때 권장됩니다. 다른 데이터베이스로 이전할 때에는 명령행 도구 \"occ db:convert-type\"을 사용하십시오.",
     "Unknown database platform" : "알 수 없는 데이터베이스 플랫폼",
-    "Architecture" : "건축",
     "64-bit" : "64비트",
     "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "이 PHP가 32비트용인 것 같습니다. Nextcloud는 64비트 시스템에서 원활하게 동작합니다. OS와 PHP를 64비트로 업그레이드 하십시오.",
     "Temporary space available" : "임시 저장 공간을 사용할 수 있음",
@@ -263,17 +256,13 @@ OC.L10N.register(
     "Profile information" : "프로필 정보",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "프로필 사진, 전체 이름, 이메일, 전화번호, 주소, 웹사이트, 트위터, 조직, 직책, 표제, 소개문구 및 프로필 활성화 여부",
     "Nextcloud settings" : "Nextcloud 환경설정",
+    "Task:" : "작업:",
     "Machine translation" : "기계 번역",
-    "Speech-To-Text" : "음성인식",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "음성인식 기능을 채용한 앱이 이곳에 표시됩니다. 음성인식 기능을 사용할 앱을 선택하십시오. ",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "현재 설치된 앱 중 음성인식 기능을 제공하는 것이 없습니다",
     "Image generation" : "이미지 생성",
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "이미지 생성 기능을 채용한 앱이 이곳에 표시됩니다. 이미지 생성 기능을 사용할 앱을 선택하십시오. ",
     "None of your currently installed apps provide image generation functionality" : "현재 설치된 앱 중 이미지 생성 기능을 제공하는 것이 없습니다",
     "Text processing" : "문장 처리",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "문장처리 기술을 채용한 앱이 이곳에 표시됩니다. 문장처리 기술을 사용할 앱과 해당 기술이 사용될 작업을 설정하십시오.",
-    "Task:" : "작업:",
-    "None of your currently installed apps provide Text processing functionality" : "현재 설치된 앱 중 문장처리 기술을 제공하는 것이 없습니다",
     "Here you can decide which group can access certain sections of the administration settings." : "이곳에서 각 설정 메뉴별로 해당 메뉴에 접근 가능한 그룹을 지정할 수 있습니다.",
     "None" : "없음",
     "Unable to modify setting" : "설정을 수정할 수 없습니다.",
@@ -287,7 +276,13 @@ OC.L10N.register(
     "Enforce password protection" : "암호 보호 강제",
     "Exclude groups from password requirements" : "특정 그룹을 암호 요구조건에서 예외로 설정",
     "Exclude groups from creating link shares" : "특정 그룹에 대해 링크 공유 생성을 금지하도록 설정",
+    "Limit sharing based on groups" : "그룹별로 공유 제한하기",
+    "Allow sharing for everyone (default)" : "그룹별 공유 기능 제한 없음 (기본값)",
+    "Exclude some groups from sharing" : "공유 기능을 제한할 그룹 지정",
+    "Limit sharing to some groups" : "공유 기능을 허용할 그룹 지정",
+    "Groups allowed to share" : "공유가 허용된 그룹",
     "Groups excluded from sharing" : "공유에서 제외된 그룹",
+    "Not allowed groups will still be able to receive shares, but not to initiate them." : "공유가 제한된 그룹은 다른 사람의 데이터를 공유 받을 수는 있지만, 다른 사람에게 자신의 데이터를 공유할 수는 없습니다.",
     "Set default expiration date for shares" : "공유에 대한 기본 만료 날짜 설정",
     "Enforce expiration date" : "만료 날짜 강제",
     "Default expiration time of new shares in days" : "공유에 대한 기본 유효기간 (일 단위)",
@@ -299,10 +294,7 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "링크 및 메일 공유에 대한 기본 만료 날짜 설정",
     "Default expiration time of shares in days" : "공유에 대한 기본 유효기간 (일 단위)",
     "Privacy settings for sharing" : "공유에 대한 개인정보 보호 설정",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "공유 대화창에서 시스템 주소록에 있는 사용자 이름을 자동으로 채울 수 있도록 허용",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"같은 그룹\" 또는 \"전화번호 기반\" 자동 채우기가 활성화되었을 경우 각 항목에 일치하는 사용자가 자동으로 표시됩니다.",
-    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "사용자 이름 자동 채우기를 같은 그룹에 소속된 사용자로 한정",
-    "Allow username autocompletion to users based on phone number integration" : "전화번호를 기반으로 사용자 이름 자동 채우기를 허용",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "전체 이름 또는 이메일 주소를 입력했을 때 사용자 이름 자동 채우기를 허용 (전화번호 일치/소속 그룹 일치 여부에 대한 설정값을 무시)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "공개 링크 업로드 페이지에 고지 사항 문구를 표시 (파일 목록이 숨겨져 있는 경우에만 표시)",
     "Disclaimer text" : "고지 사항 문구",
@@ -337,7 +329,7 @@ OC.L10N.register(
     "Results from other categories" : "다른 카테고리로부터의 결과",
     "No apps found for your version" : "설치된 버전에 대한 앱 없음",
     "Disable all" : "전체 비활성화",
-    "Download and enable all" : "다운로드 및 모두 활성화",
+    "Download and enable all" : "모두 다운로드 및 사용",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n개의 앱을 업데이트 할 수 있습니다."],
     "_Update_::_Update all_" : ["모두 업데이트"],
     "Nothing to show" : "표시할 항목 없음",
@@ -514,42 +506,29 @@ OC.L10N.register(
     "Common languages" : "공통 언어",
     "Other languages" : "다른 언어",
     "Password change is disabled because the master key is disabled" : "마스터 키가 비활성화 되어 암호 변경이 비활성화 됨",
-    "New user" : "새 사용자",
+    "New account" : "새로운 계정",
     "Display name" : "표시 이름",
     "Either password or email is required" : "암호 또는 이메일이 필요합니다",
     "Password (required)" : "암호 (필수)",
     "Email (required)" : "이메일 (필수)",
     "Email" : "이메일",
-    "Groups (required)" : "그룹 (필수)",
-    "Set user groups" : "사용자 그룹 설정",
-    "Set user as admin for …" : "사용자를 다음에 대한 관리자로 설정 ...",
     "Quota" : "할당량",
-    "Set user quota" : "사용자 할당량 지정",
     "Language" : "언어",
     "Set default language" : "기본 언어 지정",
     "Manager" : "담당 관리자",
-    "Add new user" : "새 사용자 추가",
-    "Set user manager" : "사용자 담당 관리자 지정",
-    "Username will be autogenerated" : "사용자 이름이 자동으로 생성됩니다",
-    "Username (required)" : "사용자 이름 (필수)",
     "Total rows summary" : "총 행 요약",
-    "Loading users …" : "사용자 불러오는 중 ...",
     "Scroll to load more rows" : "스크롤 하여 더 불러오기",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount}명의 사용자 ..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount}명의 사용자"],
     "Avatar" : "아바타",
-    "Username" : "사용자 이름",
+    "Account name" : "계정 아이디",
     "Group admin for" : "다음 그룹의 관리자:",
-    "User backend" : "사용자 백엔드",
     "Storage location" : "저장소 위치",
     "Last login" : "마지막 로그인",
-    "User actions" : "사용자 동작",
+    "Account actions" : "계정 동작",
     "Loading account …" : "계정 불러오는 중 ...",
     "Change display name" : "표시 이름 변경",
     "Set new password" : "새 암호 설정",
     "You do not have permissions to see the details of this account" : "이 계정의 상세정보를 볼 권한이 없습니다.",
     "Set new email address" : "새 이메일 주소 설정",
-    "Add user to group" : "사용자를 그룹에 추가",
     "Add account to group" : "계정을 그룹에 추가",
     "Set account as admin for" : "계정을 다음에 대한 관리자로 설정: ",
     "Select account quota" : "계정 할당량 설정",
@@ -598,12 +577,11 @@ OC.L10N.register(
     "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "You need to enable the File sharing App." : "파일 공유 앱을 활성화해야 합니다.",
-    "Active accounts" : "활성화된 계정",
+    "Developer documentation ↗" : "개발자 문서 ↗",
     "Admins" : "관리자",
-    "Disabled accounts" : "비활성화된 계정",
     "Account group: {group}" : "계정 그룹: {group}",
     "Account management" : "계정 관리",
-    "New account" : "새로운 계정",
+    "Creating group…" : "그룹 생성 ...",
     "Create group" : "그룹 생성",
     "Group name" : "그룹 이름",
     "Please enter a valid group name" : "올바른 그룹 이름을 입력하세요",
@@ -636,12 +614,15 @@ OC.L10N.register(
     "Show to everyone" : "전체 공개",
     "Show to logged in accounts only" : "로그인된 계정에 공개",
     "Hide" : "비공개",
-    "Download and enable" : "다운로드 및 활성화",
-    "Allow untested app" : "미시험 앱 허용",
+    "Download and enable" : "다운로드 및 사용",
+    "Allow untested app" : "확인되지 않은 앱 허용",
     "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다.",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
     "Never" : "하지 않음",
-    "An error occurred during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
+    "Could not register device: Network error" : "기기를 등록할 수 없음: 네트워크 오류",
+    "Could not register device: Probably already registered" : "기기를 등록할 수 없음: 이미 등록된 기기인 것 같습니다",
+    "Could not register device" : "기기를 등록할 수 없음",
+    "An error occurred during the request. Unable to proceed." : "요청을 보내는 도중 오류가 발생하였습니다. 더 이상 진행할 수 없습니다.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "Error: This app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다.",
     "Do you really want to wipe your data from this device?" : "정말 이 기기로 부터 데이터를  지우시겠습니까?",
@@ -650,6 +631,7 @@ OC.L10N.register(
     "Error while wiping the device with the token" : "토큰으로 기기를 제거하는 도중 오류 발생",
     "Error while updating device token name" : "기기 토큰 이름을 갱신하는 중 오류 발생",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
+    "Error" : "오류",
     "Account documentation" : "계정 문서",
     "Administration documentation" : "관리 문서",
     "Forum" : "포럼",
@@ -669,15 +651,16 @@ OC.L10N.register(
     "Authentication" : "인증",
     "Authentication required" : "인증 필요함",
     "Credentials" : "인증 정보",
+    "SMTP Login" : "SMTP 로그인",
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Test and verify email settings" : "이메일 설정 테스트 및 검증",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
     "All checks passed." : "모든 검사를 통과했습니다.",
-    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 에러가 있습니다.",
+    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 오류가 있습니다.",
     "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
     "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 에러를 확인하세요.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 오류를 확인하세요.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 이 Nextcloud의 보안을 점검하세요.",
     "Reasons to use Nextcloud in your organization" : "당신의 조직에서 Nextcloud를 사용해야 할 이유",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
@@ -692,113 +675,81 @@ OC.L10N.register(
     "No user supplied" : "사용자가 지정되지 않음",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
     "Backend does not support password change, but the user's encryption key was updated." : "백엔드에서 암호 변경을 지원하지 않지만 사용자의 암호화 키는 업데이트되었습니다.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
-    "Federated Cloud Sharing" : "클라우드 연합 공유",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL이 오래된 %1$s 버전을 사용하고 있습니다(%2$s). 운영 체제나 기능을 업데이트하지 않으면 %3$s 등을 안정적으로 사용할 수 없습니다.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "https://nextcloud.com에 대한 HTTPS 요청 중 오류가 발생하여 cURL의 TLS 버전이 오래되었는지 확인할 수 없습니다. 자세한 정보는 Nextcloud 로그 파일을 참조하여 주십시오.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPchache가 비활성화 되었습니다. PHP 설정에서 <code>opcahce.enable=1</code>을 적용하는 것을 권장합니다.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache가 code comment를 삭제하도록 설정되어 있습니다. Nextcloud의 원활한 작동을 위해 OPcahce 활성화 시 <code>opcache.save_comments=1</code>을 설정해야 합니다.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud가 OPcache API를 사용하도록 허용되지 않았습니다. Nextcloud core나 앱 업그레이드 중 에러 발생을 방지하기 위해, OPcache 활성화 시 모든 Nextcloud 디렉토리를 <code>opcahce.restrict_api</code>에 포함하거나 해당 설정을 해제하여 OPcahce API 제한을 비활성화 하는 것을 권장합니다.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud가 OPcache API를 사용하도록 허용되지 않았습니다. Nextcloud core나 앱 업그레이드 중 에러 발생을 방지하기 위해, OPcache 활성화 시 모든 Nextcloud 디렉토리를 <code>opcahce.restrict_api</code>에 포함하거나 해당 설정을 해제하여 OPcahce API 제한을 비활성화 하는 것을 권장합니다.",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "공유 메모리 기반 OPcahce가 비활성화되었습니다. 성능 향상을 위해 PHP 설정에 <code>opcache.file_cache_only=0</code>을 적용하고, 파일 캐시를 2단계 캐시 전용으로 사용하십시오.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache key가 최대치를 초과할 것으로 보입니다. 모든 스크립트가 캐시에 유지될 수 있도록, PHP 설정에서 <code>opcache.max_accelerated_files</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache 버퍼가 가득 찰 것으로 보입니다. 모든 스크립트가 캐시에 보관될 수 있도록, PHP 설정에서 <code>opcache.memory_consumption</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache interned buffer가 가득 찰 것으로 보입니다. 반복 문자열이 효율적으로 캐싱될 수 있도록, PHP 설정에서 <code>opcache.interned_strings_buffer</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "이메일 발송 테스트를 진행하기 앞서 당신의 사용자 이메일을 설정해야 합니다. 설정을 위해 %s(으)로 가십시오.",
     "Invalid user" : "잘못된 사용자",
     "Your username is: %s" : "사용자 이름: %s",
     "Logged in user must be a subadmin" : "로그인한 사용자는 부관리자여야 합니다.",
+    "Old user imported certificates" : "과거 사용자가 인증서를 가져왔습니다",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "사용자가 불러온 SSL 인증서를 확인하는 백그라운드 작업이 진행중입니다. 나중에 다시 확인하십시오.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "현재 사용자가 불러온 SSL 인증서 중 Nextcloud 21과 함께 사용할 수 없는 것이 있습니다. 이러한 인증서는 커맨드라인 명령어 \"occ security:certificates:import\"로 불러올 수 있습니다. 데이터 디렉토리 내부에 있는 해당 인증서의 경로가 아래에 표시됩니다.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "잘못된 LDAP 사용자 또는 그룹 UUID를 발견했습니다. LDAP 설정의 '전문가' 부분에서 \"Override UUID detection\"을 재확인하시고, \"occ ldap:update-uuid\" 명령어를 통해 이를 갱신하십시오.",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "DAV 시스템 주소록 동기화가 아직 작동하지 않았습니다. 이는 인스턴스의 사용자가 1000명을 초과하거나 오류가 발생했기 때문입니다. occ dav:sync-system-addressbook 명령어를 통해 수동으로 이를 수행하십시오.",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 사용자 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹을 선택 또는 제외할 때, 이들의 2단계 인증 강제 여부는 다음과 같은 로직을 따릅니다: 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 사용자에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 사용자가 선택된 그룹과 제외된 그룹에 동시에 속해 있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
-    "Enable all" : "모두 활성화",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google 크롬",
-    "Safari" : "Safari",
-    "iPhone" : "아이폰",
-    "iPad" : "아이패드",
-    "Sync client - {os}" : "동기화 클라이언트 - {os}",
-    "Error while deleting the token" : "토큰을 삭제하는 중 오류가 발생했습니다",
-    "Use the credentials below to configure your app or device." : "앱 또는 장치를 구성하는 아래의 자격 증명을 사용합니다.",
-    "For security reasons this password will only be shown once." : "보안상의 이유로 이 암호는 한 번만 표시됩니다.",
-    "Copied!" : "복사 성공!",
-    "Copy" : "복사",
-    "Execute one task with each page loaded. Use case: Single user instance." : "페이지를 로드할 때마다 작업을 실행합니다. 사용자가 한 명인 인스턴스에 적합합니다.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php를 webcron 서비스에 등록하여 매 5분마다 HTTP 상에서 실행합니다. 사용자가 1~5명인 소규모 인스턴스에 적합합니다.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "시스템 cron 서비스를 통해 5분마다 cron.php 파일을 실행합니다. 가장 권장됩니다.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "시스템 사용자 \"{user}\"(으)로 cron.php를 실행해야 합니다.",
-    "Enable or disable profile by default for new users." : "신규 사용자에 대한 프로필 기본 사용 여부를 설정하십시오.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
-    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
-    "Your profile information" : "내 프로필 정보",
-    "Your email address" : "이메일 주소",
-    "Additional emails" : "추가 이메일",
-    "Enable Profile" : "프로필 활성화",
-    "Your Twitter handle" : "내 트위터",
-    "You do not have permissions to see the details of this user" : "사용자의 상세정보를 볼 권한이 없습니다.",
-    "Edit display name" : "표시 이름 수정",
-    "Add new password" : "새로운 암호 입력",
-    "Add new email address" : "새로운 이메일 추가하기",
-    "Set user as admin for" : "사용자를 다음에 대한 관리자로 설정",
-    "Select user quota" : "사용자 할당량 선택",
-    "Select manager" : "담당 관리자 지정",
-    "Toggle user actions menu" : "사용자 동작 메뉴 켜고 끄기",
-    "Delete user" : "사용자 지우기",
-    "Wipe all devices" : "모든 기기 지우기",
-    "Disable user" : "사용자 비활성화하기",
-    "Enable user" : "사용자 활성화하기",
-    "Edit User" : "사용자 편집",
-    "Will be autogenerated" : "자동으로 생성될 것임",
-    "Select user manager" : "사용자 담당 관리자 지정",
-    "Add a new user" : "새 사용자 추가",
-    "No users in here" : "사용자가 이곳에 없습니다.",
-    "Name your device" : "장치 이름 설정",
-    "Server error while trying to add WebAuthn device" : "WebAuthn 기기 추가 시도 중 서버 오류 발생",
-    "{license}-licensed" : "{license} 라이선스",
-    "by {author}\n{license}" : "{author} 님이 작성\n{license}",
-    "Enter group name" : "그룹 이름 입력",
-    "Add group" : "그룹 추가",
-    "Active users" : "활성 사용자",
-    "Disabled users" : "비활성화된 사용자",
-    "Default quota:" : "기본 할당량:",
-    "Show Languages" : "언어 보이기",
-    "Show user backend" : "사용자 백엔드 보이기",
-    "Send email to new user" : "새 사용자에게 이메일 보내기",
-    "Not saved" : "저장하지 않음",
-    "Twitter" : "트위터",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "계정에서 연합이 비활성화되어 현재 사용할 수 없는 상태입니다. 시스템 관리자에게 문의하십시오",
-    "Show to logged in users only" : "로그인된 사용자에게 공개",
-    "Enable untested app" : "미시험 앱 활성화",
-    "SMTP Username" : "SMTP 사용자 이름",
-    "Expire after" : "다음 날짜 후 만료",
-    "day(s)" : "일",
-    "Exclude groups from password requirements:" : "이 그룹을 암호 요구조건에서 예외로 설정: ",
-    "Set default expiration date" : "기본 만료 날짜 설정",
-    "Exclude groups from creating link shares:" : "이 그룹에 대해 링크 공유 생성을 금지하도록 설정:",
-    "Exclude groups from sharing" : "공유에서 그룹 제외",
-    "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
-    "Old user imported certificates" : "과거 사용자가 인증서를 가져왔습니다",
+    "Missing optional index \"%s\" in table \"%s\"." : "표 \"%s\"의 optional index \"%s\"이(가) 사라졌습니다",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
     "Could not check for JavaScript support. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "JavaScript 지원 여부를 확인할 수 없습니다. 이 웹 서버가 JacaScript MIME 타입을 통해 `.mjs` 파일을 제공할 경우 수동으로 이를 확인하십시오.",
     "MySQL unicode support" : "MySQL 유니코드 지원",
     "Overwrite cli URL" : "CLI URL 덮어쓰기",
     "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "현재 PHP %s이(가) 동작 중입니다. Nextcloud 27에서 PHP 8.0의 지원이 중단되었습니다. Nextcloud 28은 최소 PHP 8.1이 요구됩니다. 가능한 빨리 PHP Group에서 제공하는 공식 지원 PHP 버전으로 업그레이드 하십시오.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "현재 MariaDB \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MariaDB 10.2 이상을 사용하십시오.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "현재 MySQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MySQL 8.0 혹은 MariaDB 10.2 이상을 사용하십시오.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "현재 PostgreSQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. PostgreSQL 9.6 이상을 사용하십시오.",
+    "Speech-To-Text" : "음성인식",
+    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "음성인식 기능을 채용한 앱이 이곳에 표시됩니다. 음성인식 기능을 사용할 앱을 선택하십시오. ",
+    "None of your currently installed apps provide Speech-To-Text functionality" : "현재 설치된 앱 중 음성인식 기능을 제공하는 것이 없습니다",
+    "None of your currently installed apps provide Text processing functionality" : "현재 설치된 앱 중 문장처리 기술을 제공하는 것이 없습니다",
+    "Exclude groups from sharing" : "공유에서 그룹 제외",
+    "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
+    "Allow username autocompletion in share dialog and allow access to the system address book" : "공유 대화창에서 시스템 주소록에 있는 사용자 이름을 자동으로 채울 수 있도록 허용",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 사용자 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹을 선택 또는 제외할 때, 이들의 2단계 인증 강제 여부는 다음과 같은 로직을 따릅니다: 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 사용자에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 사용자가 선택된 그룹과 제외된 그룹에 동시에 속해 있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
+    "{license}-licensed" : "{license} 라이선스",
     "Rating: {score}/10" : "점수: {score}/10",
+    "Username" : "사용자 이름",
+    "Execute one task with each page loaded. Use case: Single user instance." : "페이지를 로드할 때마다 작업을 실행합니다. 사용자가 한 명인 인스턴스에 적합합니다.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php를 webcron 서비스에 등록하여 매 5분마다 HTTP 상에서 실행합니다. 사용자가 1~5명인 소규모 인스턴스에 적합합니다.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "시스템 사용자 \"{user}\"(으)로 cron.php를 실행해야 합니다.",
+    "Enable or disable profile by default for new users." : "신규 사용자에 대한 프로필 기본 사용 여부를 설정하십시오.",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "그룹 \"{group}\"을(를) 지우려고 합니다. 그룹의 사용자는 삭제되지 않습니다.",
+    "Additional emails" : "추가 이메일",
+    "Enable Profile" : "프로필 활성화",
     "No users" : "사용자 없음",
+    "Loading users …" : "사용자 불러오는 중 ...",
     "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "사용자 목록입니다. 이 목록은 성능을 위해 완전히 처리되지 않았습니다. 목록을 계속 탐색하면 남은 목록이 자동으로 처리됩니다.",
+    "New user" : "새 사용자",
+    "Groups (required)" : "그룹 (필수)",
+    "Set user groups" : "사용자 그룹 설정",
+    "Set user as admin for …" : "사용자를 다음에 대한 관리자로 설정 ...",
+    "Set user quota" : "사용자 할당량 지정",
+    "Add new user" : "새 사용자 추가",
+    "Set user manager" : "사용자 담당 관리자 지정",
+    "Username will be autogenerated" : "사용자 이름이 자동으로 생성됩니다",
+    "Username (required)" : "사용자 이름 (필수)",
+    "User backend" : "사용자 백엔드",
+    "User actions" : "사용자 동작",
     "Loading user …" : "사용자 불러오는 중 ...",
+    "You do not have permissions to see the details of this user" : "사용자의 상세정보를 볼 권한이 없습니다.",
+    "Add user to group" : "사용자를 그룹에 추가",
+    "Set user as admin for" : "사용자를 다음에 대한 관리자로 설정",
+    "Select user quota" : "사용자 할당량 선택",
+    "Delete user" : "사용자 지우기",
+    "Wipe all devices" : "모든 기기 지우기",
+    "Disable user" : "사용자 비활성화하기",
+    "Enable user" : "사용자 활성화하기",
     "Failed to update user manager" : "사용자 담당 관리자를 지정할 수 없음",
+    "Toggle user actions menu" : "사용자 동작 메뉴 켜고 끄기",
     "User management settings" : "사용자 관리 설정",
+    "Show user backend" : "사용자 백엔드 보이기",
     "Send welcome email to new users" : "새 사용자에게 환영 이메일 보내기",
+    "Name your device" : "장치 이름 설정",
+    "Server error while trying to add WebAuthn device" : "WebAuthn 기기 추가 시도 중 서버 오류 발생",
+    "by {author}\n{license}" : "{author} 님이 작성\n{license}",
     "User management" : "사용자 관리",
+    "Active users" : "활성 사용자",
+    "Disabled users" : "비활성화된 사용자",
     "Creating group …" : "그룹 생성 ...",
     "User group: {group}" : "사용자 그룹: {group}",
-    "Nextcloud help resources" : "Nextcloud 도움말 자원"
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "계정에서 연합이 비활성화되어 현재 사용할 수 없는 상태입니다. 시스템 관리자에게 문의하십시오",
+    "Show to logged in users only" : "로그인된 사용자에게 공개",
+    "Nextcloud help resources" : "Nextcloud 도움말 자원",
+    "SMTP Username" : "SMTP 사용자 이름",
+    "Active accounts" : "활성화된 계정"
 },
 "nplurals=1; plural=0;");
