@@ -107,7 +107,6 @@ OC.L10N.register(
     "Unlimited" : "Chene lìmites",
     "Verifying" : "Averguende",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In sa base de datos mancat calicuna colunna optzionale. Agiùnghere is colunnas optzionale a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-columns\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is colunnas sunt agiuntas unas cantas funtzionalidades diant pòdere resurtare prus reativos o prus bellu a impreare. ",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In sa base de datos mancat calicuna crae primària. Agiùnghere is craes primàrias a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-primary-keys\". Si podent agiùnghere a manu is craes primàrias chi mancant in s'interis chi s'istàntzia est in funtzione.",
     "Disabled" : "Disativadu",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Su formadu betzu de tzifradura ladu serbidore est ativu. Racumandamus de ddu disativare. ",
@@ -132,7 +131,6 @@ OC.L10N.register(
     "Enforce expiration date" : "Impone data de iscadèntzia",
     "Set default expiration date for shares to other servers" : "Imposta sa data de iscadèntzia predefinida pro is cumpartziduras a àteros serbidores",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si sa cumponidura automàtica \"matessi grupu\" e \"integratzione de nùmeru de telèfonu\" sunt ativadas, una currispondèntzia in unu de is duas bastat a mustrare s'utente.",
-    "Allow username autocompletion to users based on phone number integration" : "Permite sa cumponidura automàtica de su nùmene de utente a is utentes segundu s'integratzione de su nùmeru de telèfonu",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mustra sa liberatòria in sa pàgina de carrigamentu de su ligòngiu pùblicu (mustradu isceti cando s'archìviu de sa lista est cuadu)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Custu testu s'at a mustrare in sa pàgina de carrigamentu de su ligòngiu pùblicu cando s'archìviu de sa lista est cuadu.",
     "Default share permissions" : "Permissos de cumpartzidura predefinidos",
@@ -245,18 +243,15 @@ OC.L10N.register(
     "Default language" : "Limba predefinida",
     "Common languages" : "Limbas comunes",
     "Password change is disabled because the master key is disabled" : "Su càmbiu de sa crae est disativadu ca sa crae printzipale est disativada",
-    "New user" : "Utèntzia noa",
     "Display name" : "Ammustra nùmene",
     "Email" : "Posta eletrònica",
     "Quota" : "Cuota",
     "Language" : "Limba",
     "Avatar" : "Avatar",
-    "Username" : "Nùmene utente",
     "Group admin for" : "In amministratzione pro su grupu",
-    "User backend" : "Motore utente",
     "Storage location" : "Positzione de s'archiviatzione",
     "Last login" : "Ùrtimu atzessu",
-    "Add user to group" : "Agiunghe un'utente a unu grupu",
+    "Account actions" : "Atziones de su contu",
     "{size} used" : "{size} impreadu",
     "Delete account" : "Cantzella contu",
     "Resend welcome email" : "Torra a imbiare su messàgiu de benebènnida",
@@ -318,6 +313,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Errore agiornende si nùmene de su token de su dispositivu",
     "Error while updating device token scope" : "Errore agiornende s'àmbitu de su token de su dispositivu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
+    "Error" : "Errore",
     "Forum" : "Forum",
     "Legal notice" : "Avisu legale",
     "Privacy policy" : "Critèriu de riservadesa",
@@ -352,69 +348,35 @@ OC.L10N.register(
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si impreas aplicatziones de sa de tres partes pro ti connètere a Nextcloud, assegura•ti de creare e cunfigurare una crae pro cada aplicatzione antis de ativare su segundu fatore de autenticatzione.",
     "No user supplied" : "Peruna utèntzia frunida",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fruni una crae amministrativa de riprìstinu; si nono, s'ant a perdere totu is datos de utente.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installatzione e agiornamentu de is aplicatziones tràmite sa butega de is aplicatziones o sa cumpartzidura in sa nue federada",
-    "Federated Cloud Sharing" : "Cumpartzidura in sa nue federada",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL est impreende una versione %1$sagiornada (%2$s). Agiorna su sistema operativu tuo, si nono funtzionalidades comente %3$s no ant a funtzionare.",
     "Invalid user" : "Utèntzia non bàlida",
     "Your username is: %s" : "Su nùmene utente tuo est: %s",
     "Logged in user must be a subadmin" : "S'utente devet essere de sa suta-amministratzione ",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Un'atividade in segundu pianu est in isetu pro controllare is tzertificados SSL importados dae s'utente. Torra a controllare prus a tardu.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "B'at tzertificados SSL importados dae utentes chi non s'impreant prus cun Nextcloud 21. Si podent importare in sa lìnia de cumandu tràmite su cumandu \"occ security:certificates:import\". Is percursos issoro in sa cartella de is datos sunt mustrados in fatu.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
+    "Exclude groups from sharing" : "Esclude grupos dae sa cumpartzidura",
+    "These groups will still be able to receive shares, but not to initiate them." : "Custos grupos ant a pòdere retzire cumpartziduras, ma no ddas ant a pòdere cumintzare.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "S'autenticatzione a duos fatores si podet aplicare a totu is utentes e grupos ispetzìficos. Si non tenent unu frunidore a duos fatores cunfiguradu, no ant a pòdere intrare in su sistema.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando si seletzionant/escludent grupos, pro determinare si un'utente at aplicadu 2FA, s'impreat sa lògica in fatu: si non si seletzionat perunu grupu, 2FA est ativu pro chie chi siat, francu pro cumponentes de grupos esclùdidos. Si un'utente est siat in unu grupu seletzionadu siat in unu esclùdidu, cussu seletzionadu passat in antis e 2FA est aplicadu.",
-    "Enable all" : "Ativa totu",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Cliente de sincronizatzione - {os}",
-    "Error while deleting the token" : "Errore in sa cantzelladura de su token",
-    "Use the credentials below to configure your app or device." : "Imprea is credentziales in suta pro cunfigurare s'aplicatzione o su dispositivu.",
-    "For security reasons this password will only be shown once." : "Pro resones de seguresa, custa crae s'at a mustrare una borta isceti.",
-    "Copied!" : "Copiadu!",
-    "Copy" : "Còpia",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pro esecutare custu, serbit s'estensione PHP POSIX. Càstia {linkstart}documentatzione PHP{linkend} pro àteros detàllios.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Ses acanta de nche bogare su grupu {group}. Is utèntzias NO s'ant a cantzellare.",
-    "Please confirm the group removal " : "Cunfirma de bogare su grupu",
-    "Your email address" : "Indiritzu tuo de posta eletrònica",
+    "{license}-licensed" : "suta lissèntzia {license}",
+    "Username" : "Nùmene utente",
+    "New user" : "Utèntzia noa",
+    "User backend" : "Motore utente",
     "You do not have permissions to see the details of this user" : "Non tenes is permissos pro bìdere is detàllios de s'utente",
-    "Add new password" : "Agiunghe una crae noa",
-    "Add new email address" : "Agiunghe un'indiritzu nou de posta eletrònica",
+    "Add user to group" : "Agiunghe un'utente a unu grupu",
     "Set user as admin for" : "Include a un'utente in s'amministratzione pro",
     "Select user quota" : "Seletziona cuota utente",
-    "Toggle user actions menu" : "Càmbia su menu de is atziones de s'utente",
     "Delete user" : "Cantzella utente",
     "Wipe all devices" : "Cantzella totu is dispositivos",
     "Disable user" : "Disativa utente",
     "Enable user" : "Ativa utente",
-    "Edit User" : "Modìfica utente",
-    "Will be autogenerated" : "At a èssere auto-generadu",
-    "Add a new user" : "Agiunghe un'utèntzia noa",
-    "No users in here" : "Peruna utèntzia inoghe",
+    "Toggle user actions menu" : "Càmbia su menu de is atziones de s'utente",
+    "Show user backend" : "Mustra su motore utente",
     "Name your device" : "Nùmena su dispositivu",
     "Server error while trying to add WebAuthn device" : "Errore de su serbidore chirchende de agiùnghere su dispositivu WebAuthn",
-    "{license}-licensed" : "suta lissèntzia {license}",
     "by {author}\n{license}" : "de {author}\n{license}",
-    "Enter group name" : "Inserta nùmene de su grupu",
-    "Add group" : "Agiunghe grupu",
     "Active users" : "Utèntzias ativas",
     "Disabled users" : "Disativa utentes",
-    "Default quota:" : "Cuota predefinida:",
-    "Show Languages" : "Mustra limbas",
-    "Show user backend" : "Mustra su motore utente",
-    "Send email to new user" : "Imbia messàgiu de posta a utèntzia noa",
-    "Not saved" : "Non sarvadu",
-    "Twitter" : "Twitter",
-    "Enable untested app" : "Ativa aplicatzione non verificada",
-    "SMTP Username" : "Nùmene utente SMTP ",
-    "Expire after" : "Iscadit pustis de",
-    "day(s)" : "die(s)",
-    "Set default expiration date" : "Imposta sa data de iscadèntzia predefinida ",
-    "Exclude groups from creating link shares:" : "Esclude grupos dae sa creatzione de ligòngios de cumpartzidura:",
-    "Exclude groups from sharing" : "Esclude grupos dae sa cumpartzidura",
-    "These groups will still be able to receive shares, but not to initiate them." : "Custos grupos ant a pòdere retzire cumpartziduras, ma no ddas ant a pòdere cumintzare."
+    "SMTP Username" : "Nùmene utente SMTP "
 },
 "nplurals=2; plural=(n != 1);");
