@@ -13,6 +13,7 @@ OC.L10N.register(
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
     "Keyboard shortcuts" : "Atajos del teclado",
+    "Link" : "Liga",
     "Action" : "Acción",
     "Undo" : "Deshacer",
     "Save changes" : "Guardar cambios",
@@ -24,6 +25,7 @@ OC.L10N.register(
     "Source code" : "Código fuente",
     "Info" : "Info",
     "Success" : "Éxito",
-    "Warning" : "Advertencia"
+    "Warning" : "Advertencia",
+    "Details" : "Detalles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
