@@ -16,6 +16,7 @@ OC.L10N.register(
     "Create new text file" : "Luo uusi tekstitiedosto",
     "Editing session has expired. Please reload the page." : "Muokkausistunto vanheni. Lataa sivu uudelleen.",
     "{user} has mentioned you in the text document {node}" : "{user} mainitsi sinut tekstiasiakirjassa {node}",
+    "File not found" : "Tiedostoa ei löytynyt",
     "Readme" : "Lueminut",
     "Text" : "Teksti",
     "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
@@ -38,10 +39,9 @@ OC.L10N.register(
     "Guest" : "Vieras",
     "Save guest name" : "Tallenna vieraan nimi",
     "Insert an attachment" : "Lisää liite",
+    "Show link preview" : "Näytä linkin esikatselu",
     "Remove link" : "Poista linkki",
     "guest" : "vieras",
-    "Show author colors" : "Näytä tekijän värit",
-    "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
     "Active people" : "Aktiiviset ihmiset",
     "Save document" : "Tallenna asiakirja",
     "Last saved" : "Viimeksi tallennettu",
@@ -52,6 +52,8 @@ OC.L10N.register(
     "Last saved {lastSave}" : "Viimeksi tallennettu {lastSave}",
     "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
     "Unsaved changes" : "Tallentamattomia muutoksia",
+    "Connection failed." : "Yhteys epäonnistui.",
+    "Formatting and shortcuts" : "Muotoilu ja pikanäppäimet",
     "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
     "Just type the Markdown syntax from below." : "Kirjoita Markdown-syntaksia alapuolelta.",
@@ -80,7 +82,9 @@ OC.L10N.register(
     "Quoted text" : "Lainattu teksti",
     "Code block" : "Koodilohko",
     "Some code" : "Koodia",
+    "Link" : "Linkki",
     "Insert emoji" : "Lisää emoji",
+    "Mention someone" : "Mainitse käyttäjä",
     "name" : "nimi",
     "Action" : "Toiminto",
     "Undo" : "Kumoa",
@@ -125,7 +129,6 @@ OC.L10N.register(
     "Diagram" : "Kaavio",
     "Both" : "Molemmat",
     "Mermaid documentation" : "Mermaid-dokumentaatio",
-    "Link to this section" : "Linkki tähän osioon",
     "Delete this attachment" : "Poista tämä liite",
     "Delete this image" : "Poista tämä kuva",
     "Failed to load" : "Lataaminen epäonnistui",
@@ -148,6 +151,7 @@ OC.L10N.register(
     "Success" : "Onnistui",
     "Warning" : "Varoitus",
     "Table" : "Taulukko",
+    "Details" : "Tiedot",
     "Insert attachment" : "Lisää liite",
     "Command" : "Komento",
     "Control" : "Hallinta",
@@ -158,10 +162,9 @@ OC.L10N.register(
     "Created \"{name}\"" : "Luotu \"{name}\"",
     "Copied to the clipboard" : "Kopioitu leikepöydälle",
     "Could not copy to the clipboard" : "Ei voitu kopioida leikepöydälle",
-    "Source language" : "Lähdekieli",
-    "Target language" : "Kohdekieli",
-    "e.g. php, javascript, json, ..." : "esim. php, javascript, json...",
-    "Show rich workspaces" : "Näytä rikastetut työtilat",
+    "Link to this section" : "Linkki tähän osioon",
+    "Show author colors" : "Näytä tekijän värit",
+    "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
     "Add description" : "Lisää kuvaus"
 },
 "nplurals=2; plural=(n != 1);");
