@@ -1,9 +1,11 @@
 OC.L10N.register(
     "text",
     {
+    "File not found" : "Файл олдсонгүй",
     "Translate" : "Орчуулга",
     "Guest" : "Зочин",
     "Saved" : "Хадгалах",
+    "Link" : "Холбоос",
     "Undo" : "буцах",
     "Cancel" : "Цуцлах",
     "URL" : "URL",
@@ -12,6 +14,7 @@ OC.L10N.register(
     "Edit" : "засварлах",
     "Source code" : "эх үүсвэр талын код",
     "Info" : "Info",
-    "Warning" : "Warning"
+    "Warning" : "Warning",
+    "Details" : "Дэлгэрэнгүй"
 },
 "nplurals=2; plural=(n != 1);");
