@@ -39,10 +39,12 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Calca'l botón siguiente pa reaniciar la contraseña. Si nun solicitesti esta aición, inora'l mensaxe.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Calca l'enllaz siguiente pa reaniciar la contraseña. Si nun solicitesti esta aición, inora'l mensaxe.",
     "Reset your password" : "Reaniciar la contraseña",
-    "Requested task type does not exist" : "El tipu de xera solicitada nun esiste",
-    "Necessary language model provider is not available" : "El modelu llingüísticu necesariu nun ta disponible",
+    "The given provider is not available" : "El fornidor apurríu nun ta disponible",
     "Task not found" : "Nun s'atopó la xera",
     "Internal error" : "Error internu",
+    "Not found" : "Nun s'atopó",
+    "Requested task type does not exist" : "El tipu de xera solicitada nun esiste",
+    "Necessary language model provider is not available" : "El modelu llingüísticu necesariu nun ta disponible",
     "No text to image provider is available" : "Nun hai nengún fornidor de testu a imaxe disponible",
     "Image not found" : "Nun s'atopó la imaxe",
     "No translation provider available" : "Nun hai nengún fornidor de traducciones disponible",
@@ -95,15 +97,37 @@ OC.L10N.register(
     "Continue to {productName}" : "Siguir con «{productName}»",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundu.","L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundos."],
     "Applications menu" : "Menú d'aplicaciones",
+    "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
-    "Currently open" : "Abierto",
     "_{count} notification_::_{count} notifications_" : ["{count} avisu","{count} avisos"],
     "No" : "Non",
     "Yes" : "Sí",
+    "Federated user" : "Usuariu federáu",
+    "Create share" : "Crear l'elementu compartíu",
+    "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
     "Custom date range" : "Intervalu de dates personalizáu",
     "Pick start date" : "Escoyer la data de comienzu",
     "Pick end date" : "Escoyer la data de fin",
     "Search in date range" : "Buscar nun intervalu de dates",
+    "Unified search" : "Busca unificada",
+    "Search apps, files, tags, messages" : "Buscar aplicaciones, ficheros, etiquetes, mensaxes",
+    "Places" : "Llugares",
+    "Date" : "Data",
+    "Today" : "Güei",
+    "Last 7 days" : "Los últimos 7 díes",
+    "Last 30 days" : "Los últimos 30 díes",
+    "This year" : "Esti añu",
+    "Last year" : "L'añu pasáu",
+    "Search people" : "Buscar persones",
+    "People" : "Persones",
+    "Filter in current view" : "Peñerar na vista actual",
+    "Results" : "Resultaos",
+    "Load more results" : "Cargar más resultaos",
+    "Search in" : "Buscar en",
+    "Searching …" : "Buscando…",
+    "Start typing to search" : "Comienza a escribir pa buscar",
+    "No matching results" : "Nun hai nengún resultáu que concasare",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Ente'l ${this.dateFilter.startFrom.toLocaleDateString()} y ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Aniciar la sesión",
     "Logging in …" : "Aniciando la sesión…",
     "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
@@ -117,8 +141,7 @@ OC.L10N.register(
     "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
     "This account is disabled" : "Esta cuenta ta desactivada",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
-    "Login with username or email" : "Aniciar la sesión col nomatu o la direición de corréu electrónicu",
-    "Login with username" : "Aniciar la sesión col nomatu",
+    "Account name or email" : "Nome de la cuenta o direición de corréu electrónicu",
     "Log in with a device" : "Aniciar la sesión con un preséu",
     "Login or email" : "Cuenta o direición de corréu electrónicu",
     "Your account is not setup for passwordless login." : "La cuenta nun ta configurada p'aniciar la sesión ensin contraseñes.",
@@ -138,11 +161,11 @@ OC.L10N.register(
     "Recommended apps" : "Aplicaciones aconseyaes",
     "Loading apps …" : "Cargando les aplicaciones…",
     "Could not fetch list of apps from the App Store." : "Nun se pudo dir en cata de la llista d'aplicaciones de la tienda d'aplicaciones",
-    "Installing apps …" : "Instalando les aplicaciones…",
     "App download or installation failed" : "La descarga o instalación d'aplicaciones falló",
     "Cannot install this app because it is not compatible" : "Nun se pue instalar esta aplicación porque nun ye compatible",
     "Cannot install this app" : "Nun se pue instalar esta aplicación",
     "Skip" : "Saltar",
+    "Installing apps …" : "Instalando les aplicaciones…",
     "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
     "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
@@ -150,6 +173,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Charres, videollamaes, compartición de pantalla, reuniones en llinia y conferencies web; nel restolador y coles aplicaciones móviles.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
     "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
+    "Settings menu" : "Menú de configuración",
+    "Avatar of {displayName}" : "Avatar de: {displayName}",
     "Search contacts" : "Buscar contautos",
     "Reset search" : "Reaniciar la busca",
     "Search contacts …" : "Buscar contautos…",
@@ -161,14 +186,11 @@ OC.L10N.register(
     "Looking for {term} …" : "Buscando {term}…",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
     "Search for {name} only" : "Buscar «{name}» namás",
-    "Start typing to search" : "Comienza a escribir pa buscar",
     "Loading more results …" : "Cargando más resultaos…",
-    "Load more results" : "Cargar más resultaos",
     "Search" : "Buscar",
     "No results for {query}" : "Nun hai nengún resultáu pa «{query}»",
     "Press Enter to start searching" : "Primi la tecla «Intro» pa comenzar la busca",
     "An error occurred while searching for {type}" : "Prodúxose un error mentanto se buscaba «{type}»",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduz {minSearchLength} caráuter o más pa buscar","Introduz {minSearchLength} caráuteres o más pa buscar"],
     "Forgot password?" : "¿Escaeciesti la contraseña?",
     "Back to login form" : "Volver al formulariu p'aniciar la sesión",
     "Back" : "Atrás",
@@ -179,31 +201,13 @@ OC.L10N.register(
     "You have not added any info yet" : "Nun amestesti nenguna información",
     "{user} has not added any info yet" : "{user} nun amestó nenguna información",
     "Error opening the user status modal, try hard refreshing the page" : "Hebo un error al abrir el diálogu modal del estáu d'usuariu, prueba a anovar la páxina",
-    "Unified search" : "Busca unificada",
-    "Search apps, files, tags, messages" : "Buscar aplicaciones, ficheros, etiquetes, mensaxes",
-    "Search {types} …" : "Buscar «{types}»…",
-    "Places" : "Llugares",
-    "Date" : "Data",
-    "Today" : "Güei",
-    "Last 7 days" : "Los últimos 7 díes",
-    "Last 30 days" : "Los últimos 30 díes",
-    "This year" : "Esti añu",
-    "Last year" : "L'añu pasáu",
-    "Search people" : "Buscar persones",
-    "Not found" : "Nun s'atopó",
-    "People" : "Persones",
-    "Filter in current view" : "Peñerar na vista actual",
-    "Search in" : "Buscar en",
-    "Searching …" : "Buscando…",
-    "No matching results" : "Nun hai nengún resultáu que concasare",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Ente'l ${this.dateFilter.startFrom.toLocaleDateString()} y ${this.dateFilter.endAt.toLocaleDateString()}",
+    "More actions" : "Más aiciones",
     "This browser is not supported" : "Esti restolador nun ye compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
     "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
     "Supported versions" : "Versiones compatibles",
     "{name} version {version} and above" : "{name} versión {version} y superior",
-    "Settings menu" : "Menú de configuración",
-    "Avatar of {displayName}" : "Avatar de: {displayName}",
+    "Search {types} …" : "Buscar «{types}»…",
     "Choose {file}" : "Escoyer «{filer}»",
     "Choose" : "Escoyer",
     "Copy to {target}" : "Copiar a {target}",
@@ -229,7 +233,7 @@ OC.L10N.register(
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
     "Add to a project" : "Amestar al proyeutu",
     "Show details" : "Amosar los detalles",
-    "Hide details" : "Anubrir los detalles",
+    "Hide details" : "Esconder los detalles",
     "Rename project" : "Renomar el proyeutu",
     "Failed to rename the project" : "Nun se pue renomar el proyeutu",
     "Failed to create a project" : "Nun se pue crear el proyeutu",
@@ -256,7 +260,6 @@ OC.L10N.register(
     "No tags found" : "Nun s'atopó nenguna etiqueta",
     "Personal" : "Personal",
     "Accounts" : "Cuentes",
-    "Apps" : "Aplicaciones",
     "Admin" : "Alministración",
     "Help" : "Ayuda",
     "Access forbidden" : "Prohíbese l'accesu",
@@ -371,75 +374,24 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "El sirvidor web nun ta configuráu correutamente pa resolver «{url}». Pues atopar más información na {linkstart}documentación ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "El sirvidor web nun se configuró afayadizamente pa resolver «{url}». Ye posible qu'esto tea rellacionao con una configuración del sirvidor que nun s'anovó pa entregar esta carpeta direutamente. Compara'l to ficheru de configuración col forníu, volvi escribir les regles nel ficheru «.htaccess» d'Apache o'l forníu na documentación de Nginx que ta na so {linkstart}páxina de documentación ↗{linkend}. En Nginx, normalmente son les llinies que comiencen per «location ~» son les que precisen un anovamientu.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "El sirvidor web nun ta configuráu afayadizamente pa entregar ficheros .woff2. Esto, polo xeneral, ye un problema cola configuración de Nginx. Pa Nextcloud 15 tamién tienes de facer cambeos pa entregar ficheros .woff2. Compara la configuración de Nginx cola aconseyada na {linkstart}documentación ↗{linkend}",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paez que PHP nun ta configuráu afayadizamente pa solicitar les variables d'entornu del sistema. La prueba con getenv(\"PATH\") namás devuelve una rempuesta balera.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Consulta la {linkstart}documentación d'installación ↗{linkend} pa ver les notes de configuración de PHP  y la configuración de PHP del to sirvidor, especialmente cuando uses php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Activóse la configuración de namás llectura. Esta aición impide que se puedan configurar dalgunes opciones pela interfaz web. Arriendes d'eso, en cada anovamientu ye necesario activar la escritura del ficheru manualmente.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Nun afitesti o verifiquesti la configuración del sirvidor de corréu electrónicu. Vete a la {mailSettingsStart}configuración básica{mailSettingsEnd} p'afitala. Dempués, usa'l botón «Unviar un mensaxe» d'embaxo'l formulariu pa verificar la configuración",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La base de datos nun s'executa col nivel d'aislamientu de transaiciones «READ COMMITTED». Esta transaición pue causar problemes cuando s'executen múltiples aiciones en paralelo.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Falta'l módulu de PHP «fileinfo». Ye mui aconseyable que lu actives pa consiguir los meyores resultaos cola deteición de tipos MIME.",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La direición remota identificóse como «{remoteAddress}» y  nesti momentu ta llendada por fuercia bruta, cosa qu'amenorga'l rendimientu de delles solicitúes. Si la direición remota nun ye la to direición, pue ser un indicador de qu'un proxy nun ta configuráu correutamente. Pues atopar más información na {linkstart}documentación ↗{linkend}.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "El bloquéu de ficheros transaicional ta desactiváu y esto quiciabes produza problemes con condiciones de carrera. Activa «filelocking.enabled» nel ficheru config.php pa evitar estos problemes. Mira la {linkstart}documentación ↗{linkend} pa consiguir más información.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "La base de datos úsase pal bloquéu de ficheros transaicional. P'ameyorar el rindimientu, configura la memoria caché, si ta disponible. Mira la {linkstart}documentación ↗{linkend} pa consiguir más información.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Asegúrate d'afitar la opción «overwrite.cli.url» nel ficheru config.php cola URL que los usuarios usen principalmente p'acceder a esta instancia de Nextcloud.. Suxerencia: «{suggestedOverwriteCliURL}». D'otra miente, pue haber problemes de rindimientu cola xeneración d'URLs per cron. (ye posible que la URL suxerida nun seya la URL que los usuarios usen principalmente p'acceder a esta instancia de Nextcloud. Lo meyor que que lo compruebes dos vegaes.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "La instalación nun tien nenguna rexón telefónica por defeutu configurada. Ye obligatorio pa validar númberos de teléfonu ensin un códigu de país na configuración de los perfiles. Pa permitir los númberos ensin códigu de país, amiesta la opción «default_phone_region» col {linkstart}códigu ISO 3166-1 ↗{linkend} respeutivu de la rexón nel ficheru de configuración.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nun foi posible executar el trabayu de cron per CLI. Apaecieron los errores téunicos siguientes:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "L'últimu trabayu en segundu planu executóse'l {relativeTime}. Hai daqué mal. {linkstart}Comprueba la configuración del trabayu en segundu planu ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Esta versión comunitaria de Nextcloud nun ye compatible. Pola mor del tamañu d'esta instancia nun se puen garantizar el rindimientu, la fiabilidá nin la escalabilidá. Los avisos push tán llendaos pa evitar una sobrecarga del nuesu serviciu gratuitu. Conoz más tocante a los beneficios de Nextcloud Enterprise en {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Esti sirvidor nun tien una conexón a internet que funcione. Nun se pudieron algamar múltiples estremos. Esto significa que dalgunes funciones como'l montase d'almacenamientos esternos, los avisos tocante a anovamientos o la instalación d'aplicaciones de terceros nun van funcionar. L'accesu remotu a los ficheros y l'unviu de mensaxe d'avisu per corréu electrónicu puen nun funcionar tampoco. Afita una conexón d'esti sirvidor a internet pa esfrutar de toles funciones.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nun se configuró nenguna caché de memoria. P'ameyorar el rindimientu, configura una si ta disponible. Pues atopar más información na {linkstart}documentación ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nun atopó nenguna fonte d'azar afayadiza, lo que ye mui desaconseyable por motivos de seguranza. Pues atopar más información na {linkstart}documentación ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Tas executando PHP {version}. Anueva la versión de PHP p'aprovechar los {linkstart}anovamientos de rindimientu y seguranza forníos pol PHP Group ↗{linkend} namás que la to distribución seya compatible.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 ta anticuáu en Nextcloud 27. Nextcloud 28 pue riquir, polo menos, PHP 8.1. Anueva a {linkstart}una de les versiones oficiales compatibles de PHP forníes pol grupu PHP ↗{linkend} namás que puedas.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configuración de la testera del proxy inversu ye incorreuta o tás accediendo a Nextcloud dende un proxy d'enfotu. Si non, esto ye un problema de seguranza y pue permitir qu'un atacador falsie la so direición IP como visible a Nextlcloud. Pues atopar más información na {linkstart}documentación ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached ta configuráu como caché distribuyida mas instalóse'l módulu de PHP «memcache» incorreutu.\n\\OC\\Memcache\\Memcached ye compatible namás con «memcached», non «memcache». Mira la {linkstart}wiki de memcached pa consiguir información tocante a dambos módulos ↗{linkend}.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos fálten-y dalgunos índices. Como amestar índices a tables grandes pue tardar tiempu, nun s'amestaron automáticamente. Pues executar «occ db:add-missing-columns» p'amestar los índices que falten manualmente cola instancia en funcionamientu. Dempués d'amestar los índices, les consultes que se faigan a eses tables van ser, polo xeneral, muncho más rápides.",
-    "Missing primary key on table \"{tableName}\"." : "Falta la clave primaria na tabla «{tableName}»",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos fálten-y dalgunes claves primaries. Pola mor de qu'amestar claves primaries en tables grandes pue tardar tiempu, nun s'amestaron automáticamente. Al executar «occ db:add-missing-primary-keys» eses claves primaries que falten podríen amestase manualmente mentanto la instancia sigue n'execución.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Falta la columna opcional «{columnName}» na tabla «{tableName}».",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos fálten-y columnes opcionales. Como amestar columnes a table grandes pue tardar tiempu y son opcionales, nun s'amestaron automáticamente. Pues executar «occ db:add-missing-columns» p'amestar les columnes que falten manualmente cola instancia en funcionamientu. Dempués d'amestar la columnes, ye posible qu'ameyora'l tiempu de rempuesta o la usabilidá de dalgunes funciones.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "El módulu de PHP «imagick» nun ta activáu magar que l'aplicación d'estilos lo ta. Pa que la xeneración de favíconos funcione correutamente, tienes d'instalar y activar esti módulu.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia execútase nel mou depuración. Activa esta opción namás pa desendolcar y non pa entornos de desendolcu.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet. El ficheru .httaccess nun funciona. Ye mui aconseyable que configures el sirvidor web pa que yá nun se pueda acceder al direutoriu de datos o movi los datos del direutoriu fuera del raigañu de documentos del sirvidor web.",
-    "Account name or email" : "Nome de la cuenta o direición de corréu electrónicu",
+    "Currently open" : "Abierto",
     "Wrong username or password." : "El nome d'usuariu o la contraseña son incorreutos",
     "User disabled" : "L'usuariu ta desactiváu",
+    "Login with username or email" : "Aniciar la sesión col nomatu o la direición de corréu electrónicu",
+    "Login with username" : "Aniciar la sesión col nomatu",
     "Username or email" : "Nome d'usuariu o direición de corréu electrónicu",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta esiste, unvióse un mensaxe pa reaniciar la contraseña a la so direición de corréu electrónicu. Si nun recibes nengún, verifica la direición y/o'l nome de la cuenta, comprueba la carpeta Spam o pidi ayuda a l'alministración.",
-    "Start search" : "Aniciar la busca",
-    "Open settings menu" : "Abrir el menú de configuración",
-    "Settings" : "Configuración",
-    "Avatar of {fullName}" : "Avatar de: {fullName}",
-    "Show all contacts …" : "Amosar tolos contautos…",
-    "No files in here" : "Nun hai nengún ficheru",
-    "New folder" : "Carpeta nueva",
-    "No more subfolders in here" : "Equí nun hai más socarpetes",
-    "Name" : "Nome",
-    "Size" : "Tamañu",
-    "Modified" : "Modificóse",
-    "\"{name}\" is an invalid file name." : "«{name}» ye un nome inválidu.",
-    "File name cannot be empty." : "El nome del ficheru nun pue tar baleru.",
-    "\"/\" is not allowed inside a file name." : "«/» ye un caráuter que nun ta permitíu nel nome del ficheru.",
-    "\"{name}\" is not an allowed filetype" : "«{name}» nun ye un tipu de ficheru permitíu",
-    "{newName} already exists" : "«{newName}» xá esiste",
-    "Error loading file picker template: {error}" : "Hebo un error al cargar la plantía de selector de ficheros: {error}",
+    "Apps and Settings" : "Aplicaciones y configuración",
     "Error loading message template: {error}" : "Hebo un error al cargar la plantía del mensaxe: {error}",
-    "Show list view" : "Amosar la vista en llista",
-    "Show grid view" : "Amosar la vista en rexáu",
-    "Pending" : "Pendiente",
-    "Home" : "Aniciu",
-    "Copy to {folder}" : "Copiar en «{folder}»",
-    "Move to {folder}" : "Mover a «{folder}»",
-    "Authentication required" : "L'autenticación ye obligatoria",
-    "This action requires you to confirm your password" : "Esta aición rique que confirmes la contraseña",
-    "Confirm" : "Confirmar",
-    "Failed to authenticate, try again" : "Nun se pue autenticar, volvi tentalo",
     "Users" : "Usuarios",
     "Username" : "Nome d'usuariu",
     "Database user" : "Usuariu de la base de datos",
+    "This action requires you to confirm your password" : "Esta aición rique que confirmes la contraseña",
     "Confirm your password" : "Comfirmar la contraseña",
+    "Confirm" : "Confirmar",
     "App token" : "Pase de l'aplicación",
     "Alternative log in using app token" : "Aniciu de la sesión alternativu col pase de l'aplicación",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 usuarios.",
-    "Apps and Settings" : "Aplicaciones y configuración"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 usuarios."
 },
 "nplurals=2; plural=(n != 1);");
