@@ -34,6 +34,7 @@ OC.L10N.register(
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknite sljedeću poveznicu kako biste resetirali svoju zaporku. Ako niste podnijeli zahtjev za resetiranje zaporke, zanemarite ovu poruku.",
     "Reset your password" : "Resetirajte svoju zaporku",
     "Internal error" : "Unutarnja pogreška",
+    "Not found" : "Nije pronađeno",
     "Nextcloud Server" : "Nextcloud poslužitelj",
     "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
@@ -77,9 +78,19 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ažuriranje nije uspjelo. Prijavite ovaj problem <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudovoj zajednici</a>.",
     "Continue to {productName}" : "Nastavite do {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekundu.","Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekunde.","Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekundi."],
+    "Apps" : "Aplikacije",
     "More apps" : "Više aplikacija",
     "No" : "Ne",
     "Yes" : "Da",
+    "Create share" : "Stvori dijeljenje",
+    "Failed to add the public link to your Nextcloud" : "Dodavanje javne poveznice u Nextcloud nije uspjelo",
+    "Date" : "Datum",
+    "Last year" : "Prošle godine",
+    "People" : "Ljudi",
+    "Results" : "Rezultati",
+    "Load more results" : "Učitaj više rezultata",
+    "Searching …" : "Traženje…",
+    "Start typing to search" : "Počnite unositi tekst za pretraživanje",
     "Log in" : "Prijava",
     "Logging in …" : "Prijavljivanje...",
     "Server side authentication failed!" : "Autentifikacija na poslužitelju nije uspjela!",
@@ -105,16 +116,17 @@ OC.L10N.register(
     "Recommended apps" : "Preporučene aplikacije",
     "Loading apps …" : "Učitavanje aplikacija…",
     "Could not fetch list of apps from the App Store." : "Dohvaćanje popisa aplikacija iz trgovine aplikacijama nije uspjelo.",
-    "Installing apps …" : "Instaliranje aplikacija…",
     "App download or installation failed" : "Neuspješno preuzimanje ili instalacija aplikacije",
     "Cannot install this app because it is not compatible" : "Aplikaciju nije moguće instalirati jer nije kompatibilna",
     "Cannot install this app" : "Ovu aplikaciju nije moguće instalirati",
     "Skip" : "Preskoči",
+    "Installing apps …" : "Instaliranje aplikacija…",
     "Install recommended apps" : "Instaliraj preporučene aplikacije",
     "Schedule work & meetings, synced with all your devices." : "Zakažite zadatke i sastanke, sinkronizirajte ih sa svim svojim uređajima.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Čuvajte podatke o kolegama i prijateljima na jednom mjestu bez ugrožavanja njihovih osobnih informacija.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednostavna aplikacija za upravljanje e-poštom, integrirana s aplikacijama Files, Contacts i Calendar.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
+    "Settings menu" : "Izbornik postavki",
     "Reset search" : "Resetiraj pretraživanje",
     "Search contacts …" : "Pretraži kontakte...",
     "Could not load your contacts" : "Učitavanje vaših kontakata trenutno nije moguće",
@@ -124,23 +136,15 @@ OC.L10N.register(
     "Loading your contacts …" : "Učitavanje vaših kontakata...",
     "Looking for {term} …" : "Tražim {term}…",
     "Search for {name} only" : "Traži samo {name}",
-    "Start typing to search" : "Počnite unositi tekst za pretraživanje",
     "Loading more results …" : "Učitavanje više rezultata…",
-    "Load more results" : "Učitaj više rezultata",
     "Search" : "Traži",
     "No results for {query}" : "Nema rezultata za {query}",
     "An error occurred while searching for {type}" : "Došlo je do pogreške pri traženju {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje"],
     "Forgot password?" : "Zaboravili ste zaporku?",
     "Back" : "Natrag",
     "Login form is disabled." : "Obrazac za prijavu je onemogućen.",
+    "More actions" : "Dodatne radnje",
     "Search {types} …" : "Traži {types}…",
-    "Date" : "Datum",
-    "Last year" : "Prošle godine",
-    "Not found" : "Nije pronađeno",
-    "People" : "Ljudi",
-    "Searching …" : "Traženje…",
-    "Settings menu" : "Izbornik postavki",
     "Choose" : "Odaberite",
     "Copy" : "Kopiraj",
     "Move" : "Premjesti",
@@ -188,7 +192,6 @@ OC.L10N.register(
     "No tags found" : "Nema pronađenih oznaka",
     "Personal" : "Osobno",
     "Accounts" : "Korisnićki računi",
-    "Apps" : "Aplikacije",
     "Admin" : "Administrator",
     "Help" : "Pomoć",
     "Access forbidden" : "Pristup zabranjen",
@@ -289,37 +292,6 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaš mrežni poslužitelj ne može razriješiti „{url}”. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Vaš web poslužitelj nije ispravno postavljen za razrješavanje „{url}”. To je najvjerojatnije uzrokovano konfiguracijom web-poslužitelja koja nije ažurirana i ne isporučuje izravno mapu. Usporedite svoju konfiguraciju s isporučenim pravilima za prepisivanje u „.htaccess” za Apache ili u dokumentaciji za Nginx na {linkstart}stranici s dokumentacijom ↗{linkend}. Na Nginxu su to obično linije koje počinju s „location ~” i potrebno ih je ažurirati.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Vaš web poslužitelj nije ispravno postavljen za isporuku .woff2 datoteka. To je obično problem s konfiguracijom Nginxa. Nextcloud 15 zahtijeva podešavanje za isporuku .woff2 datoteka. Usporedite svoju Nginx konfiguraciju s preporučenom konfiguracijom u našoj {linkstart}dokumentaciji ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Čini se da PHP nije ispravno postavljen za slanje upita u vezi s varijablama okruženja sustava. Ispitivanje s getenv („PATH”) vraća samo prazan odgovor.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Provjerite {linkstart}instalacijsku dokumentaciju ↗{linkend} za napomene o konfiguraciji PHP-a i konfiguraciju PHP-a na svojem poslužitelju, posebice ako upotrebljavate php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša se baza podataka ne pokreće s razinom izolacije transakcije „READ COMMITTED”. To može uzrokovati probleme kada se paralelno izvršava više radnji.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Nedostaje PHP modul „fileinfo”. Preporučujemo da omogućite ovaj modul kako biste postigli najbolje rezultate s detekcijom vrste MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Onemogućeno je zaključavanje transakcijskih datoteka što može dovesti do problema s uvjetima utrke. Omogućite „filelocking.enabled” u datoteci config.php kako biste izbjegli navedene probleme. Pogledajte {linkstart}dokumentaciju ↗{linkend} za više informacija.",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Nije postavljena zadana regija telefonskih brojeva za vašu instalaciju. Potrebna je radi provjeravanja valjanosti telefonskih brojeva u postavkama profila bez pozivnog broja države. Kako biste omogućili korištenje brojeva bez pozivnog broja države dodajte „default_phone_region” s odgovarajućom {linkstart}ISO 3166-1 šifrom ↗{linkend} regije u svoju konfiguracijsku datoteku.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nije bilo moguće izvršiti cron zadatak putem sučelja komandne linije. Došlo je do sljedećih tehničkih pogrešaka:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Zadnje izvršenje zadatka u pozadini trajalo je {relativeTime}. Nešto nije u redu. {linkstart}Provjerite postavke za pozadinske zadatke ↗{linkend}.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nije konfigurirana nikakva predmemorija. Kako biste poboljšali performanse sustava, konfigurirajte predmemoriju ako je dostupna. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nije pronašao nikakav izvor nasumičnosti što nije povoljno iz sigurnosnog gledišta. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Trenutno upotrebljavate PHP {version}. Nadogradite inačicu PHP-a kako biste iskoristili {linkstart}ažuriranja performansi i sigurnosti koje isporučuje PHP Grupa ↗{linkend} čim vam vaša distribucija to omogući.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfiguracija obrnutog proxy zaglavlja je netočna ili pristupate Nextcloudu putem pouzdanog proxy poslužitelja. Ako to nije slučaj, radi se o sigurnosnom problemu koji može omogućiti napadaču da lažno predstavi svoju IP adresu koja je vidljiva Nextcloudu. Dodatne informacije možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached je konfiguriran kao distribuirana predmemorija, ali je instaliran pogrešan PHP modul „memcache”. \\OC\\Memcache\\Memcached podržava samo „memcached”, a ne „memcache”. Pogledajte {linkstart}memcached wiki za informacije o oba modula ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Neke datoteke nisu prošle provjeru cjelovitosti. Dodatne informacije o tome kako riješiti taj problem možete pronaći u {linkstart1}dokumentaciji ↗{linkend}. ({linkstart2}Popis nevažećih datoteka…{linkend} / {linkstart3}Ponovno skeniranje…{linkend})",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP-a „set_time_limit” nije dostupna. To bi moglo dovesti do zaustavljanja skripti tijekom izvršenja i prekida instalacije. Preporučuje se uključivanje ove funkcije.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaš PHP nema podršku za FreeType što može uzrokovati neispravan prikaz profilnih slika i sučelja postavki.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Nedostaje indeks „{indexName}” u tablici „{tableName}”.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
-    "Missing primary key on table \"{tableName}\"." : "Nedostaje primarni ključ u tablici „{tableName}”.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "U bazi podataka nedostaju određeni primarni ključevi. Zbog činjenice da bi dodavanje primarnih ključeva moglo potrajati neko duže vrijeme u velikim tablicama, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-primary-keys” ti se primarni ključevi mogu ručno dodati dok instanca radi.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Nedostaje neobavezan stupac „{columnName}” u tablici „{tableName}”.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "U bazi podataka nedostaju određeni neobavezni stupci. Zbog činjenice da bi dodavanje stupaca u velikim tablicama moglo potrajati neko duže vrijeme, stupci se ne dodaju automatski, već je njihovo dodavanje neobavezno. Izvršenjem „occ db:add-missing-columns” ti se stupci mogu ručno dodati dok instanca radi. Nakon dodavanja stupaca može se poboljšati odaziv ili uporabljivost određenih značajki.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "U ovoj instanci nedostaju neki preporučeni moduli PHP-a. Preporučujemo da ih instalirate kako biste poboljšali performanse i ostvarili bolju kompatibilnost.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nema podršku za SVG u ovoj instanci. Preporučuje se da ga instalirate kako biste osigurali bolju kompatibilnost.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite se trenutno upotrebljava kao pozadinska baza podataka. Za veće instalacije preporučujemo da se prebacite na neku drugu pozadinsku bazu podataka.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "To se osobito preporučuje ako upotrebljavate klijent za sinkronizaciju datoteka.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Ograničenje memorije PHP-a ispod je preporučene vrijednosti od 512 MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Određeni direktoriji aplikacija vlasništvo su korisnika koji nije vlasnik web poslužitelja. To se može dogoditi ako su aplikacije ručno instalirane. Provjerite dopuštenja za sljedeće direktorije aplikacija:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL se koristi kao aktivna baza podataka, ali ne podržava 4-bajtne znakove. Kako biste se mogli koristiti 4-bajtnim znakovima (primjerice, smajlići) bez problema u nazivima datoteka ili komentarima, preporučuje se da omogućite 4-bajtnu podršku u MySQL-u. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje u dokumentaciji ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ova instanca upotrebljava pohranu objekta temeljenu na S3 kao primarnu pohranu. Otpremljene datoteke privremeno se pohranjuju na poslužitelju i stoga je preporučljivo osigurati 50 GB slobodnog prostora u privremenom direktoriju PHP-a. Više informacija o putovima i dostupnom prostoru potražite u zapisima poslužitelja. Ako želite osloboditi više prostora, promijenite privremeni direktorij u datoteci php.ini ili oslobodite prostor na tom putu.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Instanci pristupate putem sigurne veze, ali instanca generira nesigurne URL-ove. To najvjerojatnije znači da se nalazite iza obrnutog proxyja i nisu točno postavljene varijable za izmjenu konfiguracijske datoteke. Pročitajte {linkstart}odgovarajuću dokumentaciju ↗{linkend}.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. Neke značajke možda neće ispravno raditi pa preporučujemo da prilagodite ovu postavku.",
@@ -328,33 +300,13 @@ OC.L10N.register(
     "Wrong username or password." : "Pogrešno korisničko ime ili zaporka.",
     "User disabled" : "Korisnik je onemogućen",
     "Username or email" : "Korisničko ime ili adresa e-pošte",
-    "Settings" : "Postavke",
-    "Show all contacts …" : "Prikaži sve kontakte...",
-    "No files in here" : "Nema datoteka",
-    "New folder" : "Nova mapa",
-    "No more subfolders in here" : "Ovdje više nema podmapa",
-    "Name" : "Naziv",
-    "Size" : "Veličina",
-    "Modified" : "Promijenjeno",
-    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
-    "File name cannot be empty." : "Naziv datoteke ne može biti prazan.",
-    "\"/\" is not allowed inside a file name." : "„/” nije dopušteno unutar naziva datoteke.",
-    "\"{name}\" is not an allowed filetype" : "„{name}” nije dopuštena vrsta datoteke",
-    "{newName} already exists" : "{newName} već postoji",
-    "Error loading file picker template: {error}" : "Pogrešno učitavanje predloška za pronalazača datoteke: {error}",
     "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}",
-    "Pending" : "Na čekanju",
-    "Home" : "Početna",
-    "Copy to {folder}" : "Kopiraj u {folder}",
-    "Move to {folder}" : "Premjesti u {folder}",
-    "Authentication required" : "Potrebna autentifikacija",
-    "This action requires you to confirm your password" : "Za izvršavanje ove radnje potvrdite svoju zaporku",
-    "Confirm" : "Potvrdi",
-    "Failed to authenticate, try again" : "Pogreška pri provjeri autentičnosti, pokušajte ponovo",
     "Users" : "Korisnici",
     "Username" : "Korisničko ime",
     "Database user" : "Korisnik baze podataka",
+    "This action requires you to confirm your password" : "Za izvršavanje ove radnje potvrdite svoju zaporku",
     "Confirm your password" : "Potvrdite svoju zaporku",
+    "Confirm" : "Potvrdi",
     "App token" : "Aplikacijski token",
     "Alternative log in using app token" : "Alternativna prijava s pomoću aplikacijskog tokena",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Ažurirajte putem naredbenog retka jer imate veliku instancu s više od 50 korisnika."
