@@ -39,10 +39,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "아래 단추를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "아래 링크를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
     "Reset your password" : "내 암호 재설정",
-    "Requested task type does not exist" : "요청한 작업 타입이 존재하지 않음",
-    "Necessary language model provider is not available" : "필요한 언어 모델 제공자를 사용할 수 없습니다",
+    "The given provider is not available" : "주어진 공급자가 사용 가능하지 않습니다.",
     "Task not found" : "작업을 찾을 수 없습니다",
     "Internal error" : "내부 오류",
+    "Not found" : "찾을 수 없음",
+    "Bad request" : "잘못된 요청",
+    "Requested task type does not exist" : "요청한 작업 타입이 존재하지 않음",
+    "Necessary language model provider is not available" : "필요한 언어 모델 제공자를 사용할 수 없습니다",
     "No text to image provider is available" : "사용할 수 있는 text to image 제공자가 없습니다.",
     "Image not found" : "이미지를 찾지 못함",
     "No translation provider available" : "이용 가능한 번역 제공자 없음",
@@ -95,15 +98,39 @@ OC.L10N.register(
     "Continue to {productName}" : "{productName}으로 계속하기",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["업데이트가 성공했습니다. %n초 후 {productName}(으)로 이동합니다."],
     "Applications menu" : "애플리케이션 메뉴",
+    "Apps" : "앱",
     "More apps" : "더 많은 앱",
-    "Currently open" : "현재 열려있음",
     "_{count} notification_::_{count} notifications_" : ["{count}개의 알림"],
     "No" : "아니요",
     "Yes" : "예",
+    "Create share" : "공유 만들기",
+    "Failed to add the public link to your Nextcloud" : "Nextcloud에 공개 링크를 추가할 수 없음",
     "Custom date range" : "맞춤 날짜 범위",
     "Pick start date" : "시작일 선택",
     "Pick end date" : "종료일 선택",
     "Search in date range" : "날짜 범위로 검색",
+    "Search in current app" : "현재 앱에서 찾기",
+    "Clear search" : "찾기 초기화",
+    "Search everywhere" : "모든 곳에서 찾기",
+    "Unified search" : "통합검색",
+    "Search apps, files, tags, messages" : "앱 및 파일, 태그, 메시지 검색",
+    "Places" : "장소",
+    "Date" : "날짜",
+    "Today" : "오늘",
+    "Last 7 days" : "지난 7일",
+    "Last 30 days" : "지난 30일",
+    "This year" : "올해",
+    "Last year" : "작년",
+    "Search people" : "사람 검색",
+    "People" : "사람들",
+    "Filter in current view" : "현재 화면을 필터",
+    "Results" : "결과들",
+    "Load more results" : "더 많은 결과 불러오기",
+    "Search in" : "다음에서 검색",
+    "Searching …" : "검색 중...",
+    "Start typing to search" : "검색어 입력",
+    "No matching results" : "일치하는 결과 없음",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()}(과)와 ${this.dateFilter.endAt.toLocaleDateString()} 사이",
     "Log in" : "로그인",
     "Logging in …" : "로그인 중 …",
     "Server side authentication failed!" : "서버 인증 실패!",
@@ -117,8 +144,8 @@ OC.L10N.register(
     "Wrong login or password." : "로그인 또는 암호가 잘못되었습니다.",
     "This account is disabled" : "이 계정은 비활성화 되었습니다.",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "사용 중인 IP에서 여러 번의 잘못된 로그인 시도를 감지했습니다. 30초 후에 다시 로그인할 수 있습니다.",
-    "Login with username or email" : "아이디 또는 이메일로 로그인",
-    "Login with username" : "아이디로 로그인",
+    "Account name or email" : "아이디 또는 이메일",
+    "Account name" : "계정 아이디",
     "Log in with a device" : "기기로 로그인",
     "Login or email" : "로그인 또는 이메일",
     "Your account is not setup for passwordless login." : "당신의 계정은 암호 없이 로그인하도록 설정되지 않았습니다.",
@@ -138,11 +165,11 @@ OC.L10N.register(
     "Recommended apps" : "추천되는 앱",
     "Loading apps …" : "앱 로딩중 ...",
     "Could not fetch list of apps from the App Store." : "앱스토어로부터 앱 목록을 가져올 수 없음",
-    "Installing apps …" : "앱 설치중...",
     "App download or installation failed" : "앱 다운로드 또는 설치에 실패함",
     "Cannot install this app because it is not compatible" : "호환되지 않아 앱을 설치할 수 없습니다.",
     "Cannot install this app" : "앱을 설치할 수 없음",
     "Skip" : "건너뛰기",
+    "Installing apps …" : "앱 설치중...",
     "Install recommended apps" : "추천 앱 설치",
     "Schedule work & meetings, synced with all your devices." : "업우와 회의 일정을 짜고, 당신의 모든 기기와 동기화하세요.",
     "Keep your colleagues and friends in one place without leaking their private info." : "개인정보 누출 없이 동료와 친구들을 한 곳으로 모아두세요.",
@@ -150,6 +177,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "당신의 브라우저와 모바일 앱 속의  채팅, 영상 통화, 화면 공유, 온라인 미팅 그리고 웹 회의",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online에 기반한 협업 문서, 스프레드시트와 프레젠테이션",
     "Distraction free note taking app." : "방해 없는 무료 메모 작성 앱.",
+    "Settings menu" : "설정 메뉴",
+    "Avatar of {displayName}" : "{displayName}의 아바타",
     "Search contacts" : "연락처 검색",
     "Reset search" : "검색 초기화",
     "Search contacts …" : "연락처 검색…",
@@ -161,14 +190,11 @@ OC.L10N.register(
     "Looking for {term} …" : "{term} 검색 중 …",
     "Search starts once you start typing and results may be reached with the arrow keys" : "입력을 시작하면 검색이 시작되며, 방향키를 통해 결과로 이동할 수 있습니다.",
     "Search for {name} only" : "{name}(으)로만 검색",
-    "Start typing to search" : "검색어 입력",
     "Loading more results …" : "더 많은 결과 불러오는 중...",
-    "Load more results" : "더 많은 결과 불러오기",
     "Search" : "검색",
     "No results for {query}" : "{query}에 대한 결과가 없음",
     "Press Enter to start searching" : "검색을 시작하려면 엔터를 누르세요.",
     "An error occurred while searching for {type}" : "{type} 탐색중 오류 발생",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["{minSearchLength}개 이상의 글자를 입력해 검색해 주세요."],
     "Forgot password?" : "암호를 잊으셨습니까?",
     "Back to login form" : "로그인으로 돌아가기",
     "Back" : "뒤로",
@@ -179,31 +205,13 @@ OC.L10N.register(
     "You have not added any info yet" : "아직 아무 정보도 추가하지 않았습니다.",
     "{user} has not added any info yet" : "{user}님이 아직 아무 정보도 추가하지 않음",
     "Error opening the user status modal, try hard refreshing the page" : "사용자 상태 모달을 불러오는 데 실패했습니다, 페이지를 완전히 새로고침 해 보십시오.",
-    "Unified search" : "통합검색",
-    "Search apps, files, tags, messages" : "앱 및 파일, 태그, 메시지 검색",
-    "Search {types} …" : "{types} 검색 ...",
-    "Places" : "장소",
-    "Date" : "날짜",
-    "Today" : "오늘",
-    "Last 7 days" : "지난 7일",
-    "Last 30 days" : "지난 30일",
-    "This year" : "올해",
-    "Last year" : "작년",
-    "Search people" : "사람 검색",
-    "Not found" : "찾을 수 없음",
-    "People" : "사람들",
-    "Filter in current view" : "현재 화면을 필터",
-    "Search in" : "다음에서 검색",
-    "Searching …" : "검색 중...",
-    "No matching results" : "일치하는 결과 없음",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()}(과)와 ${this.dateFilter.endAt.toLocaleDateString()} 사이",
+    "More actions" : "더 많은 동작",
     "This browser is not supported" : "이 브라우저는 지원되지 않습니다.",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "이 브라우저는 지원되지 않습니다. 새로운 버전 및 지원되는 브라우저로 업그레이드 하세요.",
     "Continue with this unsupported browser" : "지원되지 않는 브라우저로 계속 사용하기",
     "Supported versions" : "지원되는 버전",
     "{name} version {version} and above" : "{name}의 {version} 버전 이상",
-    "Settings menu" : "설정 메뉴",
-    "Avatar of {displayName}" : "{displayName}의 아바타",
+    "Search {types} …" : "{types} 검색 ...",
     "Choose {file}" : "{file} 선택",
     "Choose" : "선택",
     "Copy to {target}" : "{target}에 복사",
@@ -256,7 +264,6 @@ OC.L10N.register(
     "No tags found" : "태그를 찾을 수 없음",
     "Personal" : "개인",
     "Accounts" : "계정",
-    "Apps" : "앱",
     "Admin" : "관리자",
     "Help" : "도움말",
     "Access forbidden" : "접근 금지됨",
@@ -273,6 +280,7 @@ OC.L10N.register(
     "The server was unable to complete your request." : "서버에서 요청을 처리할 수 없습니다.",
     "If this happens again, please send the technical details below to the server administrator." : "만약 이 오류가 다시 발생하면 서버 관리자에게 다음 기술 정보를 알려 주십시오.",
     "More details can be found in the server log." : "서버 로그에서 자세한 정보를 찾을 수 있습니다.",
+    "For more details see the documentation ↗." : "좀 더 자세한 사항은 문서를 참고하세요↗.",
     "Technical details" : "기술 정보",
     "Remote Address: %s" : "원격 주소: %s",
     "Request ID: %s" : "요청 ID: %s",
@@ -371,53 +379,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "웹 서버에서 \"{url}\"을(를) 올바르게 처리할 수 없습니다. 더 많은 정보를 보려면  {linkstart}문서 ↗{linkend}를 참고하십시오.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "이 웹 서버는 “{url}”을(를) 처리하기 위해 적절히 설정되지 않았습니다. 이는 대부분 웹 서버 설정값이 이 폴더를 직접 전달하도록 설정되지 않은 상황입니다. 서버가 Apache일 경우, 서버의 설정값과 “‘htaccess”의 재작성 규칙을 대조해보십시오. Nginx 서버의 경우, 제공되는 {linkstart}문서 페이지 ↗{linkend}를 참조하십시오. Nginx에서는 보통 “location ~”으로 시작하는 부분이 이 문제와 관련이 있으며, 수정과 갱신이 필요합니다.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "이 웹 서버는 .woff2 파일을 전달하기에 적절히 설정되지 않았습니다. 이는 대부분 Nginx 설정과 관련있습니다. Nextcloud 15에서는 .woff2 파일을 전달하기 위해 설정을 수정해야 합니다. 이 서버의 Nginx 설정과 저희가 제공하는 권장 설정 {linkstart}문서 ↗{linkend}를 비교하십시오.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP에서 시스템 환경 변수를 올바르게 조회할 수 없는 것 같습니다. getenv(\"PATH\") 시험 결과 빈 값이 반환되었습니다.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "PHP 설정과 관련된 {linkstart}문서 ↗{linkend}를 참조하시어 이 서버의 PHP 설정을 확인하십시오. 특히 php-fpm을 사용할 경우 관련성이 높습니다.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "이메일 서버 설정이 입력되지 않았거나 검증되지 않았습니다. {mailSettingsStart}기본 설정{mailSettingsEnd}으로 이동해 설정을 완료하십시오. 서버 정보를 입력한 후 양식 아래 “이메일 발송” 버튼을 눌러 설정을 검증하십시오.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "데이터베이스가 \"READ COMMITTED\" 트랜잭션 격리 수준에서 실행되고 있지 않습니다. 여러 작업이 동시에 실행될 때 문제가 발생할 수 있습니다.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP의 \"fileinfo\" 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "당신의 원격지 주소는 \"{remoteAddress}\"(으)로 식별되며, 현재 무차별 대입 공격 방어를 위해 여러 요청의 성능을 저하시켰습니다. 위 원격지 주소가 당신의 주소가 아니라면, 프록시 설정이 제대로 되지 않았음을 나타냅니다. 자세한 내용은 {linkstart}문서 ↗{linkend}를 참조하십시오.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 해결할 수 있습니다. 자세한 내용은 {linkstart} 사용 설명서 ↗{linkend}를 참고하십시오.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "데이터베이스는 트랜잭션 파일 잠금에 사용됩니다. 성능을 향상하려면 가능한 경우 memcache를 구성하세요. 자세한 내용은 {linkstart} 문서 ↗{linkend} 를 참조하세요.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "주로 사용할 URL이 config.php 파일의 \"overwrite.cli.url\" 옵션에 올바르게 설정되어 있는지 확인하십시오. 제안: \"{suggestedOverwriteCliURL}\". 설정이 잘못되었을 경우 cron을 통한 URL 생성에 문제가 생길 수 있습니다. (제안된 URL이 이 Nextcloud에 접근하는 주된 URL이 아닐 수 있습니다. 따라서, 해당 사항을 직접 재확인하는 것이 좋습니다.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "당신의 설치에서 기본 국가 번호가 설정되지 않았습니다. 프로필 설정에서 국가 번호 없이 전화번호를 사용하기 위해서 이 설정이 필요합니다. 국가 번호 없이 전화번호를 사용하게 하려면, 지역의 {linkstart}ISO 3166-1 코드↗{linkend}를 참조하여 설정 파일에 \"default_phone_region\"을 추가하십시오.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI로 cron 작업을 실행시킬 수 없었습니다. 다음 오류가 발생했습니다:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "마지막 백그라운드 작업이 {relativeTime}에 수행되었습니다. 무엇인가 잘못된 것 같습니다. {linkstart}백그라운드 작업 설정을 확인하십시오 ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "이 빌드는 공식적으로 지원하지 않는 Nextcloud 커뮤니티 빌드입니다. 이 인스턴스의 크기를 고려하면, 성능과 신뢰성, 확장성 등을 보장할 수 없습니다. 무료 서비스의 과부하를 방지하기 위해 푸시 알림은 제한됩니다. Nextcloud Enterprise의 혜택에 대해서는 {linkstart}https://nextcloud.com/enterprise{linkend}를 참조하십시오.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "서버가 인터넷에 연결되지 않아 다수의 종단점에 도달할 수 없습니다. 이로 인해 외부 저장소 마운트, 서드파티 앱 업데이트와 설치에 대한 알림 수신 등의 기능을 사용할 수 없을 것입니다. 원격 파일 접근과 알림 이메일 전송 또한 작동하지 않을 것입니다. 서버를 인터넷과 연결하여 모든 기능을 사용하십시오.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "매모리 캐시가 설정되지 않았습니다. 성능 향상을 위해 가능하면 memcache를 설정하십시오. 더 많은 정보는 {linkstart}문서 ↗{linkend}를 참조하십시오.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP가 안전한 난수 발생기를 사용할 수 없어 보안에 취약합니다. 자세한 내용은 {linkstart}문서 ↗{linkend}.를 참고하십시오.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "현재 PHP {version}(으)로 실행중입니다. PHP 버전을 업그레이드 하여 지원중인 {linkstart} PHP 그룹의 성능 및 보안 업데이트 ↗{linkend} 혜택을 누리십시오.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Nextcloud 27에서 PHP 8.0 지원이 중단되었습니다. Nextcloud 28은 PHP 8.1 이상이 필요합니다.  {linkstart}공식 지원되는 버전의 PHP{linkend}로 업그레이드 하십시오.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "역방향 프록시 헤더 설정이 올바르지 않거나 신뢰하는 프록시를 통해 Nextcloud에 접근하고 있을 수 있습니다. 만약 Nextcloud를 신뢰하는 프록시를 통해 접근하고 있지 않다면 이는 보안 문제이며 공격자가 Nextcloud에 보이는 IP 주소를 속이고 있을 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 \"memcache\"가 설치되어 있습니다. \\OC\\Memcache\\Memcached는 \"memcached\"만 지원하고 \"memcache\"는 지원하지 않습니다. {linkstart}두 모듈에 대한 memcached 위키 ↗{linkend}.를 참조하세요.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "일부 파일이 무결성 검사를 통과하지 못했습니다. 이 문제를 해결하는 방법에 대한 자세한 내용은 {linkstart1}문서 ↗{linkend}에서 확인할 수 있습니다. ({linkstart2}잘못된 파일 목록...{linkend} / {linkstart3}재검사...{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP의 OPcache 모듈이 올바르게 설정되지 않았습니다. 추가적인 정보가 필요할 경우 {linkstart}문서 ↗{linkend}를 참조하십시오.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 함수 \"set_time_limit\"을 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP에 Freetype 지원이 없습니다. 프로필 사진과 설정 인터페이스가 올바르게 표시되지 않을 수도 있습니다.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "테이블 \"{tableName}\"에 인덱스 \"{indexName}\"이(가) 없습니다.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
-    "Missing primary key on table \"{tableName}\"." : "\"{tableName}\" 테이블에 Primary key가 없습니다.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "데이터베이스에 일부 기본 키가 누락되었습니다. 큰 테이블에 기본 키를 추가하는 데 시간이 걸릴 수 있기 때문에 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-primary-keys\"를 실행하면 인스턴스가 계속 실행되는 동안 누락된 기본 키를 수동으로 추가할 수 있습니다.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "테이블 \"{tableName}\"에서 \"{columnName}\" 컬럼이 빠졌습니다.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "데이터베이스에 일부 선택적 열이 누락되었습니다. 큰 테이블에 열을 추가하는 데 시간이 걸릴 수 있기 때문에 선택 사항일 수 있는 열이 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-columns\"를 실행하면 누락된 열을 인스턴스를 실행되는 동안 수동으로 추가할 수 있습니다. 열이 추가되면 일부 기능의 응답성이나 사용성이 향상될 수 있습니다.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "이 인스턴스에 권장 PHP 모듈 중 일부가 존재하지 않습니다. 성능 향상과 호환성을 위하여 해당 PHP 모듈을 설치하는 것을 추천합니다.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "테마 앱이 활성화되었으나, PHP 모듈 “imagick”이 활성화되지 않았습니다. 파비콘 생성을 위해 해당 모듈을 설치하고 활성화하십시오.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP 모듈 “gmp” 혹은 “bcmath”가 활성화되지 않았습니다. WebAuthn 무암호 인증을 사용할 경우, 해당 모듈이 모두 필요합니다.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "32비트 PHP 버전을 사용중인 것 같습니다. Nextcloud가 잘 작동하려면 64비트 버전이 필요합니다. OS와 PHP를 64비트로 업그레이드 하시기 바랍니다! 자세한 설명은 {linkstart}이에 대한 문서 페이지 ↗{linkend}를 참고하세요.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "이 인스턴스의 모듈 php-imagick에 SVG 지원이 없습니다. 더 나은 호환성을 위해 설치를 권장합니다.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "일부 데이터베이스 열이 big int로 변환되지 않았습니다. 큰 테이블의 열 형식을 변환하는 데 시간이 걸리기 때문에 자동으로 변환하지 않았습니다. 명령행에서 \"occ db:convert-filecache-bigint\" 명령을 실행하여 변경 사항을 직접 적용할 수 있습니다. 이 작업은 인스턴스를 오프라인으로 전환하고 실행해야 합니다. 더 많은 정보를 보려면 {linkstart}이에 관한 문서 페이지 ↗{linkend} 를 참조하십시오.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "현재 백엔드 데이터베이스로 SQLite를 사용하고 있습니다. 대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드로 전환할 것을 권장합니다.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정인 경우 권장됩니다.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "다른 데이터베이스를 통합하기 위해서 커맨드라인 도구 “occ db:convert-type”을 사용하십시오. 더 자세한 정보는 {linkstart}문서에 있습니다 ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP 메모리 제한이 추천값인 512MB보다 작습니다.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "일부 앱 디렉터리를 웹 서버 사용자와 다른 사용자가 소유하고 있습니다. 수동으로 앱을 설치한 경우에 발생할 수 있습니다. 다음 앱 디렉터리의 사용 권한을 확인하십시오:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL이 데이터베이스로 사용되고 있으나 4바이트 문자를 지원하지 않고 있습니다. 파일 이름이나 댓글 등에 Emoji와 같은 4바이트 문자를 문제 없이 사용하기 위해, MySQL에서 4바이트 문자 지원을 활성화하길 권장합니다. 더 구체적인 정보는 {linkstart}관련 문서를 참조하십시오↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "이 인스턴스에서 S3 기반 객체 저장소를 주 저장소로 사용하고 있습니다. 업로드한 파일을 서버에 임시로 저장하기 때문에 PHP 임시 디렉터리에 최소 50 GB의 빈 공간을 두는 것을 추천합니다. 전체 경로와 사용 가능한 정보를 보려면 로그를 참조하십시오. 성능을 개선하려면 php.ini의 임시 디렉터리를 변경하거나, 해당 위치에서 사용할 수 있는 공간을 더 많이 할당하십시오.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "이 인스턴스의 임시 디렉토리가 존재하지 않거나 쓰기 불가능한 디렉토리를 가르키고 있습니다.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "당신의 인스턴스는 안전한 연결상에서 동작하고 있지만, 인스턴스는 안전하지 않은 URL입니다. 대부분의 경우 리버스 프록시 뒤에 있거나 설정 변수가 제대로 설정 되지 않기 때문입니다. 다음 {linkstart}문서를 읽어 주세요 ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "이 인스턴스는 디버그 모드에서 작동 중입니다. 프로덕션 환경이 아닌 로컬 개발을 위해서만 활성화 하세요.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "현재 인터넷을 통해 누구나 당신의 데이터 디렉토리에 직접 접근할 수도 있습니다. .hraccess 파일이 동작하지 않고 있습니다. 웹 서버를 설정하여 데이터 디렉토리에 직접 접근할 수 없도록 하거나, 웹 서버 루트 밖으로 데이터 디렉토리를 이전하십시오.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"(으)로 설정되어 있지 않습니다. 잠재적인 정보 유출 및 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"(으)로 설정되어 있지 않습니다. 일부 기능이 올바르게 작동하지 않을 수 있으므로 설정을 변경하는 것을 추천합니다.",
@@ -425,46 +387,23 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "\"{header}\" HTTP 헤더가 \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" 또는 \"{val5}\"(으)로 설정되어 있지 않습니다. referer 정보가 유출될 수 있습니다. 자세한 사항은 {linkstart}W3C 권장사항 ↗{linkend} 을 참조하십시오.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP 헤더가 \"{seconds}\"초 이상으로 설정되어 있지 않습니다. {linkstart}보안 팁 ↗{linkend}에서 제안하는 것처럼 HSTS를 활성화하는 것을 추천합니다.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "HTTP를 통해 사이트에 안전하지 않게 액세스하고 있습니다. {linkstart}보안 팁 ↗{linkend}에 설명된 대로  HTTPS를 필수적으로 사용하도록 서버를 설정할 것을 강력히 권장합니다. 그렇지 않으면 \"클립보드에 복사\" 또는 \"서비스 워커\"와 같은 중요한 웹 기능이 작동하지 않습니다!",
-    "Account name or email" : "아이디 또는 이메일",
+    "Currently open" : "현재 열려있음",
     "Wrong username or password." : "ID나 암호가 잘못되었습니다.",
     "User disabled" : "사용자 비활성화됨",
+    "Login with username or email" : "아이디 또는 이메일로 로그인",
+    "Login with username" : "아이디로 로그인",
     "Username or email" : "사용자 이름 또는 이메일",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "계정이 존재한다면, 암호 초기화 메시지가 해당 계정의 이메일 주소로 전송됩니다. 만일 메일을 수신하지 못했다면, 이메일 주소 및 계정 ID를 확인하고 스팸 메일 폴더를 확인하십시오. 또는, 가까운 관리자에게 도움을 요청하십시오.",
-    "Start search" : "검색 시작",
-    "Open settings menu" : "설정 메뉴 열기",
-    "Settings" : "설정",
-    "Avatar of {fullName}" : "{fullName}의 아바타",
-    "Show all contacts …" : "모든 연락처 보기 …",
-    "No files in here" : "여기에 파일이 없음",
-    "New folder" : "새 폴더",
-    "No more subfolders in here" : "더 이상의 하위 폴더 없음",
-    "Name" : "이름",
-    "Size" : "크기",
-    "Modified" : "수정한 날짜",
-    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
-    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
-    "\"/\" is not allowed inside a file name." : "파일 이름에 \"/\"를 사용할 수 없습니다.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\"은(는) 허용된 파일 형식이 아님",
-    "{newName} already exists" : "{newName}이(가) 이미 존재함",
-    "Error loading file picker template: {error}" : "파일 선택 템플릿을 불러오는 중 오류 발생: {error}",
+    "Apps and Settings" : "앱과 설정",
     "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
-    "Show list view" : "리스트 보기",
-    "Show grid view" : "바둑판식 보기",
-    "Pending" : "보류 중",
-    "Home" : "홈",
-    "Copy to {folder}" : "{folder}에 복사",
-    "Move to {folder}" : "{folder}(으)로 이동",
-    "Authentication required" : "인증 필요",
-    "This action requires you to confirm your password" : "이 작업을 수행하려면 암호를 입력해야 합니다",
-    "Confirm" : "확인",
-    "Failed to authenticate, try again" : "인증할 수 없습니다. 다시 시도하십시오.",
     "Users" : "사용자",
     "Username" : "사용자 이름",
     "Database user" : "데이터베이스 사용자",
+    "This action requires you to confirm your password" : "이 작업을 수행하려면 암호를 입력해야 합니다",
     "Confirm your password" : "암호 확인",
+    "Confirm" : "확인",
     "App token" : "앱 토큰",
     "Alternative log in using app token" : "앱 토큰으로 대체 로그인",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "현재 인스턴스에 50명 이상의 사용자가 있기 때문에 명령행 업데이터를 사용하십시오.",
-    "Apps and Settings" : "앱과 설정"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "현재 인스턴스에 50명 이상의 사용자가 있기 때문에 명령행 업데이터를 사용하십시오."
 },
 "nplurals=1; plural=0;");
