@@ -1,16 +1,21 @@
 OC.L10N.register(
     "core",
     {
-    "Please select a file." : "Lūdzu izvēlies datni.",
-    "File is too big" : "Datne ir par lielu",
+    "Please select a file." : "Lūgums atlasīt datni.",
+    "File is too big" : "Datne pārāk liela",
     "The selected file is not an image." : "Atlasītā datne nav attēls.",
     "The selected file cannot be read." : "Atlasīto datni nevar nolasīt.",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
+    "The file was uploaded" : "Datne tika augšupielādēta",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE vērtību, kas tika norādīta HTML formā",
+    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
     "No file was uploaded" : "Neviena datne netika augšupielādēta",
     "Missing a temporary folder" : "Trūkst pagaidu mapes",
+    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
+    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
     "Invalid file provided" : "Norādīta nederīga datne",
     "No image or file provided" : "Nav norādīts attēls vai datne",
-    "Unknown filetype" : "Nezināms datnes tips",
+    "Unknown filetype" : "Nezināms datnes veids",
     "An error occurred. Please contact your admin." : "Notika kļūda. Lūdzu sazinies ar savu administratoru.",
     "Invalid image" : "Nederīgs attēls",
     "No temporary profile picture available, try again" : "Profila pagaidu attēls nav pieejams, mēģini vēlreiz",
@@ -18,19 +23,23 @@ OC.L10N.register(
     "No valid crop data provided" : "Nav norādīti derīgi apgriešanas dati",
     "Crop is not square" : "Griezums nav kvadrāts",
     "State token does not match" : "Neatbilstošs stāvokļa talons",
+    "Invalid app password" : "Nederīga lietotnes parole",
     "Could not complete login" : "Nevarēja pabeigt pieslēgšanos",
     "Your login token is invalid or has expired" : "Pieteikšanās pilnvara nav derīga vai tā ir beigusies",
     "Login" : "Autorizēties",
     "Password reset is disabled" : "Paroles atiestatīšana nav iespējota",
     "%s password reset" : "%s paroles maiņa",
     "Password reset" : "Parole atiestatīta",
-    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo pogu, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
-    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo saiti, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
+    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Jānospiež zemāk esošā poga, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
+    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Jāklikšķina uz zemāk esošās saites, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
     "Reset your password" : "Atiestatīt paroli",
     "Internal error" : "Iekšēja kļūda",
+    "Not found" : "Nav atrasts",
+    "Image not found" : "Attēls nav atrasts",
     "Nextcloud Server" : "Nextcloud Serveris",
-    "Some of your link shares have been removed" : "Dažas no jūsu kopīgotajām saitēm ir noņemtas",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Sakarā ar drošības kļūdu mums nācās noņemt dažas jūsu kopīgotajām saitēm. Lūdzu, skatiet saiti, lai iegūtu vairāk informācijas.",
+    "Some of your link shares have been removed" : "Dažas no kopīgotajām saitēm ir noņemtas",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Drošības nepilnības dēļ mums bija jānoņem dažas no kopīgotajām saitēm. Lūgums apskatīt saiti, lai uzzinātu vairāk.",
+    "Learn more ↗" : "Uzzināt vairāk ↗",
     "Preparing update" : "Sagatavo atjauninājumu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Labošanas solis:",
@@ -51,10 +60,11 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesaderīgs)",
     "Already up to date" : "Jau ir jaunākā",
     "Error occurred while checking server setup" : "Radās kļūda, pārbaudot servera ",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Vairāk informācijas ir skatāma {linkstart}dokumentācijā ↗{linkend}.",
     "unknown text" : "nezināms teksts",
     "Hello world!" : "Sveika, pasaule!",
     "sunny" : "saulains",
-    "Hello {name}, the weather is {weather}" : "Sveiks {name}, laiks ir {weather}",
+    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
     "Hello {name}" : "Sveiks {name}",
     "new" : "jauns",
     "_download %n file_::_download %n files_" : ["lejupielādēt %n failus","lejupielādēt %n failus","lejupielādēt %n datnes"],
@@ -62,11 +72,23 @@ OC.L10N.register(
     "Update to {version}" : "Atjaunināts uz {version}",
     "An error occurred." : "Radās kļūda.",
     "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Plašāku informāciju skatiet <a href=\"{url}\">mūsu foruma rakstā</a> par šo problēmu.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūdzu ziņojiet šo ķļūdu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienā</a>.",
-    "More apps" : "Vairāk lietotnes",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Vairāk informācijas par šo sarežģījumu ir skatāma <a href=\"{url}\">mūsu foruma ierakstā</a> .",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūgums ziņot par šo nepilnību <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienai</a>.",
+    "Apps" : "Lietotnes",
+    "More apps" : "Vairāk lietotņu",
     "No" : "Nē",
     "Yes" : "Jā",
+    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti jūsu Nextcloud",
+    "Search in date range" : "Meklēt laika posmā",
+    "Unified search" : "Apvienotā meklēšana",
+    "Places" : "Vietas",
+    "Date" : "Datums",
+    "Today" : "Šodien",
+    "People" : "Cilvēki",
+    "Load more results" : "Ielādēt vairāk iznākumu",
+    "Search in" : "Meklēt",
+    "Searching …" : "Meklē...",
+    "Start typing to search" : "Sākt rakstīt, lai meklētu",
     "Log in" : "Pieteikties",
     "Logging in …" : "Notiek pieteikšanās …",
     "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
@@ -74,42 +96,46 @@ OC.L10N.register(
     "An internal error occurred." : "Radās iekšēja kļūda.",
     "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
     "Password" : "Parole",
-    "Log in with a device" : "Pieslēgties izmantojot ierīci",
-    "Your account is not setup for passwordless login." : "Jūsu konts nav iestatīts lai pieslēgtos bez paroles.",
-    "Passwordless authentication is not supported in your browser." : "Jūsu pārlūkprogrammā netiek atbalstīta autentifikācija bez paroles",
+    "Wrong login or password." : "Nepareizs lietotājvārds vai parole.",
+    "Account name or email" : "Lietotājvārds vai e-pasts",
+    "Account name" : "Konta nosaukums",
+    "Log in with a device" : "Pieteikties ar ierīci",
+    "Your account is not setup for passwordless login." : "Konts nav iestatīts, lai pieteiktos bez paroles.",
+    "Browser not supported" : "Pārlūkprogramma netiek atbalstīta",
+    "Passwordless authentication is not supported in your browser." : "Pārlūkprogrammā netiek nodrošināta autentifikācija bez paroles",
     "Passwordless authentication is only available over a secure connection." : "Autentifikācija bez paroles ir pieejama tikai ar drošu savienojumu.",
-    "Reset password" : "Mainīt paroli",
+    "Reset password" : "Atiestatīt paroli",
     "Couldn't send reset email. Please contact your administrator." : "Nevarēja nosūtīt maiņas e-pastu. Lūdzu sazinies ar savu administratoru.",
+    "Password cannot be changed. Please contact your administrator." : "Parole nav nomaināma. Lūgums sazināties ar savu pārvaldītāju.",
     "Back to login" : "Atpakaļ uz pieteikšanos",
     "New password" : "Jauna parole",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Jūsu faili ir šifrēti. Pēc paroles atiestatīšanas nebūs iespējams atgūt datus. Ja nezināt, kā rīkoties, pirms turpināt, sazinieties ar administratoru. Vai tiešām vēlaties turpināt?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tavas datnes ir šifrētas. Pēc paroles atiestatīšanas nebūs iespējams atgūt datus. Ja nav zināms, kā rīkoties, lūgums pirms turpināšanas sazināties ar pārvaldītāju. Vai tiešām turpināt?",
     "I know what I'm doing" : "Es zinu ko es daru",
-    "Resetting password" : "Paroles atiestatīšana",
+    "Resetting password" : "Atiestata paroli",
     "Recommended apps" : "Ieteicamās lietotnes",
     "Loading apps …" : "Notiek lietotņu ielāde ...",
-    "Installing apps …" : "Notiek lietotņu instalēšana ...",
     "App download or installation failed" : "Lietotnes lejupielāde vai instalēšana neizdevās",
     "Skip" : "Izlaist",
-    "Schedule work & meetings, synced with all your devices." : "Ieplāno darbu un sapulces, kas sinhronizētas ar visām jūsu ierīcēm.",
+    "Installing apps …" : "Notiek lietotņu instalēšana ...",
+    "Schedule work & meetings, synced with all your devices." : "Ieplāno darbu un sapulces, kas sinhronizētas ar visās izmantotajās ierīcēs.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Turiet savus kolēģus un draugus vienuviet, neizpludinot viņu privāto informāciju.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkāršā e-pasta lietotne labi integrēta ar Failiem, Kontaktiem un Kalendāru.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkāršā e-pasta lietotne labi apvienota ar Datnēm, Kontaktiem un Kalendāru.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna koplietošana, tiešsaistes sapulces un tīmekļa konferences - pārlūkprogrammā un ar mobilajām lietotnēm.",
+    "Settings menu" : "Iestatījumu izvēlne",
     "Search contacts …" : "Meklēt kontaktpersonu",
-    "Could not load your contacts" : "Nevarēja ielādēt visas jūsu kontaktpersonas",
+    "Could not load your contacts" : "Nevarēja ielādēt visas kontaktpersonas",
     "No contacts found" : "Nav atrasta ne viena kontaktpersona",
     "Install the Contacts app" : "Instalējiet lietotni Kontaktpersonas",
     "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
     "Looking for {term} …" : "Meklē {term} …",
     "Search" : "Meklēt",
-    "Forgot password?" : "Aizmirsi paroli?",
+    "Forgot password?" : "Aizmirsta parole?",
     "Back" : "Atpakaļ",
-    "Edit Profile" : "Rediģēt profilu",
-    "Date" : "Datums",
-    "Today" : "Šodien",
-    "Searching …" : "Meklē...",
-    "Settings menu" : "Iestatījumu izvēlne",
+    "Edit Profile" : "Labot profilu",
     "Choose" : "Izvēlieties",
+    "Copy to {target}" : "Kopēt uz {target}",
     "Copy" : "Kopēt",
+    "Move to {target}" : "Pārvietot uz {target}",
     "Move" : "Pārvietot",
     "OK" : "Labi",
     "read-only" : "tikai-skatīt",
@@ -123,7 +149,7 @@ OC.L10N.register(
     "Continue" : "Turpināt",
     "(all selected)" : "(visus iezīmētos)",
     "({count} selected)" : "({count} iezīmēti)",
-    "Error loading file exists template" : "Kļūda ielādējot eksistējošas datnes veidni",
+    "Error loading file exists template" : "Kļūda esošas datnes veidnes ielādēšanā",
     "Saving …" : "Saglabā ...",
     "seconds ago" : "pirms mirkļa",
     "Connection to server lost" : "Zaudēts savienojums ar serveri",
@@ -136,15 +162,16 @@ OC.L10N.register(
     "Failed to create a project" : "Neizdevās izveidot projektu",
     "Failed to add the item to the project" : "Neizdevās pievienot vienumu projektam",
     "Connect items to a project to make them easier to find" : "Savienojiet vienumus ar projektu, lai tos būtu vieglāk atrast",
+    "New in" : "Jauns",
     "View changelog" : "Skatīt izmaiņu sarakstu",
     "Very weak password" : "Ļoti vāja parole",
     "Weak password" : "Vāja parole",
-    "So-so password" : "Normāla parole",
+    "So-so password" : "Viduvēja parole",
     "Good password" : "Laba parole",
-    "Strong password" : "Lieliska parole",
+    "Strong password" : "Spēcīga parole",
     "No action available" : "Nav pieejamu darbību",
     "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
-    "Non-existing tag #{tag}" : "Neeksistējošs tags #{tag}",
+    "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
     "Restricted" : "Ierobežota",
     "Invisible" : "Neredzama",
     "Delete" : "Dzēst",
@@ -152,7 +179,7 @@ OC.L10N.register(
     "Collaborative tags" : "Sadarbības birkas",
     "No tags found" : "Netika atrasta neviena birka",
     "Personal" : "Personīgi",
-    "Apps" : "Lietotnes",
+    "Accounts" : "Konti",
     "Admin" : "Administratori",
     "Help" : "Palīdzība",
     "Access forbidden" : "Pieeja ir liegta",
@@ -161,25 +188,28 @@ OC.L10N.register(
     "Previous" : "Iepriekšējā",
     "Internal Server Error" : "Iekšēja servera kļūda",
     "The server was unable to complete your request." : "Serveris nevarēja izpildīt tavu pieprasījumu.",
-    "More details can be found in the server log." : "Sīkāka informācija atrodama servera žurnāla datnē.",
+    "More details can be found in the server log." : "Vairāk informācijas var atrast servera žurnālā.",
     "Technical details" : "Tehniskās detaļas",
     "Remote Address: %s" : "Attālinātā adrese: %s",
     "Request ID: %s" : "Pieprasījuma ID: %s",
-    "Type: %s" : "Tips: %s",
+    "Type: %s" : "Veids: %s",
     "Code: %s" : "Kods: %s",
     "Message: %s" : "Ziņojums: %s",
     "File: %s" : "Datne: %s",
     "Line: %s" : "Līnija: %s",
     "Trace" : "Izsekot",
     "Security warning" : "Drošības brīdinājums",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Visticamāk, jūsu datu direktorija un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Iespējams, ka datu mape un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
     "Create an <strong>admin account</strong>" : "Izveidot <strong>administratora kontu</strong>",
+    "Show password" : "Rādīt paroli",
+    "Toggle password visibility" : "Pārslēgt paroles redzamību",
     "Storage & database" : "Krātuve & datubāze",
     "Data folder" : "Datu mape",
     "Configure the database" : "Konfigurēt datubāzi",
     "Only %s is available." : "Tikai %s ir pieejams.",
     "Install and activate additional PHP modules to choose other database types." : "Instalējiet un aktivizējiet papildus PHP moduļus lai izvēlētos citus datubāžu tipus.",
-    "For more details check out the documentation." : "Sīkākai informācijai skatiet dokumentāciju.",
+    "For more details check out the documentation." : "Vairāk informācijas ir meklējama dokumentācijā.",
+    "Database account" : "Datubāzes konts",
     "Database password" : "Datubāzes parole",
     "Database name" : "Datubāzes nosaukums",
     "Database tablespace" : "Datubāzes tabulas telpa",
@@ -188,68 +218,45 @@ OC.L10N.register(
     "Performance warning" : "Veiktspējas brīdinājums",
     "Need help?" : "Vajadzīga palīdzība?",
     "See the documentation" : "Skatiet dokumentāciju",
-    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šai lietotnei nepieciešams JavaScript. Lūdzu {linkstart}ieslēdziet JavasScript{linkend} un pārlādējiet lapu.",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šīs lietotnes pareizai darbībai ir nepieciešams JavaScript. Lūgums {linkstart}ieslēgt JavasScript{linkend} un pārlādēt lapu.",
+    "App password" : "Lietotnes parole",
     "Grant access" : "Piešķirt pieeju",
     "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
+    "Email address" : "E-pasta adrese",
+    "Password sent!" : "Parole ir nosūtīta.",
     "Two-factor authentication" : "Divpakāpju autentifikācija",
-    "Use backup code" : "Izmantojiet dublēšanas kodu",
+    "Use backup code" : "Izmantot rezerves kodu",
     "Cancel login" : "Atcelt pieteikšanos",
-    "Error while validating your second factor" : "Kļūda validējot jūsu otru faktoru.",
+    "Error while validating your second factor" : "Kļūda otra faktora apstiprināšanas laikā",
     "Access through untrusted domain" : "Piekļūt caur neuzticamu domēnu",
     "App update required" : "Lietotnei nepieciešama atjaunināšana",
     "These incompatible apps will be disabled:" : "Šīs nesaderīgās lietotnes tiks atspējotas:",
     "The theme %s has been disabled." : "Tēma %s ir atspējota.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Lūdzu pārliecinieties ka datubāze, config mape un data mape ir  dublētas pirms turpināšanas.",
     "Start update" : "Sākt atjaunināšanu",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Lai izvairītos no noliedzes ar lielākām instalācijām, jūs varat palaist sekojošo komandu no jūsu instalācijas mapes:",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Lai izvairītos no noildzēm lielākās instalācijās, tā vietā uzstādīšanas mapē var izpildīt šo komandu:",
     "Detailed logs" : "Detalizēti žurnāli",
     "Update needed" : "Nepieciešama atjaunināšana",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu ka ja es turpināšu atjauninājumu caur tīmekļa atjauninātāju ir risks ka pieprasījumam būs noliedze , kas var radīt  datu zudumu, bet man ir dublējumkopija un es zinu kā atjaunot instanci neveiksmes gadijumā.",
     "Upgrade via web on my own risk" : "Atjaunināt caur tīmekļa atjauninātāju uz mana paša risku.",
     "Maintenance mode" : "Uzturēšanas režīms",
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "Sazinieties ar sistēmas administratoru, ja šis ziņojums tiek rādīts.. vai parādījās negaidīti",
+    "This page will refresh itself when the instance is available again." : "Šī lapa atsvaidzināsies, kad Nextcloud būs atkal pieejams.",
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jāsazinās ar sistēmas pārvaldītāju, ja šis ziņojums nepazūd vai parādījās negaidīti",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsu serveris nav pareizi uzstādīts lai atļautu datņu sinhronizēšanu jo WebDAV interfeiss šķiet salūzis.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu MIME tipus.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebija iespējams paveikt cron darbu izmantojot CLI. Sekojošās tehniskās kļūdas ir uzradušās:",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tas ir īpaši ieteicams, ja, izmantojot darbvirsmas klientu, lai veiktu failu sinhronizāciju.",
-    "Account name or email" : "Lietotājvārds vai e-pasts",
     "Wrong username or password." : "Nepareizs lietotājvārds vai parole.",
     "User disabled" : "Lietotājs deaktivizēts",
+    "Login with username or email" : "Pieteikties ar lietotājvārdu vai e-pasta adresi",
+    "Login with username" : "Pieteikties ar lietotājvārdu",
     "Username or email" : "Lietotājvārds vai e-pasts",
-    "Settings" : "Iestatījumi",
-    "Show all contacts …" : "Rādīt visas kontaktpersonas",
-    "No files in here" : "Šeit nav datņu",
-    "New folder" : "Jauna mape",
-    "No more subfolders in here" : "Šeit nav vairāk apakšmapju",
-    "Name" : "Vārds",
-    "Size" : "Izmērs",
-    "Modified" : "Mainīts",
-    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
-    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
-    "\"/\" is not allowed inside a file name." : "\"/\" nav atļauts faila nosaukumā.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" nav atļauts faila tips",
-    "{newName} already exists" : "{newName} jau eksistē",
-    "Error loading file picker template: {error}" : "Kļūda ielādējot izvēlēto veidni: {error}",
     "Error loading message template: {error}" : "Kļūda ielādējot ziņojuma veidni: {error}",
-    "Show list view" : "Rādīt saraksta skatu",
-    "Show grid view" : "Rādīt režģa skatu",
-    "Pending" : "Gaida",
-    "Home" : "Sākums",
-    "Copy to {folder}" : "Kopēt uz {folder}",
-    "Move to {folder}" : "Pārvietot uz {folder}",
-    "Authentication required" : "Nepieciešama autentifikācija",
-    "This action requires you to confirm your password" : "Lai veiktu šo darbību, jums jāievada sava parole.",
-    "Confirm" : "Apstiprināt",
-    "Failed to authenticate, try again" : "Neizdevās autentificēt, mēģiniet vēlreiz",
     "Users" : "Lietotāji",
     "Username" : "Lietotājvārds",
     "Database user" : "Datubāzes lietotājs",
-    "Confirm your password" : "Apstipriniet paroli",
+    "This action requires you to confirm your password" : "Šī darbība ir jāapliecina ar savu paroli",
+    "Confirm your password" : "Jāapstiprina sava parole",
+    "Confirm" : "Apstiprināt",
     "App token" : "Lietotnes pilnvara",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Lūdzu, izmantojiet komandrindas atjauninātāju, jo jums ir vairāk nekā 50 lietotāji."
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Lūgums izmantot komandrindas atjauninātāju, jo instancē ir vairāk nekā 50 lietotāju."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
