@@ -5,14 +5,14 @@ OC.L10N.register(
     "File is too big" : "O ficheiro é demasiado grande",
     "The selected file is not an image." : "O ficheiro selecionado não é uma imagem.",
     "The selected file cannot be read." : "O ficheiro selecionado não pode ser lido.",
-    "The file was uploaded" : "O ficheiro foi carregado",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva MAX_FILE_SIZE definida no formulário HTML",
-    "The file was only partially uploaded" : "O ficheiro foi apenas parcialmente carregado",
-    "No file was uploaded" : "Não foi carregado nenhum ficheiro",
+    "The file was uploaded" : "O ficheiro foi enviado",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a diretiva \"upload_max_filesize\" no php.ini ",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva \"MAX_FILE_SIZE\" definida no formulário HTML",
+    "The file was only partially uploaded" : "O ficheiro foi enviado apenas parcialmente",
+    "No file was uploaded" : "Não foi enviado nenhum ficheiro",
     "Missing a temporary folder" : "Falta uma pasta temporária",
-    "Could not write file to disk" : "Não foi possível escrever o ficheiro no disco.",
-    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o carregamento do ficheiro.",
+    "Could not write file to disk" : "Não foi possível gravar o ficheiro no disco",
+    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do ficheiro.",
     "Invalid file provided" : "Fornecido ficheiro inválido",
     "No image or file provided" : "Imagem ou ficheiro não fornecido",
     "Unknown filetype" : "Tipo de ficheiro desconhecido",
@@ -22,11 +22,11 @@ OC.L10N.register(
     "No crop data provided" : "Não foram fornecidos dados de recorte",
     "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
     "Crop is not square" : "O recorte não é quadrado",
-    "State token does not match" : "O token de estado não corresponde",
-    "Invalid app password" : "Palavra-passe de aplicação inválida",
-    "Could not complete login" : "Não foi possível fazer login",
-    "State token missing" : "O token da sessão está em falta",
-    "Your login token is invalid or has expired" : "O seu token de login é inválido ou expirou",
+    "State token does not match" : "O código de estado não corresponde",
+    "Invalid app password" : "Palavra-passe da aplicação inválida",
+    "Could not complete login" : "Não foi possível concluir a autenticação",
+    "State token missing" : "O código de estado está em falta",
+    "Your login token is invalid or has expired" : "O seu código de autenticação é inválido ou expirou",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "A versão comunitária da Nextcloud não tem suporte e as notificações a pedido são limitadas.",
     "Login" : "Iniciar sessão",
     "Password reset is disabled" : "A reposição da senha está desativada",
@@ -39,10 +39,11 @@ OC.L10N.register(
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
     "Reset your password" : "Repor a senha",
     "Internal error" : "Erro interno",
+    "Not found" : "Não foi encontrado",
     "Nextcloud Server" : "Nextcloud Server",
-    "Some of your link shares have been removed" : "Alguns dos links das suas partilhas foram removidos",
+    "Some of your link shares have been removed" : "Algumas das suas partilhas de hiperligação foram removidas",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
-    "Learn more ↗" : "Aprenda mais ↗",
+    "Learn more ↗" : "Saiba mais ↗",
     "Preparing update" : "A preparar a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa da reparação:",
@@ -54,7 +55,7 @@ OC.L10N.register(
     "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
     "Updating database schema" : "A atualizar o esquema da base de dados",
     "Updated database" : "Base de dados atualizada",
-    "Update app \"%s\" from App Store" : "Actualizar a aplicação \"%s\" da Loja de Aplicações",
+    "Update app \"%s\" from App Store" : "Atualizar a aplicação \"%s\" a partir da Loja de Aplicações",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo, dependendo do tamanho da base de dados)",
     "Updated \"%1$s\" to %2$s" : "Atualizar \"%1$s\" para %2$s",
     "Set log level to debug" : "Definir nível de registo para depurar",
@@ -62,7 +63,7 @@ OC.L10N.register(
     "Starting code integrity check" : "A iniciar a verificação da integridade do código",
     "Finished code integrity check" : "Terminada a verificação da integridade do código",
     "%s (incompatible)" : "%s (incompatível)",
-    "The following apps have been disabled: %s" : "As seguintes aplicações foram desactivadas: %s",
+    "The following apps have been disabled: %s" : "As seguintes aplicações foram desativadas: %s",
     "Already up to date" : "Já está atualizado",
     "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
     "unknown text" : "texto desconhecido",
@@ -74,15 +75,24 @@ OC.L10N.register(
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualização está a decorrer. Se deixar esta página o processo pode ser interrompido.",
-    "Update to {version}" : "Actualizar para {version}",
+    "Update to {version}" : "Atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
     "Please reload the page." : "Por favor, recarregue a página.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, informe este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
+    "Apps" : "Aplicações",
     "More apps" : "Mais apps",
     "No" : "Não",
     "Yes" : "Sim",
+    "Failed to add the public link to your Nextcloud" : "Não foi possível adicionar a hiperligação pública ao seu Nextcloud",
+    "Date" : "Data",
+    "Today" : "Hoje",
+    "Last year" : "Ultimo ano",
+    "Results" : "Resultados",
+    "Load more results" : "Mostrar mais resultados...",
+    "Searching …" : "À procura …",
+    "Start typing to search" : "Digitar para pesquisar",
     "Log in" : "Iniciar sessão",
     "Logging in …" : "A entrar...",
     "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
@@ -106,14 +116,15 @@ OC.L10N.register(
     "Resetting password" : "A fazer reset à palavra passe",
     "Recommended apps" : "Aplicações recomendadas",
     "Loading apps …" : "A carregar aplicações...",
-    "Installing apps …" : "A instalar aplicações ...",
     "App download or installation failed" : "A transferência ou a instalação desta aplicação falhou",
     "Cannot install this app because it is not compatible" : "Não é possível instalar esta aplicação por não ser compatível",
     "Cannot install this app" : "Não é possível instalar esta aplicação",
     "Skip" : "Saltar",
+    "Installing apps …" : "A instalar aplicações ...",
     "Install recommended apps" : "Instalar aplicações recomendadas",
     "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
+    "Settings menu" : "Menu de configurações",
     "Reset search" : "Redefinir pesquisa",
     "Search contacts …" : "Pesquisar contactos...",
     "Could not load your contacts" : "Não foi possível carregar os seus contactos",
@@ -122,9 +133,7 @@ OC.L10N.register(
     "Loading your contacts …" : "A carregar os seus contactos",
     "Looking for {term} …" : "Procurando por {term} …",
     "Search for {name} only" : "Pesquisar apenas por {name}",
-    "Start typing to search" : "Digitar para pesquisar",
     "Loading more results …" : "A carregar mais resultados...",
-    "Load more results" : "Mostrar mais resultados...",
     "Search" : "Procurar",
     "No results for {query}" : "Nenhum resultado para {query}",
     "An error occurred while searching for {type}" : "Ocorreu um erro enquanto pesquisava por {type}",
@@ -132,18 +141,13 @@ OC.L10N.register(
     "Back" : "Anterior",
     "Edit Profile" : "Editar perfil",
     "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
-    "Search {types} …" : "Pesquisar {types}...",
-    "Date" : "Data",
-    "Today" : "Hoje",
-    "Last year" : "Ultimo ano",
-    "Not found" : "Não foi encontrado",
-    "Searching …" : "À procura …",
+    "More actions" : "Mais acções",
     "This browser is not supported" : "O seu navegador não é suportado.",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A versão do seu navegador não é suportada. Por favor atualize para uma versão mais recente ou para uma que seja suportada.",
     "Continue with this unsupported browser" : "Continuar com uma versão não suportada do navegador",
     "Supported versions" : "Versões suportadas",
     "{name} version {version} and above" : "{name} versão {version} e superior",
-    "Settings menu" : "Menu de configurações",
+    "Search {types} …" : "Pesquisar {types}...",
     "Choose" : "Escolher",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -190,7 +194,6 @@ OC.L10N.register(
     "Collaborative tags" : "Etiquetas colaborativas",
     "No tags found" : "Etiquetas não encontradas",
     "Personal" : "Pessoal",
-    "Apps" : "Aplicações",
     "Admin" : "Administração",
     "Help" : "Ajuda",
     "Access forbidden" : "Acesso proibido",
@@ -282,59 +285,18 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "O seu webserver não está configurado correctamente resolver \"{url}\". Pode encontrar mais informações na documentação {linkstart} ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, verifique a {linkstart}documentação de instalação ↗{linkend} para notas de configuração de PHP e a configuração de PHP do seu servidor, especialmente ao utilizar php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "O módulo PHP 'fileinfo' está ausente. Recomendamos vivamente que ative este módulo para obter melhores resultados na detecção de tipo MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "O bloqueio de arquivo transaccional está desativado, isso pode levar a problemas com condições de corrida. Ative \"filelocking.enabled\" em config.php para evitar esses problemas. Consulte a {linkstart}documentação ↗{linkend} para obter mais informação.",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "A instalação não tem uma região de telefone predefinida. A região predefinida é necessária para validar números de telefone sem código de país nas configurações do perfil . Para permitir números sem um código de país, adicione \"default_phone_region\" com o respectivo {linkstart}código ISO 3166-1 ↗{linkend} da região ao seu ficheiro de configuração.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron job via CLI. Ocorreram os seguintes erros técnicos:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Índice \"{indexName}\" em falta na tabela \"{tableName}\".",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Esta instância tem em falta alguns módulos PHP recomendados. Para melhor desempenho e melhor compatibilidade, é altamente recomendável instalá-los.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite é atualmente utilizado como a base de dados de backend. Para instalações maiores recomendamos que mude para uma base de dados de backend diferente.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Isto é particularmente recomendado quando estiver a usar um cliente de desktop para sincronização de ficheiros.",
-    "The PHP memory limit is below the recommended value of 512MB." : "O limite de memória do PHP está abaixo do valor recomendado de 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algumas diretorias de aplicações pertencem a um utilizador diferente do servidor web. Pode ser esse o caso se as aplicações foram instaladas manualmente. Verifique as permissões das seguintes diretorias de aplicações:",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
     "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
     "User disabled" : "Utilizador desativado",
     "Username or email" : "Utilizador ou e-mail",
-    "Start search" : "Inicie a pesquisa",
-    "Open settings menu" : "Abrir o menu das configurações",
-    "Settings" : "Definições",
-    "Show all contacts …" : "Mostrar todos os contactos ...",
-    "No files in here" : "Sem ficheiros aqui",
-    "New folder" : "Nova pasta",
-    "No more subfolders in here" : "Atualmente não existem subpastas aqui",
-    "Name" : "Nome",
-    "Size" : "Tamanho",
-    "Modified" : "Modificado",
-    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
-    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
-    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
-    "{newName} already exists" : "{newName} já existe",
-    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
     "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
-    "Show list view" : "Mostrar visualização em lista",
-    "Show grid view" : "Mostrar visualização em grelha",
-    "Pending" : "Pendente",
-    "Home" : "Casa",
-    "Copy to {folder}" : "Copiar para {folder}",
-    "Move to {folder}" : "Mover para {folder}",
-    "Authentication required" : "Autenticação necessária",
-    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
-    "Confirm" : "Confirmar",
-    "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
     "Users" : "Utilizadores",
     "Username" : "Nome de utilizador",
     "Database user" : "Utilizador da base de dados",
+    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
     "Confirm your password" : "Confirmar senha",
+    "Confirm" : "Confirmar",
     "App token" : "Token da aplicação",
     "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores."
