@@ -38,10 +38,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați butonul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați link-ul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Reset your password" : "Resetați-vă parola",
-    "Requested task type does not exist" : "Tipul de sarcină cerut nu există",
-    "Necessary language model provider is not available" : "Furnizorul de model de limbă nu este disponibil",
     "Task not found" : "Sarcina nu a fost găsită",
     "Internal error" : "Eroare internă",
+    "Not found" : "Nu a fost găsit",
+    "Requested task type does not exist" : "Tipul de sarcină cerut nu există",
+    "Necessary language model provider is not available" : "Furnizorul de model de limbă nu este disponibil",
     "No text to image provider is available" : "Niciun provider disponibil pentru text - imagine",
     "Image not found" : "Imagine indisponibilă",
     "No translation provider available" : "Niciun furnizor de traducere nu este disponibil",
@@ -92,15 +93,32 @@ OC.L10N.register(
     "Continue to {productName}" : "Continuă la {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Actualizare efectuată. Redirectare la {productName} în %n secundă.","Actualizare efectuată. Redirectare la {productName} în %n seconde.","Actualizare efectuată. Redirectare la {productName} în %n secunde."],
     "Applications menu" : "Meniul aplicațiilor",
+    "Apps" : "Aplicații",
     "More apps" : "Mai multe aplicatii",
-    "Currently open" : "Deschise curent",
     "_{count} notification_::_{count} notifications_" : ["{count} notificare","{count} notificări","{count} notificări"],
     "No" : "Nu",
     "Yes" : "Da",
+    "Failed to add the public link to your Nextcloud" : "Eroare la adăugarea link-ului public la Nextcloud",
     "Custom date range" : "Interval particular de date",
     "Pick start date" : "Selectează o dată de început",
     "Pick end date" : "Selectează o dată de sfârșit",
     "Search in date range" : "Caută în intervalul",
+    "Search apps, files, tags, messages" : "Caută aplicații, fișiere, etichete, mesaje",
+    "Today" : "Azi",
+    "Last 7 days" : "Ultimele 7 zile",
+    "Last 30 days" : "Ultimele 30 de zile",
+    "This year" : "Anul acesta",
+    "Last year" : "Anul trecut",
+    "Search people" : "Caută persoane",
+    "People" : "Persoane",
+    "Filter in current view" : "Filtrează în vizualizarea curentă",
+    "Results" : "Rezultate",
+    "Load more results" : "Încarcă mai multe rezultate",
+    "Search in" : "Caută în",
+    "Searching …" : "Căutare ...",
+    "Start typing to search" : "Tastați pentru căutare",
+    "No matching results" : "Niciun rezultat găsit",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Între ${this.dateFilter.startFrom.toLocaleDateString()} și ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Autentificare",
     "Logging in …" : "Se autentifică...",
     "Server side authentication failed!" : "Autentificarea la nivel de server a eșuat!",
@@ -112,6 +130,7 @@ OC.L10N.register(
     "Password" : "Parolă",
     "Log in to {productName}" : "Logare la {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
+    "Account name or email" : "Cont utilizator sau email",
     "Log in with a device" : "Logare cu dispozitiv",
     "Your account is not setup for passwordless login." : "Contul acesta nu este configurat pentru logare fără parolă.",
     "Browser not supported" : "Browser incompatibil",
@@ -129,11 +148,11 @@ OC.L10N.register(
     "Recommended apps" : "Aplicații recomandate",
     "Loading apps …" : "Se încarcă aplicațiile ...",
     "Could not fetch list of apps from the App Store." : "Nu s-a putut prelua lista aplicațiilor din App Store.",
-    "Installing apps …" : "Se instalează aplicațiile ...",
     "App download or installation failed" : "Descărcarea și instalarea aplicației a eșuat",
     "Cannot install this app because it is not compatible" : "Nu se poate instala aplicația deoarece este incompatibilă",
     "Cannot install this app" : "Nu se poate instala această aplicație",
     "Skip" : "Sari peste",
+    "Installing apps …" : "Se instalează aplicațiile ...",
     "Install recommended apps" : "Instalați aplicațiile recomandate",
     "Schedule work & meetings, synced with all your devices." : "Organizează munca & întâlnirile, sincronizat pe toate dispozitivele.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Un loc comun pentru colegi și prieteni fără scurgeri de informații private.",
@@ -141,6 +160,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, apeluri video, partajare ecran, întâlniri online și videoconferințe - în browser și cu aplicația mobilă.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documente colaborative, foi de calcul și prezentări, create în Collabora Online.",
     "Distraction free note taking app." : "Aplicație simplă pentru note",
+    "Settings menu" : "Meniul Setări",
+    "Avatar of {displayName}" : "Avatarul {displayName}",
     "Search contacts" : "Cautare contacte",
     "Reset search" : "Resetează căutarea",
     "Search contacts …" : "Caută contacte ...",
@@ -152,14 +173,11 @@ OC.L10N.register(
     "Looking for {term} …" : "Se caută  {term} …",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Căutarea începe când tastați și navigarea în rezultate se face cu tastele săgeți",
     "Search for {name} only" : "Caută doar {name} ",
-    "Start typing to search" : "Tastați pentru căutare",
     "Loading more results …" : "Se încarcă mai multe rezultate ...",
-    "Load more results" : "Încarcă mai multe rezultate",
     "Search" : "Căutare",
     "No results for {query}" : "Niciun rezultat pentru {query}",
     "Press Enter to start searching" : "Apăsați Enter pentru căutare",
     "An error occurred while searching for {type}" : "Eroare la căutarea pentru {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduceți {minSearchLength} caracter sau mai multe pentru căutare","Introduceți {minSearchLength} sau mai multe caractere pentru căutare","Introduceți {minSearchLength} sau mai multe caractere pentru căutare"],
     "Forgot password?" : "Ai uitat parola?",
     "Back to login form" : "Înapoi la forma de login",
     "Back" : "Înapoi",
@@ -169,28 +187,13 @@ OC.L10N.register(
     "You have not added any info yet" : "Nu ați adăugat nicio informație",
     "{user} has not added any info yet" : "{user} nu a adăugat nicio informație",
     "Error opening the user status modal, try hard refreshing the page" : "Eroare la deschiderea status utilizator, încercați refresh",
-    "Search apps, files, tags, messages" : "Caută aplicații, fișiere, etichete, mesaje",
-    "Search {types} …" : "Căutare {types} …",
-    "Today" : "Azi",
-    "Last 7 days" : "Ultimele 7 zile",
-    "Last 30 days" : "Ultimele 30 de zile",
-    "This year" : "Anul acesta",
-    "Last year" : "Anul trecut",
-    "Search people" : "Caută persoane",
-    "Not found" : "Nu a fost găsit",
-    "People" : "Persoane",
-    "Filter in current view" : "Filtrează în vizualizarea curentă",
-    "Search in" : "Caută în",
-    "Searching …" : "Căutare ...",
-    "No matching results" : "Niciun rezultat găsit",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Între ${this.dateFilter.startFrom.toLocaleDateString()} și ${this.dateFilter.endAt.toLocaleDateString()}",
+    "More actions" : "Mai multe acțiuni",
     "This browser is not supported" : "Browser incompatibil",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
     "Continue with this unsupported browser" : "Continuă cu browserul incompatibil",
     "Supported versions" : "Versiuni compatibile",
     "{name} version {version} and above" : "{name} versiunea {version} și superioară",
-    "Settings menu" : "Meniul Setări",
-    "Avatar of {displayName}" : "Avatarul {displayName}",
+    "Search {types} …" : "Căutare {types} …",
     "Choose {file}" : "Selectați {file}",
     "Choose" : "Alege",
     "Copy to {target}" : "Copiază la {target}",
@@ -241,7 +244,6 @@ OC.L10N.register(
     "Collaborative tags" : "Etichete colaborative",
     "No tags found" : "Nu au fost găsite etichete",
     "Personal" : "Personal",
-    "Apps" : "Aplicații",
     "Admin" : "Administrator",
     "Help" : "Ajutor",
     "Access forbidden" : "Acces restricționat",
@@ -352,52 +354,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Serverul dvs. web nu este configurat corespunzător pentru a rezolva \"{url}\". Informații suplimentare pot fi găsite în documentația {linkstart} documentația ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Serverul dvs. web nu este configurat corespunzător pentru a rezolva \"{url}\". Cel mai probabil, acest lucru este legat de o configurație a serverului web care nu a fost actualizată pentru a furniza direct acest folder. Vă rugăm să comparați configurația dvs. cu regulile de rescriere livrate în \".htaccess\" pentru Apache sau cu cea furnizată în documentația pentru Nginx la pagina de documentare {linkstart}↗{linkend}. În cazul Nginx, liniile care încep cu \"location ~\" sunt cele care au nevoie de o actualizare.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Serverul dvs. web nu este configurat corespunzător pentru a furniza fișiere .woff2. Aceasta este de obicei o problemă cu configurația Nginx. Pentru Nextcloud 15 este nevoie de o ajustare pentru a furniza și fișierele .woff2. Comparați configurația Nginx cu configurația recomandată în documentația noastră {linkstart} ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nu pare să fie configurat corespunzător pentru a interoga variabilele de mediu ale sistemului. Testul cu getenv(\"PATH\") returnează doar un răspuns gol.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Vă rugăm să verificați documentația de instalare {linkstart} ↗{linkend} pentru note de configurare PHP și pentru configurația PHP a serverului dumneavoastră, în special atunci când utilizați php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A fost activată configurația doar pentru citire. Acest lucru împiedică setarea unor configurații prin intermediul interfeței web. În plus, fișierul trebuie să fie făcut scriere manual la fiecare actualizare.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Nu ați setat sau verificat încă configurația serverului de e-mail. Vă rugăm să mergeți la {mailSettingsStart}Setări de bază{mailSettingsEnd} pentru a le seta. După aceea, utilizați butonul \"Trimiteți e-mail\" de sub formular pentru a verifica setările.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza dumneavoastră de date nu rulează cu nivelul de izolare a tranzacției \"READ COMMITTED\". Acest lucru poate cauza probleme atunci când mai multe acțiuni sunt executate în paralel.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Modulul PHP \"fileinfo\" lipsește. Se recomandă cu tărie activarea acestui modul pentru a obține cele mai bune rezultate cu detectarea tipurilor MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Blocarea fișierului tranzacțional este dezactivată, aceasta poate duce la probleme. Adăugați \"filelocking.enabled\" în config.php pentru a evita aceste probleme. Vedeți {linkstart}linkend{linkend} pentru mai multe informații.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Pentru blocarea tranzacțională a fișierelor este folosită baza de date. Pentru îmbunătățirea performanței, configurați memcache, dacă este disponibilă. Vedeți {linkstart}documentația ↗{linkend} pentru mai multe informații.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Verificați configurarea opțiunii \"overwrite.cli.url\" în config.php către URL-ul pe care-l folosesc utilizatorii pentru a accesa Nextcloud. Sugestie: \"{suggestedOverwriteCliURL}\". Altfel s-ar putea să fie probleme cu URL-ul generat via cron. (E posibil totuși ca URL-ul sugerat să nu fie URL-ul principal folosit de utilizatori pentru a accesa Nextcloud. Este important să verificați atent.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Instanța nu are configurată o regiune telefonică implicită. Aceasta este necesară pentru validarea numerelor de telefon în setările profilurilor fără un cod de țară. Pentru a permite utilizarea numerelor fără cod de țară, adăugați \"default_phone_region\" cu codul respectiv {linkstart}ISO 3166-1 ↗{linkend} al regiunii în fișierul de configurație.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Cron job-ul nu s-a putut executa via CLI. Au apărut următoarele erori tehnice:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Ultimul job de fundal a rulat {relativeTime}. Ceva nu este în regulă.{linkstart}Verificați setările job-urilor de fundal ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Acesta este un build community de Nextcloud, fără suport. Având în vedere mărimea instanței, performanța, fiabilitatea și scalabilitatea nu pot fi garantate. Notificările push sunt restricționate pentru a evita supraîncarcarea serviciului nostru gratuit. Aflați mai multe despre avantajele Nextcloud Enterprise la {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele caracteristici precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesul fișierelor la distanță și transmiterea emailurilor de notificare. Stabiliți o conexiune la Internet pentru acest server pentru a beneficia de toate facilitățile.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nu este configurat un cache de memorie. Pentru îmbunătățirea performanței, configurați o memcache, dacă este disponibilă. Mai multe informații pot fi găsite în {linkstart}documentație ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nu a găsit o sursă potrivită pentru elemente aleatoare, ceea ce este nerecomandat din motive de securitate. Informații suplimentare se pot găsi în {linkstart}documentație ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Aveți {version} de PHP. Actualizați versiunea de PHP pentru a beneficia de {linkstart}actualizările de performanță și de securitate furnizate de PHP Group ↗{linkend} de îndată ce distribuția vă permite.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 este abandonat de la Nextcloud 27. Nextcloud 28 necesită cel puțin PHP 8.1. Faceți upgrade la {linkstart} o versiune PHP suportată oficial, furnizată de PHP Group ↗{linkend} cât mai repede.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Configurația header-ului proxiului revers este incorectă sau accesați Nextcloud printr-un proxy de încredere. Dacă nu, aceasta este o problemă de securitate și ar putea permite unui atacator să-și facă adresa IP vizibilă serverului Nextcloud. Mai multe informații pot fi găsite la {linkstart}documentation ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memvached este configurat ca un cache distribuit dar este instalat, în mod greșit,  modulul PHP \"memcache\". \\OC\\Memcache\\Memcached suportă doar modulul \"memcached\" și nu \"memcache\". Vedeți {linkstart}Wiki-ul memcached în legătură cu ambele module ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Unele fișiere nu au trecut de verificarea integrității. Mai multe informații despre cum să rezolvați această problemă pot fi găsite în {linkstart1}documentație ↗{linkend}. ({linkstart2}Lista fișierelor invalide…{linkend} / {linkstart3}Rescanare…{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Modulul PHP OPcache nu este configurat corect. Vedeți {linkstart}documentația ↗{linkend} pentru maimulte informații.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funcția PHP \"set_time_limit\" nu este disponibilă. Aceasta ar putea avea ca efect ca scripturile să fie oprite în timpul execuției, compromițând instalarea. Se recomandă puternic activarea acestei funcții.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Instalarea PHP nu are suport pentru FreeType, introducând incompatibilități cu imaginile de profil și cu interfața de configurare.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Lipsește indexul \"{indexName}\" in tabela \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
-    "Missing primary key on table \"{tableName}\"." : "Tabelei \"{tableName}\" îi lipsește cheia primară.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Coloană opțională \"{columnName}\" lipsește în tabela \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Lipsesc din configurație module PHP recomandate. Pentru a îmbunătăți performanța și o mai bună compatibilitate, se recomandă să le instalați.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Modulul PHP \"imagick\" nu este activat cu toate că aplicația de teme este. Pentru ca generarea favicon-ului să funcționeze corect, trebuie instalat și activat acest modul.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Modulul PHP \"gmp\" și/sau \"bcmath\" nu sunt active. Dacă utilizați autentificarea WebAuthn fără parolă, aceste module sunt necesare.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Se pare că aveți versiunea de 32 biți a PHP. Pentru a rula bine, Nextcloud necesită versiunea pe 64 de biți. Faceți upgrade la versiunea pe 64 de biți a sistemului de operare și a PHP! Pentru mai multe informații citiți {linkstart} pagina de documentație ↗{linkend} .",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modulul php-imagick din acestă instanță nu are suport pentru SVG. Pentru o mai bună compatibilitate se recomandă să-l instalați.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Pentru unele coloane din baza de date nu s-a făcut conversia la întreg mare. Datorită faptului că modificare tipului de coloană la tabelele mari durează mult, această conversie nu au fost făcută automat. Rulând  \"occ db:convert-filecache-bigint\", conversia se va aplica manual. Această operație trebuie făcută când instanța este offline. Pentru mai multe detalii, citiți {linkstart}despre aceasta în documentație ↗{linkend}.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Baza de date curentă este SQLite. Pentru configurații mai mari se recomandă să folosiți altă baza de date.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Aceasta se recomandă în special când utilizați clientul pentru desktop pentru sincronizarea fișierelor.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Pentru migrarea la altă bază de date folosiți linia de comandă: \"occ db:convert-type\", sau vedeți {linkstart}documentația ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Limita memoriei PHP este sub valoarea recomandată de 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Unele directoare sunt proprietatea altui utilizator decât cel al serverului web. Ar putea fi din cauza instalării manuale a aplicațiilor. Verificați permisiunile următoarelor directoare:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Este utilizat MySQL ca bază de date dar nu are suport pentru caractere pe 4 byte. Pentru a putea manipula fără probleme caractere pe 4 byte (ca emoji-urile) în numele de fișiere sau comentarii, de exemplu, se recomandă activarea suportului pentru acestea în MySQL. Pentru mai multe detalii citiți {linkstart}documentația↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Instanța folosește ca suport de stocare principal object store-ul S3. Fișierele încărcate sunt stocate temporar pe server și este deci recomandat să dispuneți de un spațiu liber de 50 GB în directorul temp al PHP. Verificați logurile pentru detalii complete despre cale și spațiul disponibil. Pentru optimizare, schimbați directorul temporar în php.ini sau creați mai mult spațiu în acesta.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Directorul temporar al acestei instanțe se referă la o locație inexistentă sau fără permisiune de scriere.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Instanța este accesată printr-o conexiune sigură. Totuși aceasta generează URL-uri nesigure. Cel mai probabil sunteți în spatele unui proxy revers și variabilele de substituție a adresei sunt configurate incorect. Citiți {linkstart}documentația ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Directorul de date și fișierele sunt probabil accesibile din Internet. Fișierul .htaccess nu este funcțional. Se recomandă puternic configurarea serverului web astfel încât directorul de date să nu mai fie accesibil astfel, sau mutați-l în afara rădăcinii documentelor a serverului web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Headerul HTTP \"{header}\" nu este setat la \"{expected}\". Aceasta este un risc major de confidențialitate și vă recomandăm să o remediați.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Headerul HTTP \"{header}\" nu este setat la \"{expected}\". Unele caracteristici pot să nu funcționeze corect și se recomandă remedierea acestei probleme.",
@@ -405,46 +362,21 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Headerul HTTP \"{header}\" nu este setat la \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" sau \"{val5}\". Aceasta poate conduce la scurgeri în legătură cu referer. Vedeți {linkstart}Recomandarea W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Headerul HTTP \"Strict-Transport-Security\" nu este setat la cel puțin \"{seconds}\" secunde. Pentru o bună securitate, se recomandă activarea HSTS așa cum este specificat în {linkstart}sugestii pentru securitate ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Site-ul se accesează nesigur via HTTP. Sunteți sfătuit să setați ca serverul să impună HTTPS, așa cum se specifică în {linkstart}sugestii de securitate ↗{linkend}. Fără aceasta, funcționalități web importante precum \"copiere în clipboard\" sau \"service workers\" nu vor funcționa!",
-    "Account name or email" : "Cont utilizator sau email",
+    "Currently open" : "Deschise curent",
     "Wrong username or password." : "Utilizator sau parolă greșite",
     "User disabled" : "Utilizator dezactivat",
     "Username or email" : "Nume de utilizator sau adresă email",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Dacă acest cont există, atunci a fost trimis un email de resetare a parolei. Dacă nu-l primiți, verificați adresa de mail și/sau numele contului, verificați folderele spam/junk sau solicitați sprijinul administratorului.",
-    "Start search" : "Caută",
-    "Open settings menu" : "Deschide meniul pentru setări",
-    "Settings" : "Setări",
-    "Avatar of {fullName}" : "Avatarul {fullName}",
-    "Show all contacts …" : "Arată toate contactele ...",
-    "No files in here" : "Nu există fișiere aici",
-    "New folder" : "Director nou",
-    "No more subfolders in here" : "Nu mai sunt subdirectoare aici",
-    "Name" : "Nume",
-    "Size" : "Mărime",
-    "Modified" : "Modificat",
-    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
-    "File name cannot be empty." : "Numele fișierului nu poate fi gol.",
-    "\"/\" is not allowed inside a file name." : "\"/\" nu este permis în denumirea fișierului.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" ",
-    "{newName} already exists" : "{newName} există deja",
-    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
+    "Apps and Settings" : "Aplicații și Setări",
     "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
-    "Show list view" : "Afișează vizualizarea listă",
-    "Show grid view" : "Afișează vizualizarea grilă",
-    "Pending" : "În așteptare",
-    "Home" : "Acasă",
-    "Copy to {folder}" : "Copiază la {folder}",
-    "Move to {folder}" : "Mută la {folder}",
-    "Authentication required" : "Este necesară autentificarea",
-    "This action requires you to confirm your password" : "Această acțiune necesită confirmarea parolei tale",
-    "Confirm" : "Confirmă",
-    "Failed to authenticate, try again" : "Eroare la autentificare, reîncearcă",
     "Users" : "Utilizatori",
     "Username" : "Nume utilizator",
     "Database user" : "Utilizatorul bazei de date",
+    "This action requires you to confirm your password" : "Această acțiune necesită confirmarea parolei tale",
     "Confirm your password" : "Confirmă parola:",
+    "Confirm" : "Confirmă",
     "App token" : "Token aplicație",
     "Alternative log in using app token" : "Conectare alternativă folosind token-ul aplicației",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Vă rugăm folosiți actualizarea din linia de comandă pentru că aveți o sesiune mare cu mai mult de 50 de utilizatori.",
-    "Apps and Settings" : "Aplicații și Setări"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Vă rugăm folosiți actualizarea din linia de comandă pentru că aveți o sesiune mare cu mai mult de 50 de utilizatori."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
