@@ -38,10 +38,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào nút sau để đặt lại mật khẩu. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào liên kết sau để đặt lại mật khẩu của bạn. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
     "Reset your password" : "Đổi mật khẩu",
-    "Requested task type does not exist" : "Loại nhiệm vụ đã yêu cầu không tồn tại",
-    "Necessary language model provider is not available" : "Không có nhà cung cấp mô hình ngôn ngữ cần thiết",
     "Task not found" : "Không tìm thấy nhiệm vụ",
     "Internal error" : "Lỗi nội bộ",
+    "Not found" : "Không tìm thấy",
+    "Requested task type does not exist" : "Loại nhiệm vụ đã yêu cầu không tồn tại",
+    "Necessary language model provider is not available" : "Không có nhà cung cấp mô hình ngôn ngữ cần thiết",
     "No translation provider available" : "Không có nhà cung cấp bản dịch",
     "Could not detect language" : "Không thể phát hiện ngôn ngữ",
     "Unable to translate" : "Không thể dịch",
@@ -89,11 +90,17 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
     "Continue to {productName}" : "Tiếp tục đến {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Cập nhật đã thành công. Chuyển hướng bạn đến {productName} trong %n seconds."],
+    "Apps" : "Ứng dụng",
     "More apps" : "Thêm ứng dụng",
-    "Currently open" : "Hiện đang mở",
     "_{count} notification_::_{count} notifications_" : ["{count} thông báo"],
     "No" : "Không",
     "Yes" : "Có",
+    "Create share" : "Tạo chia sẻ",
+    "Failed to add the public link to your Nextcloud" : "Không thể thêm liên kết công khai",
+    "Today" : "Hôm nay",
+    "Load more results" : "Tải thêm kết quả",
+    "Searching …" : "Đang tìm kiếm ...",
+    "Start typing to search" : "Nhập để tìm kiếm",
     "Log in" : "Đăng nhập",
     "Logging in …" : "Đang đăng nhập",
     "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
@@ -103,6 +110,7 @@ OC.L10N.register(
     "Password" : "Mật khẩu",
     "Log in to {productName}" : "Đăng nhập vào {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Chúng tôi đã phát hiện nhiều lần đăng nhập không hợp lệ từ IP của bạn. Do đó, lần đăng nhập tiếp theo của bạn được điều chỉnh lên đến 30 giây.",
+    "Account name or email" : "Tên tài khoản hoặc email",
     "Log in with a device" : "Đăng nhập bằng thiết bị",
     "Your account is not setup for passwordless login." : "Tài khoản của bạn chưa được thiết lập để đăng nhập không cần mật khẩu.",
     "Browser not supported" : "Trình duyệt không được hỗ trợ",
@@ -120,11 +128,11 @@ OC.L10N.register(
     "Recommended apps" : "Ứng dụng được đề xuất",
     "Loading apps …" : "Đang tải ứng dụng ...",
     "Could not fetch list of apps from the App Store." : "Không thể tìm nạp danh sách ứng dụng từ App Store.",
-    "Installing apps …" : "Đang cài đặt ứng dụng ...",
     "App download or installation failed" : "Tải xuống hoặc cài đặt ứng dụng không thành công",
     "Cannot install this app because it is not compatible" : "Không thể cài đặt ứng dụng này vì nó không tương thích",
     "Cannot install this app" : "Không thể cài đặt ứng dụng này",
     "Skip" : "Bỏ qua",
+    "Installing apps …" : "Đang cài đặt ứng dụng ...",
     "Install recommended apps" : "Cài đặt các ứng dụng được đề xuất",
     "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
@@ -132,6 +140,7 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Trò chuyện, cuộc gọi video, chia sẻ màn hình, cuộc họp trực tuyến và hội nghị trên web - trong trình duyệt của bạn và với các ứng dụng dành cho thiết bị di động.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Tài liệu, bảng tính và bản trình bày cộng tác, được xây dựng trên Collabora Online.",
     "Distraction free note taking app." : "Ứng dụng ghi chú không gây xao lãng.",
+    "Settings menu" : "Trình đơn thiết lập",
     "Search contacts" : "Tìm kiếm liên hệ",
     "Reset search" : "Đặt lại tìm kiếm",
     "Search contacts …" : "Tìm liên hệ ...",
@@ -143,14 +152,11 @@ OC.L10N.register(
     "Looking for {term} …" : "Đang tìm kiếm {term} ...",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Tìm kiếm bắt đầu khi bạn bắt đầu nhập và có thể đạt được kết quả bằng các phím mũi tên",
     "Search for {name} only" : "Chỉ tìm kiếm {name}",
-    "Start typing to search" : "Nhập để tìm kiếm",
     "Loading more results …" : "Tải thêm kết quả ...",
-    "Load more results" : "Tải thêm kết quả",
     "Search" : "Tìm kiếm",
     "No results for {query}" : "Không có kết quả cho {query}",
     "Press Enter to start searching" : "Nhấn Enter để bắt đầu tìm kiếm",
     "An error occurred while searching for {type}" : "Đã xảy ra lỗi khi tìm kiếm {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Vui lòng nhập ký tự {minSearchLength} trở lên để tìm kiếm"],
     "Forgot password?" : "Quên mật khẩu sao?",
     "Back to login form" : "Quay lại trang đăng nhập",
     "Back" : "Quay lại",
@@ -160,16 +166,13 @@ OC.L10N.register(
     "You have not added any info yet" : "Bạn chưa thêm bất kỳ thông tin nào",
     "{user} has not added any info yet" : "{user} chưa thêm bất kỳ thông tin nào",
     "Error opening the user status modal, try hard refreshing the page" : "Lỗi khi mở phương thức trạng thái người dùng, hãy thử làm mới trang",
-    "Search {types} …" : "Tìm kiếm {types} ...",
-    "Today" : "Hôm nay",
-    "Not found" : "Không tìm thấy",
-    "Searching …" : "Đang tìm kiếm ...",
+    "More actions" : "Nhiều hành động hơn",
     "This browser is not supported" : "Trình duyệt này không được hỗ trợ",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
     "Continue with this unsupported browser" : "Tiếp tục với trình duyệt không được hỗ trợ này",
     "Supported versions" : "Các phiên bản được hỗ trợ",
     "{name} version {version} and above" : "{name} phiên bản {version} trở lên",
-    "Settings menu" : "Trình đơn thiết lập",
+    "Search {types} …" : "Tìm kiếm {types} ...",
     "Choose {file}" : "Chọn {tập tin}",
     "Choose" : "Chọn",
     "Copy to {target}" : "Sao chép vào {mục tiêu}",
@@ -220,7 +223,6 @@ OC.L10N.register(
     "Collaborative tags" : "Thẻ cộng tác",
     "No tags found" : "Không tìm thấy thẻ",
     "Personal" : "Cá nhân",
-    "Apps" : "Ứng dụng",
     "Admin" : "Quản trị",
     "Help" : "Giúp đỡ",
     "Access forbidden" : "Truy cập bị cấm",
@@ -331,52 +333,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Máy chủ web của bạn không được thiết lập đúng cách để xử lý \"{url}\". Bạn có thể tìm thêm thông tin trong tài liệu {linkstart}↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Máy chủ web của bạn không được thiết lập đúng cách để xử lý \"{url}\". Điều này rất có thể liên quan đến cấu hình máy chủ web chưa được cập nhật để phân phối trực tiếp thư mục này. Vui lòng so sánh cấu hình của bạn với các quy tắc rewrite trong \".htaccess\" cho Apache hoặc quy tắc được cung cấp trong tài liệu dành cho Nginx tại trang tài liệu {linkstart}của nó ↗{linkend}. Trên Nginx, đó thường là những dòng bắt đầu bằng \"location ~\" cần cập nhật.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Máy chủ web của bạn không được thiết lập đúng cách để phân phối các tệp .woff2. Đây thường là sự cố với cấu hình Nginx. Đối với Nextcloud 15, nó cần điều chỉnh để phân phối các tệp .woff2. So sánh cấu hình Nginx của bạn với cấu hình đề xuất trong {linkstart}tài liệu ↗{linkend} của chúng tôi.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP dường như không được thiết lập đúng cách để truy vấn các biến môi trường hệ thống. Thử nghiệm với getenv(\"PATH\") trả về một phản hồi trống.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Vui lòng kiểm tra tài liệu cài đặt {linkstart}↗{linkend} để biết các ghi chú cấu hình PHP và cấu hình PHP của máy chủ của bạn, đặc biệt là khi sử dụng php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Cấu hình chỉ đọc đã được bật. Điều này ngăn thiết lập một số cấu hình thông qua giao diện web. Hơn nữa, tệp cần được ghi theo cách thủ công cho mỗi lần cập nhật.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Bạn chưa đặt hoặc xác minh cấu hình máy chủ email của mình. Vui lòng chuyển đến {mailSettingsStart}Cài đặt cơ bản{mailSettingsEnd} để đặt chúng. Sau đó, bấm nút \"Gửi email\" bên dưới biểu mẫu để xác minh cài đặt của bạn.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Cơ sở dữ liệu của bạn không chạy với mức cô lập giao dịch \"READ COMMITTED\". Điều này có thể gây ra sự cố khi nhiều hành động được thực thi song song.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Mô-đun PHP \"fileinfo\" bị thiếu. Bạn nên kích hoạt mô-đun này để nhận được kết quả tốt nhất với tính năng phát hiện loại MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Khóa tệp giao dịch bị tắt, điều này có thể dẫn đến các vấn đề về điều kiện cuộc đua. Bật \"filelocking.enabled\" trong config.php để tránh những sự cố này. Xem tài liệu {linkstart}↗{linkend} để biết thêm thông tin.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Cơ sở dữ liệu được sử dụng để khóa tệp giao dịch. Để nâng cao hiệu suất, vui lòng định cấu hình memcache, nếu có. Xem tài liệu {linkstart}↗{linkend} để biết thêm thông tin.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Vui lòng đảm bảo đặt tùy chọn \"overwrite.cli.url\" trong tệp config.php của bạn thành URL mà người dùng của bạn chủ yếu sử dụng để truy cập Nextcloud này. Đề xuất: \"{suggestedOverwriteCliURL}\". Nếu không, có thể có vấn đề với việc tạo URL qua cron. (Mặc dù có thể URL được đề xuất không phải là URL mà người dùng của bạn chủ yếu sử dụng để truy cập Nextcloud này. Tốt nhất là kiểm tra kỹ điều này trong mọi trường hợp.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Cài đặt của bạn không có vùng điện thoại mặc định được đặt. Điều này là bắt buộc để xác thực số điện thoại trong cài đặt hồ sơ mà không cần mã quốc gia. Để cho phép các số điện thoại không có mã quốc gia, vui lòng thêm \"default_phone_region\" cùng với {linkstart}mã ISO 3166-1 ↗{linkend} tương ứng của khu vực vào tệp cấu hình của bạn.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Không thể thực hiện công việc cron thông qua CLI. Các lỗi kỹ thuật sau đây đã xuất hiện:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Lần thực thi tác vụ nền cuối cùng chạy {relativeTime}. Có vẻ như có điều gì đó không ổn. {liên kết} Kiểm tra cài đặt ↗ công việc nền {linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Đây là cộng đồng không được hỗ trợ của Nextcloud. Với kích thước của phiên bản này, hiệu năng, độ tin cậy và khả năng mở rộng không thể được đảm bảo. Thông báo đẩy được giới hạn để tránh làm quá tải dịch vụ miễn phí của chúng tôi. Tìm hiểu thêm về các lợi ích của Nextcloud Enterprise tại {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Máy chủ này không có kết nối internet hoạt động: Không thể truy cập nhiều điểm cuối. Điều này có nghĩa là một số tính năng như gắn bộ nhớ ngoài, thông báo về bản cập nhật hoặc cài đặt ứng dụng của bên thứ ba sẽ không hoạt động. Truy cập tệp từ xa và gửi email thông báo cũng có thể không hoạt động. Thiết lập kết nối từ máy chủ này với internet để tận hưởng tất cả các tính năng.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Không có bộ nhớ cache nào được cấu hình. Để nâng cao hiệu suất, vui lòng định cấu hình memcache, nếu có. Thông tin thêm có thể được tìm thấy trong tài liệu ↗ {linkstart} {linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Không có nguồn phù hợp cho sự ngẫu nhiên được tìm thấy bởi PHP rất không được khuyến khích vì lý do bảo mật. Thông tin thêm có thể được tìm thấy trong tài liệu ↗ {linkstart} {linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Bạn hiện đang chạy PHP {version}. Nâng cấp phiên bản PHP của bạn để tận dụng các bản cập nhật bảo mật và hiệu suất {linkstart} do PHP Group ↗ {linkend} cung cấp ngay khi bản phân phối của bạn hỗ trợ.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 hiện không còn được dùng trong Nextcloud 27. Nextcloud 28 có thể yêu cầu ít nhất PHP 8.1. Vui lòng nâng cấp lên {linkstart}một trong những phiên bản PHP được hỗ trợ chính thức do PHP Group ↗ {linkend} cung cấp càng sớm càng tốt.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Cấu hình header proxy ngược không chính xác hoặc bạn đang truy cập Nextcloud từ một proxy đáng tin cậy. Nếu không, đây là một vấn đề bảo mật và có thể cho phép kẻ tấn công giả mạo địa chỉ IP của họ như hiển thị cho Nextcloud. Thông tin thêm có thể được tìm thấy trong tài liệu ↗ {linkstart} {linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached được cấu hình làm bộ đệm phân tán, nhưng mô-đun PHP sai \"memcache\" được cài đặt. \\OC\\Memcache\\Memcached chỉ hỗ trợ \"memcached\" chứ không hỗ trợ \"memcache\". Xem wiki {linkstart}memcached về cả hai mô-đun ↗ {linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Một số tệp chưa vượt qua kiểm tra tính toàn vẹn. Thông tin thêm về cách khắc phục sự cố này có thể được tìm thấy trong tài liệu ↗ {linkstart1} {linkend}. ({linkstart2}Danh sách các tệp không hợp lệ... {linkend} / {linkstart3}Quét lại... {liên kết})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Mô-đun OPcache PHP không được cấu hình đúng. Xem tài liệu ↗ {linkstart} {linkend} để biết thêm thông tin.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP của bạn không có hỗ trợ FreeType, dẫn đến vỡ ảnh hồ sơ và giao diện cài đặt.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Thiếu chỉ mục \"{indexName}\" trong bảng \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Cơ sở dữ liệu thiếu một số mục. Do thực tế là việc thêm mục trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-indices\", các mục bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các mục được thêm vào, các truy vấn vào các bảng đó thường nhanh hơn nhiều.",
-    "Missing primary key on table \"{tableName}\"." : "Thiếu khóa chính trên bảng \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Cơ sở dữ liệu thiếu một số khóa chính. Do thực tế là việc thêm các khóa chính trên các bảng lớn có thể mất một thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-primary-keys\", các khóa chính bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Thiếu cột tùy chọn \"{columnName}\" trong bảng \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Cơ sở dữ liệu thiếu một số cột tùy chọn. Do thực tế là việc thêm cột trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động khi chúng có thể là tùy chọn. Bằng cách chạy \"occ db:add-missing-columns\", các cột bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các cột được thêm vào, một số tính năng có thể cải thiện khả năng phản hồi hoặc khả năng sử dụng.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Phiên bản này thiếu một số mô-đun PHP được đề xuất. Để cải thiện hiệu suất và khả năng tương thích tốt hơn, bạn nên cài đặt chúng.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Mô-đun PHP \"imagick\" không được bật mặc dù ứng dụng chủ đề là. Để tạo favicon hoạt động chính xác, bạn cần cài đặt và bật mô-đun này.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Các mô-đun PHP \"gmp\" và / hoặc \"bcmath\" không được bật. Nếu bạn sử dụng xác thực không cần mật khẩu WebAuthn, các mô-đun này là bắt buộc.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Có vẻ như bạn đang chạy phiên bản PHP 32-bit. Nextcloud cần 64-bit để chạy tốt. Vui lòng nâng cấp hệ điều hành và PHP của bạn lên 64-bit! Để biết thêm chi tiết, hãy đọc {linkstart} trang ↗ tài liệu {linkend} về điều này.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Mô-đun php-imagick trong trường hợp này không có hỗ trợ SVG. Để tương thích tốt hơn, nên cài đặt nó.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Một số cột trong cơ sở dữ liệu bị thiếu chuyển đổi thành số nguyên lớn. Do thực tế là việc thay đổi loại cột trên các bảng lớn có thể mất một thời gian, chúng không được thay đổi tự động. Bằng cách chạy \"occ db:convert-filecache-bigint\", những thay đổi đang chờ xử lý đó có thể được áp dụng thủ công. Thao tác này cần được thực hiện trong khi phiên bản ngoại tuyến. Để biết thêm chi tiết, hãy đọc {linkstart} trang tài liệu về {linkend} này ↗.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite hiện đang được sử dụng làm cơ sở dữ liệu phụ trợ. Đối với các cài đặt lớn hơn, chúng tôi khuyên bạn nên chuyển sang một backend cơ sở dữ liệu khác.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Điều này đặc biệt được khuyến nghị khi sử dụng ứng dụng khách trên máy tính để bàn để đồng bộ hóa tệp.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Để di chuyển sang cơ sở dữ liệu khác, hãy sử dụng công cụ dòng lệnh: \"occ db:convert-type\" hoặc xem tài liệu ↗ {linkstart} {linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Giới hạn bộ nhớ PHP thấp hơn giá trị khuyến nghị là 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Một số thư mục ứng dụng được sở hữu bởi một người dùng khác với người dùng máy chủ web. Điều này có thể xảy ra nếu các ứng dụng đã được cài đặt thủ công. Kiểm tra quyền của các thư mục ứng dụng sau:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL được sử dụng làm cơ sở dữ liệu nhưng không hỗ trợ các ký tự 4 byte. Ví dụ: để có thể xử lý các ký tự 4 byte (như biểu tượng cảm xúc) mà không gặp sự cố về tên tệp hoặc nhận xét, bạn nên bật hỗ trợ 4 byte trong MySQL. Để biết thêm chi tiết, hãy đọc {linkstart} trang tài liệu về {linkend} này ↗.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Phiên bản này sử dụng kho lưu trữ đối tượng dựa trên S3 làm bộ lưu trữ chính. Các tệp đã tải lên được lưu trữ tạm thời trên máy chủ và do đó bạn nên có 50 GB dung lượng trống trong thư mục tạm thời của PHP. Kiểm tra nhật ký để biết đầy đủ chi tiết về đường dẫn và không gian có sẵn. Để cải thiện điều này, vui lòng thay đổi thư mục tạm thời trong php.ini hoặc tạo thêm không gian có sẵn trong đường dẫn đó.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Thư mục tạm thời của phiên bản này trỏ đến một thư mục không tồn tại hoặc không thể ghi.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Bạn đang truy cập phiên bản của mình qua kết nối bảo mật, tuy nhiên phiên bản của bạn đang tạo ra các URL không an toàn. Điều này rất có thể có nghĩa là bạn đang đứng sau một proxy ngược và các biến cấu hình ghi đè không được đặt chính xác. Vui lòng đọc {linkstart} trang tài liệu về {linkend} này ↗.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Phiên bản này đang chạy ở chế độ gỡ lỗi. Chỉ kích hoạt điều này cho sự phát triển của địa phương chứ không phải trong môi trường sản xuất.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Thư mục dữ liệu và tệp của bạn có thể truy cập được từ internet. Tệp .htaccess không hoạt động. Chúng tôi khuyên bạn nên cấu hình máy chủ web của mình để thư mục dữ liệu không thể truy cập được nữa hoặc di chuyển thư mục dữ liệu ra ngoài thư mục gốc tài liệu máy chủ web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{expected}\". Đây là một rủi ro tiềm ẩn về bảo mật hoặc quyền riêng tư, vì bạn nên điều chỉnh cài đặt này cho phù hợp.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{expected}\". Một số tính năng có thể không hoạt động chính xác, vì bạn nên điều chỉnh cài đặt này cho phù hợp.",
@@ -384,43 +341,18 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" hoặc \"{val5}\". Điều này có thể làm rò rỉ thông tin giới thiệu. Xem Khuyến nghị ↗ {linkstart}W3C {linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Tiêu đề HTTP \"Strict-Transport-Security\" không được đặt thành ít nhất \"{seconds}\" giây. Để tăng cường bảo mật, bạn nên bật HSTS như được mô tả trong mẹo ↗ bảo mật {linkstart} {linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Truy cập trang web không an toàn thông qua HTTP. Thay vào đó, bạn nên thiết lập máy chủ của mình để yêu cầu HTTPS, như được mô tả trong {linkstart} mẹo ↗ bảo mật {linkend}. Nếu không có nó, một số chức năng web quan trọng như \"sao chép vào khay nhớ tạm\" hoặc \"nhân viên dịch vụ\" sẽ không hoạt động!",
-    "Account name or email" : "Tên tài khoản hoặc email",
+    "Currently open" : "Hiện đang mở",
     "Wrong username or password." : "Tên người dùng hoặc mật khẩu sai.",
     "User disabled" : "Vô hiệu hóa sử dụng",
     "Username or email" : "Tên truy cập hoặc email",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Nếu tài khoản này tồn tại, một thông báo đặt lại mật khẩu đã được gửi đến địa chỉ email của nó. Nếu bạn không nhận được, hãy xác minh địa chỉ email và / hoặc tên tài khoản của bạn, kiểm tra thư mục spam / rác hoặc yêu cầu chính quyền địa phương của bạn trợ giúp.",
-    "Start search" : "Bắt đầu tìm kiếm",
-    "Open settings menu" : "Mở danh mục cài đặt",
-    "Settings" : "Cài đặt",
-    "Avatar of {fullName}" : "Ảnh đại diện của {fullName}",
-    "Show all contacts …" : "Hiển thị tất cả liên hệ…",
-    "No files in here" : "Không có file nào ở đây",
-    "New folder" : "Tạo thư mục",
-    "No more subfolders in here" : "Không còn thư mục con ở đây",
-    "Name" : "Tên",
-    "Size" : "Kích cỡ",
-    "Modified" : "Thay đổi",
-    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
-    "File name cannot be empty." : "Tên file không được rỗng",
-    "\"/\" is not allowed inside a file name." : "\"/\" ‎không được phép có trong tên tệp.‎",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
-    "{newName} already exists" : "{newName} đã có",
-    "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
     "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
-    "Show list view" : "Hiển thị chế độ xem danh sách",
-    "Show grid view" : "Hiển thị chế độ xem lưới",
-    "Pending" : "Đang chờ được phê duyệt",
-    "Home" : "Trang chủ",
-    "Copy to {folder}" : "Sao chép tới thư mục {folder}",
-    "Move to {folder}" : "Chuyển tới thư mục {folder}",
-    "Authentication required" : "Cần phải được xác thực",
-    "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
-    "Confirm" : "Xác nhận",
-    "Failed to authenticate, try again" : "Không thể xác thực thành công, xin vui lòng thử lại",
     "Users" : "Người dùng",
     "Username" : "Tên đăng nhập",
     "Database user" : "Người dùng cơ sở dữ liệu",
+    "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
     "Confirm your password" : "Xác nhận mật khẩu của bạn",
+    "Confirm" : "Xác nhận",
     "App token" : "Dấu hiệu ứng dụng",
     "Alternative log in using app token" : "Đăng nhập thay thế bằng mã thông báo ứng dụng",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Xin vui lòng sử dụng lệnh cập nhật bằng dòng lệnh bởi vì bạn có một bản cài đặt lớn có hơn 50 người dùng."
