@@ -19,10 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s eta %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s eta %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s eta %5$s",
-    "Education Edition" : "Hezkuntza edizioa",
+    "Education bundle" : "Hezkuntza bilduma",
     "Enterprise bundle" : "Enpresa multzoa",
     "Groupware bundle" : "Talderanerako multzoa",
     "Hub bundle" : "Hub sorta",
+    "Public sector bundle" : "Sektore publikoko sorta",
     "Social sharing bundle" : "Partekatze sozial multzoa",
     "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
     "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
@@ -36,6 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
     "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
     "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako kontua administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Your current IP address doesn’t allow you to perform admin actions" : "Zure uneko IP helbideak ez dizu administratzaile-ekintzak egiten uzten",
+    "Logged in account must be an admin or sub admin" : "Saioa hasitako kontua administratzaile edo azpi-administratzailea izan behar du",
+    "Logged in account must be an admin" : "Saioa hasitako kontua administratzailea izan behar du",
     "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
     "Wiping of device »%s« has started" : "»%s« gailuaren garbiketa hasi da",
     "»%s« started remote wipe" : "»%s«(e)k urruneko garbiketa hasi du",
@@ -76,26 +81,31 @@ OC.L10N.register(
     "seconds ago" : "duela segundo batzuk",
     "Empty file" : "Fitxategi hutsa",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s IDa duen modulua ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
+    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" debekatutako fitxategi edo karpeta-izen bat da.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" debekatutako aurrizkia da fitxategi edo karpeten izenetarako.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ez da onartzen fitxategi edo karpeta-izen baten barruan.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" debekatutako fitxategi mota bat da.",
+    "Filenames must not end with \"%1$s\"." : "Fitxategi-izenak ez dira \"%1$s\"rekin amaitu behar.",
     "File already exists" : "Badago izen bereko fitxategi bat",
     "Invalid path" : "Bide-izen baliogabea",
     "Failed to create file from template" : "Fitxategi berria txantiloitik sortzeak huts egin du",
     "Templates" : "Txantiloiak",
-    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
-    "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
-    "File name is too long" : "Fitxategi-izena luzeegia da",
-    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
+    "Path contains invalid segments" : "Bideak segmentu baliogabeak ditu",
+    "Filename contains at least one invalid character" : "Fitxategi-izenak karaktere baliogabe bat du gutxienez",
     "Empty filename is not allowed" : "Fitxategiaren izena ezin da hutsa izan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "«%s» aplikazioa ezin da instalatu appinfo fitxategia ezin delako irakurri.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" aplikazioa ezin da instalatu ez delako zerbitzariaren bertsio honekin bateragarria.",
     "__language_name__" : "Euskara",
     "This is an automatically sent email, please do not reply." : "Hau automatikoki bidalitako mezua da, ez erantzun mesedez.",
+    "Help & privacy" : "Laguntza eta pribatutasuna",
     "Appearance and accessibility" : "Itxura eta irisgarritasuna",
     "Apps" : "Aplikazioak",
     "Personal settings" : "Ezarpen pertsonalak",
     "Administration settings" : "Administrazio ezarpenak",
     "Settings" : "Ezarpenak",
     "Log out" : "Amaitu saioa",
-    "Users" : "Erabiltzaileak",
+    "Accounts" : "Kontuak",
     "Email" : "Posta elektronikoa",
     "Mail %s" : "Idatzi %s(r)i",
     "Fediverse" : "Fedibertsoa",
@@ -113,25 +123,36 @@ OC.L10N.register(
     "Headline" : "Izenburua",
     "Organisation" : "Erakundea",
     "Role" : "Zeregina",
+    "Unknown account" : "Kontu ezezaguna",
     "Additional settings" : "Ezarpen gehiago",
+    "Enter the database Login and name for %s" : "Sartu datu-basearen saioa eta izena %s(r)entzako",
+    "Enter the database Login for %s" : "Sartu %s(r)en datu-base saioa",
     "Enter the database name for %s" : "Sartu %s(r)en datu-base izena",
     "You cannot use dots in the database name %s" : "Ezin duzu punturik erabili %s datu-base izenean",
+    "MySQL Login and/or password not valid" : "MySQL saio edota pasahitza baliogabea",
     "You need to enter details of an existing account." : "Existitzen den kontu baten xehetasunak sartu behar dituzu.",
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
+    "Oracle Login and/or password not valid" : "Oracle saio edota pasahitza baliogabea",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL saio edota pasahitza baliogabea",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ez da onartzen eta %s gaizki ibiliko da plataforma honetan. Erabiltzekotan, zure ardurapean.",
     "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
+    "Set an admin Login." : "Ezarri administraziorako saioa.",
     "Set an admin password." : "Ezarri administraziorako pasahitza.",
     "Cannot create or write into the data directory %s" : "Ezin da sortu edo idatzi %s datu-direktorioan ",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
     "Sharing backend %s not found" : "Ez da %s partekatze motorra aurkitu",
     "Sharing backend for %s not found" : "Ez da %s(e)rako partekatze motorrik aurkitu",
+    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
+    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
+    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
+    "Open »%s«" : "Ireki »%s«",
+    "%1$s via %2$s" : "%2$s bidez, %1$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
     "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
-    "Open »%s«" : "Ireki »%s«",
-    "%1$s via %2$s" : "%2$s bidez, %1$s",
+    "Unknown share type" : "Partekatze mota ezezaguna",
     "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
     "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
     "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
@@ -139,13 +160,14 @@ OC.L10N.register(
     "Expiration date is in the past" : "Iraungitze-data iraganean dago",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
     "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
-    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
-    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "%s partekatzeak huts egin du, dagoeneko %s kontuarekin partekatuta dagoelako",
+    "Sharing is disabled" : "Partekatzea desgaituta dago",
     "The requested share does not exist anymore" : "Eskatutako partekatzea ez da existitzen dagoeneko",
     "The requested share comes from a disabled user" : "Eskatutako partekatzea desgaitutako erabiltzaile batengatik dator",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
     "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
+    "Input text" : "Sartu testua",
+    "The input text" : "Sarrerako testua",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
     "Tuesday" : "Asteartea",
@@ -192,6 +214,14 @@ OC.L10N.register(
     "Nov." : "Aza.",
     "Dec." : "Abe.",
     "A valid password must be provided" : "Baliozko pasahitza eman behar da",
+    "The Login is already being used" : "Saioa dagoeneko erabilita dago",
+    "Could not create account" : "Ezin izan da kontua sortu",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira saioan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
+    "A valid Login must be provided" : "Baliozko saioa eman behar da",
+    "Login contains whitespace at the beginning or at the end" : "Saioak zuriuneren bat du hasieran edo amaieran",
+    "Login must not consist of dots only" : "Saioa ezin da puntuz osatuta soilik egon",
+    "Login is invalid because files already exist for this user" : "Saioa ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
+    "Account disabled" : "Kontua desgaituta",
     "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
     "a safe home for all your data" : "zure datu guztientzako toki segurua",
@@ -224,10 +254,12 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren administratzaileari web zerbitzaria berrabiarazteko.",
     "The required %s config variable is not configured in the config.php file." : "Beharrezko %s config aldagaia ez dago konfiguratuta config.php fitxategian.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari administratzaileari Nextclouden konfigurazioa egiaztatzeko.",
+    "Your data directory is readable by other people." : "Zure datuen karpeta beste pertsonek irakur dezakete.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Aldatu baimenak 0770ra beste pertsonak karpeta ikusi ezin izateko.",
     "Your data directory must be an absolute path." : "Zure datuen karpeta bide-izen absolutua izan behar da.",
     "Check the value of \"datadirectory\" in your configuration." : "Egiaztatu \"datadirectory\"-ren balioa zure konfigurazioan.",
     "Your data directory is invalid." : "Zure datuen karpeta baliogabea da.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Ziurtatu datu-direktorioaren erroan  \"%1$s\" izeneko fitxategi bat dagoela.  \"%2$s\" edukia izan behar du.",
     "Action \"%s\" not supported or implemented." : "\"%s\" ekintza ez da onartzen edo ez dago inplementaturik.",
     "Authentication failed, wrong token or provider ID given" : "Autentifikazioak huts egin du, token edo hornitzaile ID okerra eman da",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Eskaera osatzeko parametroak falta dira. Falta diren parametroak: \"%s\"",
@@ -239,19 +271,101 @@ OC.L10N.register(
     "Storage connection error. %s" : "Biltegiratze-konexioaren errorea. %s",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
+    "Transcribe audio" : "Audioa transkribatu",
+    "Transcribe the things said in an audio" : "Audio batean esandako gauzak transkribatu",
+    "Audio input" : "Audio sarrera",
+    "The audio to transcribe" : "Transkribatzeko audioa",
+    "Transcription" : "Transkripzioa",
+    "The transcribed text" : "Transkribatutako testua",
+    "Context write" : "Testuingurua idaztea",
+    "Writes text in a given style based on the provided source material." : "Testua estilo jakin batean idazten du, emandako iturri-materialean oinarrituta.",
+    "Writing style" : "Idazteko estiloa",
+    "Demonstrate a writing style that you would like to immitate" : "Erakutsi imitatu nahiko zenukeen idazteko estiloa",
+    "Source material" : "Jatorrizko materiala",
+    "The content that would like to be rewritten in the new writing style" : "Idazkera estilo berrian berridatzi nahi den edukia",
+    "Generated text" : "Sortutako testua",
+    "The generated text with content from the source material in the given style" : "Jatorri-materialaren edukiarekin emandako estiloan sortutako testua.",
+    "Emoji generator" : "Emojien sortzailea",
+    "Takes text and generates a representative emoji for it." : "Testua hartzen du eta emoji adierazgarri bat sortzen du.",
+    "The text to generate an emoji for" : "Emoji bat sortzeko testua",
+    "Generated emoji" : "Sortutako emojia",
+    "The generated emoji based on the input text" : "Sarrerako testuan oinarrituta sortutako emojia",
+    "Generate image" : "Sortu irudia",
+    "Generate an image from a text prompt" : "Sortu irudi bat testu-gonbita batetik",
+    "Prompt" : "Galdera",
+    "Describe the image you want to generate" : "Deskribatu sortu nahi duzun irudia",
+    "Number of images" : "Irudi kopurua",
+    "How many images to generate" : "Zenbat irudi sortu behar diren",
+    "Output images" : "Irteera irudiak",
+    "The generated images" : "Sortutako irudiak",
+    "Free text to text prompt" : "Testu librea mezuaren testura",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Abisu arbitrario bat exekutatzen du erantzuna itzultzen duen hizkuntza-eredu baten bidez",
+    "Describe a task that you want the assistant to do or ask a question" : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin",
+    "Generated reply" : "Sortutako erantzuna",
+    "The generated text from the assistant" : "Laguntzaileak sortutako testua",
+    "Chat" : "Chat",
+    "Chat with the assistant" : "Hitz egin txat bidez laguntzailarekin",
+    "System prompt" : "Sistemaren gonbita",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
+    "Chat message" : "Txat mezua",
+    "Chat history" : "Txat historia",
+    "The history of chat messages before the current message, starting with a message by the user" : "Uneko mezuaren aurreko txat mezuen historia, erabiltzailearen mezu batetik hasita",
+    "Response message" : "Erantzun mezua",
+    "The generated response as part of the conversation" : "Sorturiko erantzuna, elkarrizketaren zati gisa",
+    "Formalize text" : "Formaldu testua",
+    "Takes a text and makes it sound more formal" : "Testu bat hartzen du eta doinu formalagoa ematen dio.",
+    "Write a text that you want the assistant to formalize" : "Idatz ezazu laguntzaileak formaltzea nahi duzun testu bat",
+    "Formalized text" : "Formaldutako testua",
+    "The formalized text" : "Formaldutako testua",
+    "Generate a headline" : "Sortu izenburu bat",
+    "Generates a possible headline for a text." : "Testu baten izenburu posiblea sortzen du.",
+    "Original text" : "Jatorrizko testua",
+    "The original text to generate a headline for" : "Izenburu bat sortzeko jatorrizko testua",
+    "The generated headline" : "Sortutako izenburua",
+    "Reformulate text" : "Birformulatu testua",
+    "Takes a text and reformulates it" : "Testu bat hartu eta birformulatu egiten du",
+    "Write a text that you want the assistant to reformulate" : "Idatz ezazu laguntzaileak birformulatzea nahi duzun testu bat",
+    "Reformulated text" : "Birformulatutako testua",
+    "The reformulated text, written by the assistant" : "Birformulaturiko testua, laguntzaileak idatzia",
+    "Simplify text" : "Sinpletu testua",
+    "Takes a text and simplifies it" : "Testu bat hartu eta sinpletu egiten du",
+    "Write a text that you want the assistant to simplify" : "Idatz ezazu laguntzaileak sinpletzea nahi duzun testu bat",
+    "Simplified text" : "Sinpletutako testua",
+    "The simplified text" : "Sinpletutako testua",
+    "Summarize" : "Laburtu",
+    "Summarizes a text" : "Laburtu testu bat",
+    "The original text to summarize" : "Laburtu beharreko jatorrizko testua",
+    "Summary" : "Laburpena",
+    "The generated summary" : "Sortutako laburpena",
+    "Extract topics" : "Atera gaiak",
+    "Extracts topics from a text and outputs them separated by commas" : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu",
+    "The original text to extract topics from" : "Gaiak ateratzeko jatorrizko testua",
+    "Topics" : "Gaiak",
+    "The list of extracted topics" : "Ateratako gaien zerrenda",
+    "Translate" : "Itzuli",
+    "Translate text from one language to another" : "Itzuli testua hizkuntza batetik bestera",
+    "Origin text" : "Jatorrizko testua",
+    "The text to translate" : "Itzuli beharreko testua",
+    "Origin language" : "Jatorrizko hizkuntza",
+    "The language of the origin text" : "Jatorrizko testuaren hizkuntza",
+    "Target language" : "Helburuko hizkuntza",
+    "The desired language to translate the origin text in" : "Jatorrizko testua itzultzeko nahi den hizkuntza",
+    "Result" : "Emaitza",
+    "The translated text" : "Itzulitako testua",
     "Free prompt" : "Gonbita librea",
     "Runs an arbitrary prompt through the language model." : "Hizkuntza ereduaren zehar esaldi arbitrario bat exekutatzen du.",
     "Generate headline" : "Sortu izenburua",
-    "Generates a possible headline for a text." : "Testu baten izenburu posiblea sortzen du.",
-    "Summarize" : "Laburtu",
     "Summarizes text by reducing its length without losing key information." : "Testua laburtzen du bere luzera murrizten informazio baliotsua galdu gabe.",
-    "Extract topics" : "Atera gaiak",
     "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
-    "404" : "404",
+    "Education Edition" : "Hezkuntza edizioa",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
     "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
     "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
+    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
+    "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
+    "File name is too long" : "Fitxategi-izena luzeegia da",
     "Help" : "Laguntza",
+    "Users" : "Erabiltzaileak",
     "Unknown user" : "Erabiltzaile ezezaguna",
     "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
     "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
@@ -268,9 +382,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
     "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
     "User disabled" : "Erabiltzaile desgaituta",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 behar da",
-    "Please upgrade your database version." : "Mesedez eguneratu zure datu-basearen bertsioa.",
     "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela."
 },
 "nplurals=2; plural=(n != 1);");
