@@ -65,26 +65,25 @@ OC.L10N.register(
     "in a few seconds" : "muutaman sekunnin päästä",
     "seconds ago" : "sekunteja sitten",
     "Empty file" : "Tyhjä tiedosto",
+    "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
     "File already exists" : "Tiedosto on jo olemassa",
     "Invalid path" : "Virheellinen polku",
     "Failed to create file from template" : "Tiedoston luominen mallipohjasta epäonnistui",
     "Templates" : "Mallipohjat",
-    "File name is a reserved word" : "Tiedoston nimi on varattu sana",
-    "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
-    "File name is too long" : "Tiedoston nimi on liian pitkä",
-    "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
+    "Filename contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
     "Empty filename is not allowed" : "Tiedostonimi ei voi olla tyhjä",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Sovellusta \"%s\" ei voi asentaa, koska appinfo-tiedostoa ei voi loi lukea.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Sovellusta \"%s\" ei voi asentaa, koska se ei ole yhteensopiva tämän palvelinversion kanssa.",
     "__language_name__" : "suomi",
     "This is an automatically sent email, please do not reply." : "Tämä on automaattisesti lähetetty viesti. Älä vastaa tähän viestiin.",
+    "Help & privacy" : "Tuki ja tietosuoja",
     "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
     "Apps" : "Sovellukset",
     "Personal settings" : "Henkilökohtaiset asetukset",
     "Administration settings" : "Ylläpitäjän asetukset",
     "Settings" : "Asetukset",
     "Log out" : "Kirjaudu ulos",
-    "Users" : "Käyttäjät",
+    "Accounts" : "Tilit",
     "Email" : "Sähköposti",
     "Mail %s" : "Lähetä sähköpostia %s",
     "Phone" : "Puhelin",
@@ -111,11 +110,15 @@ OC.L10N.register(
     "Set an admin password." : "Aseta ylläpitäjän salasana.",
     "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
     "Sharing backend for %s not found" : "Jakamisen taustaosaa kohteelle %s ei löytynyt",
+    "%1$s shared »%2$s« with you" : "%1$s jakoi kohteen »%2$s« kanssasi",
+    "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
+    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
+    "Open »%s«" : "Avaa »%s«",
+    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s jakoi kohteen »%2$s« kanssasi ja haluaa lisätä:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s jakoi kohteen »%2$s« kanssasi ja haluaa lisätä",
     "»%s« added a note to a file shared with you" : "»%s« lisäsi huomion jakamaasi tiedostoon",
-    "Open »%s«" : "Avaa »%s«",
-    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
+    "Unknown share type" : "Tuntematon jaon tyyppi",
     "You are not allowed to share %s" : "Oikeutesi eivät riitä kohteen %s jakamiseen.",
     "Cannot increase permissions of %s" : "Kohteen %s käyttöoikeuksien lisääminen ei onnistu",
     "Files cannot be shared with delete permissions" : "Tiedostoja ei voi jakaa poistamisoikeuksilla",
@@ -123,9 +126,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Vanhenemispäivä on menneisyydessä",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Vanhenemispäivän voi asettaa korkeintaan %n päivään tulevaisuuteen","Vanhenemispäivän voi asettaa korkeintaan %n päivään tulevaisuuteen"],
     "Sharing is only allowed with group members" : "Jakaminen on sallittu vain ryhmäjäsenten kesken",
-    "%1$s shared »%2$s« with you" : "%1$s jakoi kohteen »%2$s« kanssasi",
-    "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
-    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
     "The requested share does not exist anymore" : "Pyydettyä jakoa ei ole enää olemassa",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Käyttäjää ei luotu, koska käyttäjäraja on tullut täyteen. Tarkista ilmoitukset saadaksesi lisätietoja.",
     "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
@@ -202,7 +202,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Pyydä palvelimen ylläpitäjää tarkastamaan Nextcloudin määritykset.",
     "Your data directory must be an absolute path." : "Datahakemiston tulee olla absoluuttinen polku.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Varmista että datahakemiston juuressa on tiedosto nimeltä \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "Toiminto \"%s\" ei ole tuettu tai sitä ei ole toteutettu.",
     "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\".",
     "Storage unauthorized. %s" : "Tallennustila ei ole valtuutettu. %s",
@@ -210,9 +209,28 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
     "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
     "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
-    "404" : "404",
+    "Generate image" : "Luo kuva",
+    "Generate an image from a text prompt" : "Luo kuva tekstikehotteen perusteella",
+    "Prompt" : "Kehote",
+    "Describe the image you want to generate" : "Kuvaile luotava kuva",
+    "Number of images" : "Kuvien määrä",
+    "How many images to generate" : "Kuinka monta kuvaa luodaan",
+    "Output images" : "Valmiit kuvat",
+    "The generated images" : "Luodut kuvat",
+    "Summarize" : "Luo yhteenveto",
+    "Summarizes a text" : "Luo yhteenvedon tekstistä",
+    "The original text to summarize" : "Alkuperäinen teksti, josta yhteenveto muodostetaan",
+    "Summary" : "Yhteenveto",
+    "The generated summary" : "Luotu yhteenveto",
+    "Translate" : "Käännä",
+    "Target language" : "Kohdekieli",
+    "Result" : "Tulos",
     "Logged in user must be an admin" : "Sisäänkirjautuneen käyttäjän tulee olla ylläpitäjä",
+    "File name is a reserved word" : "Tiedoston nimi on varattu sana",
+    "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
+    "File name is too long" : "Tiedoston nimi on liian pitkä",
     "Help" : "Ohje",
+    "Users" : "Käyttäjät",
     "Unknown user" : "Tuntematon käyttäjä",
     "MySQL username and/or password not valid" : "MySQL-käyttäjätunnus ja/tai -salasana on väärin",
     "Oracle username and/or password not valid" : "Oraclen käyttäjätunnus ja/tai salasana on väärin",
@@ -227,8 +245,7 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Käyttäjänimi ei voi koostua vain pisteistä",
     "Username is invalid because files already exist for this user" : "Käyttäjänimi on virheellinen koska tiedostoja on olemassa tälle käyttäjälle",
     "User disabled" : "Käyttäjä poistettu käytöstä",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 vaaditaan.",
-    "Please upgrade your database version." : "Päivitä tietokannan versio.",
-    "Your data directory is readable by other users." : "Datahakemistosi on muiden käyttäjien luettavissa."
+    "Your data directory is readable by other users." : "Datahakemistosi on muiden käyttäjien luettavissa.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Varmista että datahakemiston juuressa on tiedosto nimeltä \".ocdata\"."
 },
 "nplurals=2; plural=(n != 1);");
