@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
-    "Education Edition" : "Edición para educación",
+    "Education bundle" : "Paquete de educación",
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de software colaborativo",
     "Hub bundle" : "Paquete de concentradores",
@@ -37,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
     "Server version %s or higher is required." : "Precísase da versión %s ou superior do servidor.",
     "Server version %s or lower is required." : "Precísase da versión %s ou inferior do servidor.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta iniciada debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta opción",
-    "Logged in account must be an admin or sub admin" : "A conta iniciada debe ser administrador ou subadministrador",
-    "Logged in account must be an admin" : "A conta iniciada debe ser un administrador",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta que accede debe ser de administración, de subadministración ou ter dereitos especiais para acceder a este axuste",
+    "Your current IP address doesn’t allow you to perform admin actions" : "O seu enderezo IP actual non lle permite realizar accións de administración",
+    "Logged in account must be an admin or sub admin" : "A conta que accede debe ser de administración ou de subadministración",
+    "Logged in account must be an admin" : "A conta que accede debe ser de administración",
     "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
     "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
     "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
@@ -55,7 +56,7 @@ OC.L10N.register(
     "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de ficheiro descoñecido",
     "Invalid image" : "Imaxe incorrecta",
-    "Avatar image is not square" : "A imaxe do avatar non é un cadrado",
+    "Avatar image is not square" : "A imaxe do avatar non é cadrada",
     "Files" : "Ficheiros",
     "View profile" : "Ver o perfil",
     "Local time: %s" : "Hora local: %s",
@@ -80,26 +81,34 @@ OC.L10N.register(
     "seconds ago" : "segundos atrás",
     "Empty file" : "Ficheiro baleiro",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte coa administración desta instancia.",
+    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
+    "\"%1$s\" is a forbidden file or folder name." : "«%1$s» é un nome de ficheiro ou cartafol prohibido.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "«%1$s» é un prefixo prohibido para os nomes de ficheiros ou cartafoles.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» non está permitido nun nome de ficheiro ou cartafol.",
+    "\"%1$s\" is a forbidden file type." : "«%1$s» é un tipo de ficheiro prohibido.",
+    "Filenames must not end with \"%1$s\"." : "Os nomes de ficheiros non deben rematar con «%1$s».",
+    "Invalid parent path" : "A ruta principal non é correcta",
     "File already exists" : "O ficheiro xa existe",
-    "Invalid path" : "Ruta incorrecta.",
+    "Invalid path" : "A ruta non é correcta.",
     "Failed to create file from template" : "Produciuse un fallo ao crear un ficheiro a partir do modelo",
     "Templates" : "Modelos",
-    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
-    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
-    "File name is too long" : "O nome de ficheiro é longo de máis",
-    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
+    "Path contains invalid segments" : "A ruta contén segmentos non válidos",
+    "Filename is a reserved word" : "O nome de ficheiro é unha palabra reservada",
+    "Filename contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
+    "Filename is too long" : "O nome de ficheiro é longo de máis",
     "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Non é posíbel instalar a aplicación «%s» por mor de non poder ler o ficheiro appinfo.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Non é posíbel instalar a aplicación «%s» por mor de non ser compatíbel con esta versión do servidor.",
     "__language_name__" : "Galego",
     "This is an automatically sent email, please do not reply." : "Este é un correo enviado automaticamente, non responda.",
+    "Help & privacy" : "Axuda e privacidade",
     "Appearance and accessibility" : "Aspecto e accesibilidade",
     "Apps" : "Aplicacións",
     "Personal settings" : "Axustes persoais",
     "Administration settings" : "Axustes de administración",
     "Settings" : "Axustes",
     "Log out" : "Saír",
-    "Users" : "Usuarios",
+    "Accounts" : "Contas",
     "Email" : "Correo-e",
     "Mail %s" : "Correo %s",
     "Fediverse" : "Fediverso",
@@ -119,45 +128,81 @@ OC.L10N.register(
     "Role" : "Cargo",
     "Unknown account" : "Conta descoñecida",
     "Additional settings" : "Axustes adicionais",
-    "Enter the database Login and name for %s" : "Introduza o inicio de sesión e o nome da base de datos para %s",
-    "Enter the database Login for %s" : "Introduza a base de datos Iniciar sesión para %s",
+    "Enter the database Login and name for %s" : "Introduza o acceso a base de datos e o nome para %s",
+    "Enter the database Login for %s" : "Introduza o acceso a base de datos para %s",
     "Enter the database name for %s" : "Introduza o nome da base de datos para %s",
     "You cannot use dots in the database name %s" : "Non pode usar puntos no nome da base de datos %s",
-    "MySQL Login and/or password not valid" : "O inicio de sesión de MySQL e/ou o contrasinal non son válidos",
+    "MySQL Login and/or password not valid" : "O acceso de MySQL e/ou o contrasinal non son válidos",
     "You need to enter details of an existing account." : "Debe introducir os detalles dunha conta existente.",
     "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
-    "Oracle Login and/or password not valid" : "O inicio de sesión ou contrasinal de Oracle non é válido",
-    "PostgreSQL Login and/or password not valid" : "O inicio de sesión e/ou o contrasinal de PostgreSQL non son válidos",
+    "Oracle Login and/or password not valid" : "O acceso de Oracle e/ou o contrasinal non son válidos",
+    "PostgreSQL Login and/or password not valid" : "O acceso de PostgreSQL e/ou o contrasinal non son válidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
-    "Set an admin Login." : "Establece un inicio de sesión de administrador.",
+    "Set an admin Login." : "Definir un acceso de administración",
     "Set an admin password." : "Estabeleza un contrasinal de administrador",
     "Cannot create or write into the data directory %s" : "Non é posíbel crear ou escribir no directorio de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
     "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
-    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
-    "Open »%s«" : "Abrir «%s»",
-    "%1$s via %2$s" : "%1$s mediante %2$s",
-    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
-    "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
-    "Files cannot be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
-    "Files cannot be shared with create permissions" : "Non é posíbel compartir ficheiros con permisos de creación",
-    "Expiration date is in the past" : "Xa pasou a data de caducidade",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel estabelecer a data de caducidade máis alo de %n día no futuro","Non é posíbel estabelecer a data de caducidade máis alo de %n días no futuro"],
-    "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
-    "Sharing %s failed, because this item is already shared with the account %s" : "Produciuse un erro ao compartir %s, porque este elemento xa se comparte coa conta %s",
     "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
     "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
     "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
+    "Open »%s«" : "Abrir «%s»",
+    "%1$s via %2$s" : "%1$s mediante %2$s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
+    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
+    "Passwords are enforced for link and mail shares" : "É obrigatorio o emprego de contrasinais para compartir por ligazón e por correo",
+    "SharedWith is not a valid user" : "O destinatario da compartición non é un usuario válido",
+    "SharedWith is not a valid group" : "O destinatario da compartición non é un grupo válido",
+    "SharedWith should be empty" : "O destinatario da compartición debe estar baleiro",
+    "SharedWith should not be empty" : "O destinatario da compartición non debe estar baleiro",
+    "SharedWith is not a valid circle" : "O destinatario da compartición non é un círculo válido",
+    "Unknown share type" : "Tipo descoñecido de compartición",
+    "SharedBy should be set" : "Debe estar definido quen inicia a compartición",
+    "Cannot share with yourself" : "Non é posíbel compartir con un mesmo.",
+    "Path should be set" : "A ruta compartida debe estar definida",
+    "Path should be either a file or a folder" : "A ruta compartida debe ser a un ficheiro ou un cartafol",
+    "You cannot share your root folder" : "Non pode compartir o seu cartafol raíz",
+    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
+    "A share requires permissions" : "Requírense permisos válidos para compartir",
+    "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
+    "Shares need at least read permissions" : "As comparticións necesitan polo menos permisos de lectura",
+    "Files cannot be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
+    "Files cannot be shared with create permissions" : "Non é posíbel compartir ficheiros con permisos de creación",
+    "Expiration date is in the past" : "Xa pasou a data de caducidade",
+    "Expiration date is enforced" : "A data de caducidade é obrigatoria",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel definir a data de caducidade máis alo de %n día no futuro","Non é posíbel definir a data de caducidade máis alo de %n días no futuro"],
+    "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Produciuse un fallo ao compartir %s, porque este elemento xa se comparte coa conta %s",
+    "Group sharing is now allowed" : "Agora está permitida a compartición en grupo",
+    "Sharing is only allowed within your own groups" : "Só se permite compartir dentro dos seus propios grupos",
+    "Path is already shared with this group" : "A ruta xa está compartida con este grupo",
+    "Link sharing is not allowed" : "Non se permite compartir ligazóns",
+    "Public upload is not allowed" : "Non se permite o envío público",
+    "Path contains files shared with you" : "A ruta contén ficheiros compartidos con Vde.",
+    "Sharing is disabled" : "A compartición está desactivada",
+    "Sharing is disabled for you" : "A compartición está desactivada para Vde.",
+    "Cannot share with the share owner" : "Non é posíbel compartir co propietario do compartido",
+    "Share does not have a full ID" : "A compartición non ten unha ID completa",
+    "Cannot change share type" : "Non é posíbel cambiar o tipo de compartición",
+    "Can only update recipient on user shares" : "Só é posíbel actualizar o destinatario nas comparticións por usuarios",
+    "Cannot enable sending the password by Talk with an empty password" : "Non é posíbel activar o envío do contrasinal por Talk cun contrasinal baleiro",
+    "Cannot enable sending the password by Talk without setting a new password" : "Non é posíbel activar o envío do contrasinal por Talk sen definir un novo contrasinal",
+    "Cannot disable sending the password by Talk without setting a new password" : "Non é posíbel desactivar o envío do contrasinal por Talk sen definir un novo contrasinal",
+    "Share provider does not support accepting" : "O provedor de comparticións non admite a aceptación",
+    "Cannot change target of link share" : "Non é posíbel cambiar o destino da ligazón compartida",
+    "Invalid recipient" : "Destinatario de compartición incorrecto",
+    "Group \"%s\" does not exist" : "O grupo «%s» non existe",
     "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
     "The requested share comes from a disabled user" : "A compartición solicitada procede dun usuario desactivado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Non se creou o usuario porque acadouse o límite de usuarios. Consulte as súas notificacións para obter máis información.",
     "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
+    "Input text" : "Texto de entrada",
+    "The input text" : "O texto de entrada",
     "Sunday" : "domingo",
     "Monday" : "luns",
     "Tuesday" : "martes",
@@ -204,14 +249,14 @@ OC.L10N.register(
     "Nov." : "nov.",
     "Dec." : "dec.",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
-    "The Login is already being used" : "O inicio de sesión xa se está a usar",
-    "Could not create account" : "Non se puido crear a conta",
-    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun inicio de sesión: \"a-z\", \"A-Z\", \"0-9\", espazos e \"_.@-'\"",
-    "A valid Login must be provided" : "É necesario proporcionar un inicio de sesión válido",
-    "Login contains whitespace at the beginning or at the end" : "O inicio de sesión contén espazos en branco ao comezo ou ao final",
-    "Login must not consist of dots only" : "O inicio de sesión non debe estar composto só por puntos",
-    "Login is invalid because files already exist for this user" : "O inicio de sesión non é válido porque xa existen ficheiros para este usuario",
-    "Account disabled" : "Conta deshabilitada",
+    "The Login is already being used" : "O acceso xa se está a usar",
+    "Could not create account" : "Non foi posíbel crear a conta",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun acceso: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
+    "A valid Login must be provided" : "Ten que fornecer un acceso válido",
+    "Login contains whitespace at the beginning or at the end" : "O acceso contén espazos en branco ao comezo ou ao final",
+    "Login must not consist of dots only" : "O acceso non debe estar composto só por puntos",
+    "Login is invalid because files already exist for this user" : "O acceso non é válido porque xa existen ficheiros para este usuario",
+    "Account disabled" : "Conta desactivada",
     "Login canceled by app" : "Acceso cancelado pola aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
     "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
@@ -244,12 +289,12 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
     "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Pídalle á administración do seu servidor que verifique a configuración de Nextcloud.",
-    "Your data directory is readable by other people." : "Outras persoas poden ler o teu directorio de datos.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Por favor, cambie os permisos a 0770 para que o directorio non poida ser listado por outras persoas.",
+    "Your data directory is readable by other people." : "Outras persoas poden ler o seu directorio de datos.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outras persoas.",
     "Your data directory must be an absolute path." : "O seu directorio de datos debe ser unha ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Comprobe o valor de «datadirectory» na súa configuración-",
     "Your data directory is invalid." : "O seu directorio de datos non é válido.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Asegúrese de que existe un ficheiro chamado «%1$s» na raíz do directorio de datos. Debería ter o contido: «%2$s»",
     "Action \"%s\" not supported or implemented." : "A acción «%s» non está admitida ou implementada.",
     "Authentication failed, wrong token or provider ID given" : "Produciuse un fallo de autenticación. Deuse un testemuño ou un ID de provedor erróneos.",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar a solicitude. Parámetros que faltan: «%s»",
@@ -261,21 +306,103 @@ OC.L10N.register(
     "Storage connection error. %s" : "Produciuse un erro na conexión ao almacenamento. %s",
     "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
     "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
+    "Transcribe audio" : "Transcribir son",
+    "Transcribe the things said in an audio" : "Transcribir as cousas ditas nun ficheiro de son",
+    "Audio input" : "Entrada de son",
+    "The audio to transcribe" : "O audio para transcribir",
+    "Transcription" : "Transcrición",
+    "The transcribed text" : "O texto transcrito",
+    "Context write" : "Redacción por contexto",
+    "Writes text in a given style based on the provided source material." : "Escribe texto nun estilo determinado baseándose no material orixinal fornecido.",
+    "Writing style" : "Estilo de escritura",
+    "Demonstrate a writing style that you would like to immitate" : "Demostre un estilo de escritura que lle gustaría imitar",
+    "Source material" : "Material orixinal",
+    "The content that would like to be rewritten in the new writing style" : "O contido que quere que sexa reescrito no novo estilo de escritura",
+    "Generated text" : "Texto xerado",
+    "The generated text with content from the source material in the given style" : "O texto xerado con contido do material orixinal no estilo indicado",
+    "Emoji generator" : "Xerador de «emojis»",
+    "Takes text and generates a representative emoji for it." : "Toma texto e xera un «emoji» representativo para el.",
+    "The text to generate an emoji for" : "O texto para xerar un «emoji»",
+    "Generated emoji" : "«Emoji» xerado",
+    "The generated emoji based on the input text" : "O «emoji» xerado en función do texto introducido",
+    "Generate image" : "Xerar imaxe",
+    "Generate an image from a text prompt" : "Xerar unha imaxe a partir dunha indicación de texto",
+    "Prompt" : "Indicación",
+    "Describe the image you want to generate" : "Describa a imaxe que quere xerar",
+    "Number of images" : "Número de imaxes",
+    "How many images to generate" : "Cantas imaxes xerar",
+    "Output images" : "Imaxes de saída",
+    "The generated images" : "As imaxes xeradas",
+    "Free text to text prompt" : "Texto libre para indicación de texto",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Procesa unha indicación arbitraria a través dun modelo de linguaxe que devolve unha resposta",
+    "Describe a task that you want the assistant to do or ask a question" : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta",
+    "Generated reply" : "Resposta xerada",
+    "The generated text from the assistant" : "O texto xerado polo asistente",
+    "Chat" : "Parola",
+    "Chat with the assistant" : "Parola co asistente",
+    "System prompt" : "Indicador do sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regras e supostos que o asistente debe seguir durante a conversa.",
+    "Chat message" : "Mensaxe de parola",
+    "Chat history" : "Historial de parola",
+    "The history of chat messages before the current message, starting with a message by the user" : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario",
+    "Response message" : "Mensaxe de resposta",
+    "The generated response as part of the conversation" : "A resposta xerada como parte da conversa",
+    "Formalize text" : "Formalizar texto",
+    "Takes a text and makes it sound more formal" : "Toma un texto e fai que soe máis formal",
+    "Write a text that you want the assistant to formalize" : "Escriba un texto que queira que sexa formalizado polo asistente",
+    "Formalized text" : "Texto formalizado",
+    "The formalized text" : "O texto formalizado",
+    "Generate a headline" : "Xerar un titular",
+    "Generates a possible headline for a text." : "Xera un posíbel titular para un texto.",
+    "Original text" : "Texto orixinal",
+    "The original text to generate a headline for" : "O texto orixinal para xerar un titular",
+    "The generated headline" : "O titular xerado",
+    "Reformulate text" : "Reformular texto",
+    "Takes a text and reformulates it" : "Toma un texto e reformúlao",
+    "Write a text that you want the assistant to reformulate" : "Escriba un texto que queira que sexa reformulado polo asistente",
+    "Reformulated text" : "Texto reformulado",
+    "The reformulated text, written by the assistant" : "O texto reformulado, escrito polo asistente",
+    "Simplify text" : "Simplificar texto",
+    "Takes a text and simplifies it" : "Toma un texto e simplifícao",
+    "Write a text that you want the assistant to simplify" : "Escriba un texto que queira que sexa simplificado polo asistente",
+    "Simplified text" : "Texto simplificado",
+    "The simplified text" : "O texto simplificado",
+    "Summarize" : "Resumir",
+    "Summarizes a text" : "Resume un texto",
+    "The original text to summarize" : "O texto orixinal para resumir",
+    "Summary" : "Resumo",
+    "The generated summary" : "O resumo xerado",
+    "Extract topics" : "Extraer temas",
+    "Extracts topics from a text and outputs them separated by commas" : "Extrae temas dun texto e amósaos separados por comas",
+    "The original text to extract topics from" : "O texto orixinal para extraer temas",
+    "Topics" : "Temas",
+    "The list of extracted topics" : "A lista de temas extraídos",
+    "Translate" : "Traducir",
+    "Translate text from one language to another" : "Traducir texto dun idioma a outro",
+    "Origin text" : "Texto orixinal",
+    "The text to translate" : "O texto a traducir",
+    "Origin language" : "Idioma do orixinal",
+    "The language of the origin text" : "O idioma do texto orixinal",
+    "Target language" : "Idioma de destino",
+    "The desired language to translate the origin text in" : "O idioma desexado para traducir o texto orixinal",
+    "Result" : "Resultado",
+    "The translated text" : "O texto traducido",
     "Free prompt" : "Indicación libre",
     "Runs an arbitrary prompt through the language model." : "Procesa unha indicación arbitraria a través do modelo de linguaxe.",
-    "Generate headline" : "Xerar título",
-    "Generates a possible headline for a text." : "Xera un posíbel título para un texto.",
-    "Summarize" : "Resumir",
+    "Generate headline" : "Xerar titular",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reducindo a súa lonxitude sen perder a información clave.",
-    "Extract topics" : "Extraer temas",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
-    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
-    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
+    "Education Edition" : "Edición para educación",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser de administración, de subadministración ou ter dereitos especiais para acceder a este axuste",
+    "Logged in user must be an admin or sub admin" : "O usuario que accede debe ser de administración ou de subadministración",
+    "Logged in user must be an admin" : "O usuario que accede debe ser de administración",
+    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
+    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
+    "File name is too long" : "O nome de ficheiro é longo de máis",
     "Help" : "Axuda",
+    "Users" : "Usuarios",
     "Unknown user" : "Usuario descoñecido",
-    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
+    "Enter the database username and name for %s" : "Introduza o nome de usuario da base de datos e o nome para %s",
     "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
     "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
     "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
@@ -290,9 +417,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
     "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
     "User disabled" : "Usuario desactivado",
-    "PostgreSQL >= 9 required." : "Precísase de PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Anove a versión da súa base de datos",
-    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios."
+    "Your data directory is readable by other users." : "Outros usuarios poden ler o seu directorio de datos.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos."
 },
 "nplurals=2; plural=(n != 1);");
