@@ -9,7 +9,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s და %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s და %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s და %5$s",
-    "Education Edition" : "საგანმანათლებლო გამოცემა",
     "Enterprise bundle" : "ენტერპრაის კონსტრუქცია",
     "Groupware bundle" : "ჯგუფური კონსტრუქცია",
     "Social sharing bundle" : "სოციალური გაზიარების შეკვრა",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "The library %s is not available." : "ბიბლიოთეკა %s ვერ იქნა ნაპოვნი.",
     "Server version %s or higher is required." : "საჭიროა სერვერი ვერსიით %s ან მეტი.",
     "Server version %s or lower is required." : "საჭიროა სერვერი ვერსიით %s ან ნაკლები.",
-    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
     "Authentication" : "აუტენტიფიკაცია",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
     "Invalid image" : "არასწორი სურათი",
@@ -46,21 +44,18 @@ OC.L10N.register(
     "in a few seconds" : "რამდენიმე წამში",
     "seconds ago" : "წამის წინ",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "მოდული ID-ით: %s არ არსებობს. გთხოვთ აამოქმედოთ ის აპლიკაციების პარამეტრებში ან დაუკავშირდეთ ადმინისტრატორს.",
-    "File already exists" : "ფაილი უკვე არსებობს",
-    "File name is a reserved word" : "ფაილის სახელი რეზერვირებული სიტყვაა",
-    "File name contains at least one invalid character" : "ფაილის სახელი მოიცავს დაუშვებელ სიმბოლოს",
-    "File name is too long" : "ფაილის სახელი ზედმეტად გრძელია",
     "Dot files are not allowed" : "წერტილოვანი ფაილები არაა ნებადართლი",
+    "File already exists" : "ფაილი უკვე არსებობს",
+    "Filename contains at least one invalid character" : "ფაილის სახელი შეიცავს მინ. 1 არასწორ ნიშანს",
     "Empty filename is not allowed" : "ცარიელი ფაილის სახელი არაა ნებადართული",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან appinfo ფაილი არ იკითხება.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან ის ამ სერვერის ვერსიასთან არაა თავსებადი.",
     "__language_name__" : "ქართული",
     "This is an automatically sent email, please do not reply." : "ეს ელ-წერილი გამოგზავნილია ავტომატურად, გთხოვთ არ უპასუხოთ.",
-    "Help" : "დახმარება",
     "Apps" : "აპლიკაციები",
     "Settings" : "პარამეტრები",
     "Log out" : "გასვლა",
-    "Users" : "მომხმარებლები",
+    "Accounts" : "ანგარიში",
     "Email" : "ელ-ფოსტა",
     "Phone" : "ტელეფონი",
     "Twitter" : "Twitter-ი",
@@ -68,27 +63,23 @@ OC.L10N.register(
     "Address" : "მისამართი",
     "Profile picture" : "პროფილის სურათი",
     "About" : "შესახებ",
-    "Unknown user" : "ამოუცნობი მომხმარებელი",
     "Additional settings" : "დამატებითი პარამეტრები",
     "You need to enter details of an existing account." : "საჭიროა შეიყვანოთ არსებული ანგარიშის დეტალები.",
     "Oracle connection could not be established" : "Oracle კავშირი ვერ დამყარდა",
-    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X არაა მხარდაჭერილი და %s ამ პლატფორმაზე სწორად არ იმუშავებს. გამოიყენეთ საკუთარი რისკით!",
     "For the best results, please consider using a GNU/Linux server instead." : "საუკეთესო შედეგებისთვის სანაცვლოდ გამოიყენეთ GNU/Linux სერვერი.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "როგორც ჩანს ეს %s ინსტანცია მოქმედებს 32-ბიტიან PHP გარემოზე და open_basedir php.ini-ში კონფიგურირებულია. ეს 4 გბ-ზე დიდ ფაილებთან გამოიწვევს პრობლემს და რეკომედირებული არაა.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "გთხოვთ ამოშალოთ open_basedir პარამეტრი php.ini-დან ან გადახვიდეთ 64-ბიტიან PHP-ზე.",
-    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
     "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "გაზიარების ბექენდმა %s-მ მოქმედებაში უნდა მოიყვანოს ინტეფეისი OCP\\Share_Backend",
     "Sharing backend %s not found" : "გაზიარების ბექენდი %s ვერ იქნა ნაპოვნი",
     "Sharing backend for %s not found" : "გაზიარების ბექენდი %s-თვის ვერ იქნა ნაპოვნი",
+    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
     "Open »%s«" : "გახნსნა »%s«",
+    "Unknown share type" : "ამოუცნობი გაზიარების სახეობა",
     "You are not allowed to share %s" : "თქვენ არ გაქვთ უფლება გააზიაროთ %s",
     "Cannot increase permissions of %s" : "%s-ის უფლებების გაზრდა ვერ ხერხდება",
     "Expiration date is in the past" : "ვადის ამოწურვის თარიღი წარსულშია",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
-    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
     "The requested share does not exist anymore" : "მოთხოვნილი გაზიარება მეტი აღარ არსებობს",
     "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
     "Sunday" : "კვირა",
@@ -137,12 +128,6 @@ OC.L10N.register(
     "Nov." : "ნოე.",
     "Dec." : "დეკ.",
     "A valid password must be provided" : "უნდა მიუთითოთ სწორი პაროლი",
-    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
-    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
-    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
-    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
-    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
-    "User disabled" : "მომხმარებელი გათიშულია",
     "Login canceled by app" : "აპლიკაციამ ლოგინი უარყო",
     "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
     "File is currently busy, please try again later" : "ფაილი ამჟამად დაკავებულია, გთხოვთ მოგვიანებით სცადოთ ახლიდან",
@@ -158,16 +143,34 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ეს შესაძლოა გამოწვეული იყოს ისეთი კეშით/აქსელერატორით როგორიცაა Zend OPcache ან eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP მოდულები დაყენდა, მაგრამ მაინც ჩამოწერილია როგორც არმყოფები?",
     "Please ask your server administrator to restart the web server." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს გადატვირთოს ვებ-სერვერი.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "დარწმუნდით რომ ფაილი სახელად \".ocdata\" მონაცემების დირექტორიის საწყისშია.",
     "Could not obtain lock type %d on \"%s\"." : "ჩაკეთვის ტიპის %d მოძიება \"%s\"-ზე ვერ მოხერხდა.",
     "Storage unauthorized. %s" : "საცავი არაავტორიზირებულია. %s",
     "Storage incomplete configuration. %s" : "საცავის არასრული კონფიგურაცია. %s",
     "Storage connection error. %s" : "საცავის კავშირის შეცდომა. %s",
     "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
     "Storage connection timeout. %s" : "საცავის კავშირის დროის ამოწურვა. %s",
-    "Full name" : "სრული სახელი",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "საჭიროა libxml2 ვერსიით 2.7.0 ან მეტი. ახლა დაყენებულია %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "ამ პრობლემის მოსაგვარებლად განაახლეთ libxml2 ვერსია და გადატვირთეთ თქვენი ვებ-სერვერი."
+    "Summary" : "შეჯამება",
+    "Translate" : "გადათარგმნეთ",
+    "Result" : "შედეგი",
+    "Education Edition" : "საგანმანათლებლო გამოცემა",
+    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
+    "File name is a reserved word" : "ფაილის სახელი რეზერვირებული სიტყვაა",
+    "File name contains at least one invalid character" : "ფაილის სახელი მოიცავს დაუშვებელ სიმბოლოს",
+    "File name is too long" : "ფაილის სახელი ზედმეტად გრძელია",
+    "Help" : "დახმარება",
+    "Users" : "მომხმარებლები",
+    "Unknown user" : "ამოუცნობი მომხმარებელი",
+    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
+    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
+    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
+    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
+    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
+    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
+    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
+    "User disabled" : "მომხმარებელი გათიშულია",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "დარწმუნდით რომ ფაილი სახელად \".ocdata\" მონაცემების დირექტორიის საწყისშია."
 },
 "nplurals=2; plural=(n!=1);");
