@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
-    "Education Edition" : "Edycja edukacyjna",
     "Enterprise bundle" : "Pakiet dla firm",
     "Groupware bundle" : "Pakiet do pracy grupowej",
     "Hub bundle" : "Pakiet centralny",
@@ -36,6 +35,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
     "Server version %s or higher is required." : "Wymagana jest wersja serwera %s lub wyższa.",
     "Server version %s or lower is required." : "Wymagana jest wersja serwera %s lub niższa.",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowane konto musi być administratorem, subadministratorem lub posiadać specjalne uprawnienia, aby uzyskać dostęp do tego ustawienia",
+    "Logged in account must be an admin or sub admin" : "Zalogowane konto musi być administratorem lub subadministratorem",
+    "Logged in account must be an admin" : "Zalogowane konto musi być administratorem",
     "Wiping of device %s has started" : "Rozpoczęto czyszczenie urządzenia %s",
     "Wiping of device »%s« has started" : "Rozpoczęto czyszczenie urządzenia »%s«",
     "»%s« started remote wipe" : "»%s« rozpoczęło zdalne czyszczenie",
@@ -76,26 +78,25 @@ OC.L10N.register(
     "seconds ago" : "przed chwilą",
     "Empty file" : "Pusty plik",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduł o ID: %s nie istnieje. Włącz go w ustawieniach aplikacji lub skontaktuj się z administratorem.",
+    "Dot files are not allowed" : "Pliki z kropką są nie dozwolone",
     "File already exists" : "Plik już istnieje",
     "Invalid path" : "Niewłaściwa ścieżka",
     "Failed to create file from template" : "Nie udało się utworzyć pliku z szablonu",
     "Templates" : "Szablony",
-    "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
-    "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
-    "File name is too long" : "Nazwa pliku jest za długa",
-    "Dot files are not allowed" : "Pliki z kropką są nie dozwolone",
+    "Filename contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
     "Empty filename is not allowed" : "Pusta nazwa pliku jest niedozwolona",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie można odczytać pliku appinfo.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie jest kompatybilna z tą wersją serwera.",
     "__language_name__" : "Polski",
     "This is an automatically sent email, please do not reply." : "Jest to wiadomość e-mail wysłana automatycznie, prosimy nie odpowiadać na nią.",
+    "Help & privacy" : "Pomoc i prywatność",
     "Appearance and accessibility" : "Wygląd i dostępność",
     "Apps" : "Aplikacje",
     "Personal settings" : "Ustawienia osobiste",
     "Administration settings" : "Ustawienia administracyjne",
     "Settings" : "Ustawienia",
     "Log out" : "Wyloguj",
-    "Users" : "Użytkownicy",
+    "Accounts" : "Konta",
     "Email" : "E-mail",
     "Mail %s" : "Poczta %s",
     "Fediverse" : "Fediverse",
@@ -113,6 +114,7 @@ OC.L10N.register(
     "Headline" : "Nagłówek",
     "Organisation" : "Organizacja",
     "Role" : "Rola społeczna",
+    "Unknown account" : "Nieznane konto",
     "Additional settings" : "Ustawienia dodatkowe",
     "Enter the database name for %s" : "Podaj nazwę bazy danych dla %s",
     "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
@@ -127,11 +129,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do udostępniania %s musi implementować interfejs OCP\\Share_Backend",
     "Sharing backend %s not found" : "Zaplecze %s do udostępniania nie zostało znalezione",
     "Sharing backend for %s not found" : "Zaplecze do udostępniania dla %s nie zostało znalezione",
+    "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
+    "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
+    "Open »%s«" : "Otwórz »%s«",
+    "%1$s via %2$s" : "%1$s przez %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s udostępnił Tobie »%2$s« i chce dodać: ",
     "%1$s shared »%2$s« with you and wants to add" : " %1$s udostępnił Tobie »%2$s« i chce dodać",
     "»%s« added a note to a file shared with you" : "»%s« dodał notatkę do udostępnionego dla Ciebie pliku",
-    "Open »%s«" : "Otwórz »%s«",
-    "%1$s via %2$s" : "%1$s przez %2$s",
+    "Unknown share type" : "Nieznany typ udostępnienia",
     "You are not allowed to share %s" : "Nie możesz udostępnić %s",
     "Cannot increase permissions of %s" : "Nie można zwiększyć uprawnień %s",
     "Files cannot be shared with delete permissions" : "Pliki nie mogą zostać udostępnione z prawem do usuwania",
@@ -139,9 +145,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Data ważności już minęła",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie można utworzyć daty wygaśnięcia na %n dzień do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu"],
     "Sharing is only allowed with group members" : "Udostępnianie jest dozwolone tylko członkom grupy",
-    "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
-    "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
     "The requested share does not exist anymore" : "Żądane udostępnienie już nie istnieje",
     "The requested share comes from a disabled user" : "Żądane udostępnienie pochodzi od wyłączonego użytkownika",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Użytkownik nie został utworzony, ponieważ osiągnięto limit użytkowników. Sprawdź swoje powiadomienia, aby dowiedzieć się więcej.",
@@ -192,6 +195,13 @@ OC.L10N.register(
     "Nov." : "Lis.",
     "Dec." : "Gru.",
     "A valid password must be provided" : "Należy podać prawidłowe hasło",
+    "The Login is already being used" : "Login jest już używany",
+    "Could not create account" : "Nie można utworzyć konta",
+    "A valid Login must be provided" : "Należy podać poprawny login",
+    "Login contains whitespace at the beginning or at the end" : "Login zawiera spacje na początku lub na końcu",
+    "Login must not consist of dots only" : "Login nie może składać się wyłącznie z kropek",
+    "Login is invalid because files already exist for this user" : "Login jest nieprawidłowy, ponieważ dla tego użytkownika istnieją już pliki",
+    "Account disabled" : "Konto wyłączone",
     "Login canceled by app" : "Logowanie anulowane przez aplikację",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Nie można zainstalować aplikacji \"%1$s\", ponieważ nie są spełnione następujące zależności: %2$s",
     "a safe home for all your data" : "bezpieczny dom dla wszystkich Twoich danych",
@@ -224,10 +234,11 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
     "The required %s config variable is not configured in the config.php file." : "Wymagana zmienna konfiguracyjna %s nie jest skonfigurowana w pliku config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Poproś administratora serwera o sprawdzenie konfiguracji Nextcloud.",
+    "Your data directory is readable by other people." : "Twój katalog danych może być odczytywany przez inne osoby.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Zmień uprawnienia na 0770, aby katalog nie mógł być wyświetlany przez inne osoby.",
     "Your data directory must be an absolute path." : "Katalog danych musi mieć ścieżkę absolutną.",
     "Check the value of \"datadirectory\" in your configuration." : "Sprawdź wartość \"datadirectory\" w swojej konfiguracji.",
     "Your data directory is invalid." : "Katalog danych jest nieprawidłowy.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Upewnij się, że w katalogu \"data\" znajduje się plik o nazwie \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "Akcja \"%s\" jest niewspierana lub niezaimplementowana.",
     "Authentication failed, wrong token or provider ID given" : "Uwierzytelnienie nie powiodło się, podano nieprawidłowy token lub ID dostawcy",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Brak parametrów w celu uzupełnienia żądania. Brakujące parametry: \"%s\"",
@@ -239,19 +250,28 @@ OC.L10N.register(
     "Storage connection error. %s" : "Błąd połączenia z magazynem. %s",
     "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
     "Storage connection timeout. %s" : "Limit czasu połączenia do magazynu. %s",
+    "Chat" : "Rozmowa",
+    "Generates a possible headline for a text." : "Generuje możliwy nagłówek tekstu.",
+    "Summarize" : "Podsumuj",
+    "Summary" : "Podsumowanie",
+    "Extract topics" : "Wyodrębnij tematy",
+    "Translate" : "Tłumaczenie",
+    "Target language" : "Język docelowy",
+    "Result" : "Wynik",
     "Free prompt" : "Monit bezpłatny",
     "Runs an arbitrary prompt through the language model." : "Uruchamia dowolny monit w modelu języka.",
     "Generate headline" : "Wygeneruj nagłówek",
-    "Generates a possible headline for a text." : "Generuje możliwy nagłówek tekstu.",
-    "Summarize" : "Podsumuj",
     "Summarizes text by reducing its length without losing key information." : "Podsumowuje tekst, zmniejszając jego długość bez utraty kluczowych informacji.",
-    "Extract topics" : "Wyodrębnij tematy",
     "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
-    "404" : "404",
+    "Education Edition" : "Edycja edukacyjna",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowany użytkownik musi być administratorem, subadministratorem lub mieć specjalne uprawnienia dostępu do tego ustawienia",
     "Logged in user must be an admin or sub admin" : "Zalogowany użytkownik musi być administratorem lub współadministratorem",
     "Logged in user must be an admin" : "Zalogowany użytkownik musi być administratorem",
+    "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
+    "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
+    "File name is too long" : "Nazwa pliku jest za długa",
     "Help" : "Pomoc",
+    "Users" : "Użytkownicy",
     "Unknown user" : "Nieznany użytkownik",
     "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
     "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
@@ -268,9 +288,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
     "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
     "User disabled" : "Użytkownik zablokowany",
-    "PostgreSQL >= 9 required." : "Wymagany PostgreSQL >= 9",
-    "Please upgrade your database version." : "Zaktualizuj wersję bazy danych.",
     "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Upewnij się, że w katalogu \"data\" znajduje się plik o nazwie \".ocdata\"."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
