@@ -17,7 +17,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s in %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s in %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s in %5$s",
-    "Education Edition" : "Izobraževalna različica",
     "Enterprise bundle" : "Poslovni paket",
     "Groupware bundle" : "Paket za skupinsko delo",
     "Hub bundle" : "Razvijalski paket",
@@ -74,14 +73,12 @@ OC.L10N.register(
     "seconds ago" : "pred nekaj sekundami",
     "Empty file" : "Prazna datoteka",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z ID: %s ne obstaja. Omogočite ga med nastavitvami, ali pa stopite v stik s skrbnikom sistema.",
+    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
     "File already exists" : "Datoteka že obstaja",
     "Invalid path" : "Neveljavna pot",
     "Failed to create file from template" : "Ustvarjanje datoteke iz predloge je spodletelo",
     "Templates" : "Predloge",
-    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
-    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
-    "File name is too long" : "Ime datoteke je predolgo",
-    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
+    "Filename contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
     "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programa »%s« ni mogoče namestiti, ker datoteke appinfo ni mogoče brati.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programa »%s« ni mogoče namestiti, ker ni združljiv z nameščeno različico strežnika.",
@@ -93,7 +90,7 @@ OC.L10N.register(
     "Administration settings" : "Skrbniške nastavitve",
     "Settings" : "Nastavitve",
     "Log out" : "Odjava",
-    "Users" : "Uporabniki",
+    "Accounts" : "Računi",
     "Email" : "Elektronski naslov",
     "Mail %s" : "Elektronski naslov %s",
     "Fediverse" : "Fediverse",
@@ -125,11 +122,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
     "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
     "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
+    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
+    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
+    "Open »%s«" : "Odpri »%s«",
+    "%1$s via %2$s" : "%1$s prek %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
     "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
-    "Open »%s«" : "Odpri »%s«",
-    "%1$s via %2$s" : "%1$s prek %2$s",
+    "Unknown share type" : "Neznana vrsta mesta souporabe",
     "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
     "Cannot increase permissions of %s" : "Ni mogoče povečati dovoljen %s",
     "Files cannot be shared with delete permissions" : "Souporaba datotek z nastavljenim dovoljenjem za brisanje ni mogoča",
@@ -137,9 +138,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum preteka je že mimo!",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datuma pretaka ni mogoče nastaviti za več kot %n dan v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dneva v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost."],
     "Sharing is only allowed with group members" : "Souporaba je dovoljena le med člani skupine",
-    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
-    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
     "The requested share does not exist anymore" : "Podano mesto souporabe ne obstaja več",
     "Could not find category \"%s\"" : "Kategorije »%s« ni mogoče najti.",
     "Sunday" : "nedelja",
@@ -220,7 +218,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
     "Your data directory must be an absolute path." : "Podatkovna mapa mora imeti navedeno celotno pot.",
     "Your data directory is invalid." : "Podatkovna mapa ni veljavna.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape.",
     "Action \"%s\" not supported or implemented." : "Dejanje »%s« ni podprto ali omogočeno.",
     "Authentication failed, wrong token or provider ID given" : "Overitev je spodletela, podan je napačen žeton oziroma določilo ID ponudnika",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Manjkajo parametri za dokončanje zahteve: »%s«.",
@@ -232,11 +229,21 @@ OC.L10N.register(
     "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
-    "404" : "404",
+    "Writing style" : "Slog pisanja",
+    "Generate image" : "Ustvari sliko",
+    "Summary" : "Povzetek",
+    "Translate" : "Prevedi",
+    "Target language" : "Ciljni jezik",
+    "Result" : "Rezultat",
+    "Education Edition" : "Izobraževalna različica",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljen uporabnik mora biti določen za skrbnika, pomočnika skrbnika ali pa mora imeti dodeljene posebna dovoljenja za dostop do nastavitve.",
     "Logged in user must be an admin or sub admin" : "Prijavljen uporabnik mora imeti dovoljenja skrbnika ali podpornega skrbnika",
     "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
+    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
+    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
+    "File name is too long" : "Ime datoteke je predolgo",
     "Help" : "Pomoč",
+    "Users" : "Uporabniki",
     "Unknown user" : "Neznan uporabnik",
     "Enter the database username and name for %s" : "Vpis uporabniškega imena in imena podatkovne zbirke za %s.",
     "Enter the database username for %s" : "Vpis uporabniškega imena podatkovne zbirke za %s.",
@@ -253,6 +260,7 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Uporabniško ime ne sme biti zgolj iz pik",
     "Username is invalid because files already exist for this user" : "Uporabniško ime ni veljavno, ker za tega uporabnika že obstajajo datoteke",
     "User disabled" : "Uporabnik je onemogočen",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
