@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s、%2$s 和 %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s、%2$s、%3$s 和 %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s、%2$s、%3$s、%4$s 和 %5$s",
-    "Education Edition" : "教育版",
+    "Education bundle" : "教育組合包",
     "Enterprise bundle" : "企業組合包",
     "Groupware bundle" : "協作組合包",
     "Hub bundle" : "集線器束",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "需要伺服器版本 %s 或更高",
     "Server version %s or lower is required." : "需要伺服器版本 %s 或更低",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登錄帳戶必須是管理員、子管理員或具有存取此設定的特殊權限",
+    "Your current IP address doesn’t allow you to perform admin actions" : "您目前的 IP 位置不允許您執行管理動作",
     "Logged in account must be an admin or sub admin" : "登入的帳戶必須要是管理員或是子管理員",
     "Logged in account must be an admin" : "登入的帳戶必須有管理員權限",
     "Wiping of device %s has started" : "已開始抹除裝置 %s ",
@@ -80,14 +81,21 @@ OC.L10N.register(
     "seconds ago" : "幾秒前",
     "Empty file" : "空檔案",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "名為 %s 的模組不存在，請在應用程式設定中啟用，或是聯絡系統管理員",
+    "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "\"%1$s\" is a forbidden file or folder name." : "「%1$s」是禁止的檔案或資料夾名稱。",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "「%1$s」是禁止的檔案或資料夾名稱前綴。",
+    "\"%1$s\" is not allowed inside a file or folder name." : "「%1$s」不允許出現在檔案或資料夾名稱中。",
+    "\"%1$s\" is a forbidden file type." : "「%1$s」是禁止的檔案類型。",
+    "Filenames must not end with \"%1$s\"." : "檔案名稱不能以「%1$s」結尾。",
+    "Invalid parent path" : "無效的上層路徑",
     "File already exists" : "檔案已存在",
     "Invalid path" : "路徑無效",
     "Failed to create file from template" : "無法從模板創建檔案",
     "Templates" : "模板",
-    "File name is a reserved word" : "檔案名稱是保留字",
-    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
-    "File name is too long" : "檔案名稱太長",
-    "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "Path contains invalid segments" : "路徑包含無效的部份",
+    "Filename is a reserved word" : "檔案名稱是保留字",
+    "Filename contains at least one invalid character" : "檔名至少要有一個有效字元",
+    "Filename is too long" : "檔案名稱太長",
     "Empty filename is not allowed" : "不允許空白的檔名",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "應用程式 \"%s\" 無法安裝，因為無法讀取 appinfo 檔案。",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "應用程式 \"%s\" 無法安裝，因為該應用程式不相容於目前伺服器的版本。",
@@ -100,7 +108,7 @@ OC.L10N.register(
     "Administration settings" : "管理設定",
     "Settings" : "設定",
     "Log out" : "登出",
-    "Users" : "用戶",
+    "Accounts" : "帳戶",
     "Email" : "電郵地址",
     "Mail %s" : "郵件 %s",
     "Fediverse" : "Fediverse",
@@ -139,26 +147,56 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend 界面",
     "Sharing backend %s not found" : "找不到分享後端 %s",
     "Sharing backend for %s not found" : "找不到 %s 的分享後端",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了 %2$s ，且想要加入：",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了 %2$s ，且想要加入",
-    "»%s« added a note to a file shared with you" : "%s 在與您分享的檔案中加入了註解",
-    "Open »%s«" : "開啟 »%s«",
-    "%1$s via %2$s" : "%1$s 由 %2$s",
-    "You are not allowed to share %s" : "你無權分享 %s",
-    "Cannot increase permissions of %s" : "無法增加 %s 的權限",
-    "Files cannot be shared with delete permissions" : "無法分享具有刪除權限的檔案",
-    "Files cannot be shared with create permissions" : "無法分享具有新建權限的檔案",
-    "Expiration date is in the past" : "到期日為過去的日期",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["到期日不能設定為 %n 天以後的日期"],
-    "Sharing is only allowed with group members" : "僅允許在群組成員中共享",
-    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳戶 %s 分享",
     "%1$s shared »%2$s« with you" : "%1$s 與您分享了 %2$s",
     "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
     "Click the button below to open it." : "點下方連結開啟",
+    "Open »%s«" : "開啟 »%s«",
+    "%1$s via %2$s" : "%1$s 由 %2$s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了 %2$s ，且想要加入：",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了 %2$s ，且想要加入",
+    "»%s« added a note to a file shared with you" : "%s 在與您分享的檔案中加入了註解",
+    "Passwords are enforced for link and mail shares" : "連結及郵件分享強制使用密碼",
+    "Unknown share type" : "分享類型不詳",
+    "Cannot share with yourself" : "無法與您自己分享",
+    "Path should be set" : "應該設定途徑",
+    "Path should be either a file or a folder" : "途徑應為檔案或資料夾",
+    "You cannot share your root folder" : "您無法分享您的根資料夾",
+    "You are not allowed to share %s" : "你無權分享 %s",
+    "A share requires permissions" : "分享需要權限",
+    "Cannot increase permissions of %s" : "無法增加 %s 的權限",
+    "Shares need at least read permissions" : "分享需要至少讀取的權限",
+    "Files cannot be shared with delete permissions" : "無法分享具有刪除權限的檔案",
+    "Files cannot be shared with create permissions" : "無法分享具有新建權限的檔案",
+    "Expiration date is in the past" : "到期日為過去的日期",
+    "Expiration date is enforced" : "屆滿日期為強制要求",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["到期日不能設定為 %n 天以後的日期"],
+    "Sharing is only allowed with group members" : "僅允許在群組成員中共享",
+    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳戶 %s 分享",
+    "Group sharing is now allowed" : "現在允許群組分享",
+    "Sharing is only allowed within your own groups" : "僅允許與您自己的群組分享",
+    "Path is already shared with this group" : "已與此群組分享了路徑",
+    "Link sharing is not allowed" : "不允許連結分享",
+    "Public upload is not allowed" : "不允許公開上傳",
+    "Path contains files shared with you" : "路徑包含與您分享的檔案",
+    "Sharing is disabled" : "已停用分享",
+    "Sharing is disabled for you" : "您已停用分享",
+    "Cannot share with the share owner" : "無法與分享擁有者分享",
+    "Share does not have a full ID" : "分享並無完整 ID",
+    "Cannot change share type" : "無法變更分享類型",
+    "Can only update recipient on user shares" : "僅能更新使用者分享的收件者",
+    "Cannot enable sending the password by Talk with an empty password" : "若密碼為空，則無法啟用透過 Talk 傳送密碼",
+    "Cannot enable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法啟用透過 Talk 傳送密碼",
+    "Cannot disable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法停用透過 Talk 傳送密碼",
+    "Share provider does not support accepting" : "分享提供者不支援接受",
+    "Cannot change target of link share" : "無法變更連結分享的目標",
+    "Invalid recipient" : "無效的收件人",
+    "Group \"%s\" does not exist" : "群組「%s」不存在",
     "The requested share does not exist anymore" : "該分享已經不存在",
     "The requested share comes from a disabled user" : "請求的分享來自已停用的用戶",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "未創建用戶因為已達到用戶上限。請查看您的通知以了解更多信息。",
     "Could not find category \"%s\"" : "找不到分類：\"%s\"",
+    "Input text" : "輸入文字",
+    "The input text" : "輸入文字",
     "Sunday" : "星期日",
     "Monday" : "星期一",
     "Tuesday" : "星期二",
@@ -250,7 +288,7 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "您的資料目錄必須為絕對路徑。",
     "Check the value of \"datadirectory\" in your configuration." : "請檢查您的設定檔中 \"datadirectory\" 的值。",
     "Your data directory is invalid." : "您的數據目錄無效。",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個 \"。ocdata\" 檔案",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "請確保資料目錄最上層有一個「%1$s」檔案。其應有內容：「%2$s」",
     "Action \"%s\" not supported or implemented." : "操作 \"%s\" 並未支援，或是尚未實作",
     "Authentication failed, wrong token or provider ID given" : "認證失敗，提供了錯誤的 token 或是 provider ID",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "欠缺完成請求所需的參數： \"%s\"",
@@ -262,19 +300,101 @@ OC.L10N.register(
     "Storage connection error. %s" : "儲存空間連線錯誤。%s",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
+    "Transcribe audio" : "抄錄音頻為文字",
+    "Transcribe the things said in an audio" : "轉錄音訊中所說的話",
+    "Audio input" : "音頻輸入",
+    "The audio to transcribe" : "要轉錄的音頻",
+    "Transcription" : "轉錄",
+    "The transcribed text" : "已轉錄的文字",
+    "Context write" : "寫作情境",
+    "Writes text in a given style based on the provided source material." : "根據提供的來源資料以指定的風格編寫文字。",
+    "Writing style" : "寫作風格",
+    "Demonstrate a writing style that you would like to immitate" : "展現您想模仿的寫作風格",
+    "Source material" : "來源資料",
+    "The content that would like to be rewritten in the new writing style" : "想要用新的寫作風格重寫的內容",
+    "Generated text" : "產生的文字",
+    "The generated text with content from the source material in the given style" : "產生的文字包含來自指定樣式的原始素材的內容",
+    "Emoji generator" : "表情符號產生程式",
+    "Takes text and generates a representative emoji for it." : "取得文字並為其產生代表性表情符號。",
+    "The text to generate an emoji for" : "用來產生表情符號的文字",
+    "Generated emoji" : "已產生表情符號",
+    "The generated emoji based on the input text" : "以輸入文字為基礎產生的表情符號",
+    "Generate image" : "産生圖像",
+    "Generate an image from a text prompt" : "根據文字提示產生圖像",
+    "Prompt" : "提示詞",
+    "Describe the image you want to generate" : "描述您想要產生的圖像",
+    "Number of images" : "圖像數量",
+    "How many images to generate" : "要產生多少圖像",
+    "Output images" : "輸出圖像",
+    "The generated images" : "產生的圖像",
+    "Free text to text prompt" : "文字提示的自由文字",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "透過回傳回覆的語言模型執行任意提示",
+    "Describe a task that you want the assistant to do or ask a question" : "描述您希望助理執行的任務或提出問題",
+    "Generated reply" : "已產生的回覆",
+    "The generated text from the assistant" : "從助理產生的文字",
+    "Chat" : "聊天",
+    "Chat with the assistant" : "與小幫手聊天",
+    "System prompt" : "系統提示詞",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
+    "Chat message" : "聊天訊息",
+    "Chat history" : "聊天紀錄",
+    "The history of chat messages before the current message, starting with a message by the user" : "目前訊息開始之前的聊天紀錄，從用戶的訊息開始",
+    "Response message" : "回應訊息",
+    "The generated response as part of the conversation" : "作為對話一部份產生的回應",
+    "Formalize text" : "正式化文字",
+    "Takes a text and makes it sound more formal" : "取得文字並使其看起來更正式",
+    "Write a text that you want the assistant to formalize" : "寫下您希望小幫手協助您正式化的文字",
+    "Formalized text" : "正式化文字",
+    "The formalized text" : "正式化文字",
+    "Generate a headline" : "產生標題",
+    "Generates a possible headline for a text." : "為文字生成可能的標題。",
+    "Original text" : "原始文字",
+    "The original text to generate a headline for" : "用來產生標題的原始文字",
+    "The generated headline" : "產生的標題",
+    "Reformulate text" : "重新表述文字",
+    "Takes a text and reformulates it" : "取得文字並將其重新表述",
+    "Write a text that you want the assistant to reformulate" : "寫下您希望小幫手協助您重新表述的文字",
+    "Reformulated text" : "已重新表述的文字",
+    "The reformulated text, written by the assistant" : "已重新表述的文字，由小幫手編寫",
+    "Simplify text" : "簡化文字",
+    "Takes a text and simplifies it" : "取得文字並將其簡化",
+    "Write a text that you want the assistant to simplify" : "寫下您希望小幫手協助您簡化的文字",
+    "Simplified text" : "簡化後的文字",
+    "The simplified text" : "簡化後的文字",
+    "Summarize" : "總結",
+    "Summarizes a text" : "總結一段文字",
+    "The original text to summarize" : "要總結的原始文字",
+    "Summary" : "摘要",
+    "The generated summary" : "產生的總結",
+    "Extract topics" : "解壓縮主題",
+    "Extracts topics from a text and outputs them separated by commas" : "從文字中擷取主題並輸出，然後用逗號分隔",
+    "The original text to extract topics from" : "用來擷取主題的原始文字",
+    "Topics" : "主題",
+    "The list of extracted topics" : "擷取的主題清單",
+    "Translate" : "翻譯",
+    "Translate text from one language to another" : "從一個語言翻譯成其他語言的文字",
+    "Origin text" : "原始文字",
+    "The text to translate" : "要翻譯的文字",
+    "Origin language" : "原始語言",
+    "The language of the origin text" : "原始文字語言",
+    "Target language" : "目標語言",
+    "The desired language to translate the origin text in" : "要翻譯原始文字成什麼語言",
+    "Result" : "結果",
+    "The translated text" : "已翻譯的文字",
     "Free prompt" : "免費提示",
     "Runs an arbitrary prompt through the language model." : "通過語言模型運行任意提示。",
     "Generate headline" : "産生標題",
-    "Generates a possible headline for a text." : "為文字生成可能的標題。",
-    "Summarize" : "總結",
     "Summarizes text by reducing its length without losing key information." : "通過減少文字長度來總結而不丟失關鍵資訊。",
-    "Extract topics" : "解壓縮主題",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中提取主題並輸出，並用逗號分隔。",
-    "404" : "404",
+    "Education Edition" : "教育版",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登錄用戶必須是管理員、子管理員或具有存取此設定的特殊權限",
     "Logged in user must be an admin or sub admin" : "登入的用戶必須要是管理員或是子管理員",
     "Logged in user must be an admin" : "登入的用戶必須有管理員權限",
+    "File name is a reserved word" : "檔案名稱是保留字",
+    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
+    "File name is too long" : "檔案名稱太長",
     "Help" : "說明",
+    "Users" : "用戶",
     "Unknown user" : "用戶不詳",
     "Enter the database username and name for %s" : "輸入 %s 的數據庫用戶名及名稱",
     "Enter the database username for %s" : "輸入 %s 的數據庫用戶名",
@@ -291,9 +411,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "用戶名稱不能只包含小數點",
     "Username is invalid because files already exist for this user" : "用戶名稱無效，因為用戶的檔案已經存在",
     "User disabled" : "用戶已停用",
-    "PostgreSQL >= 9 required." : "需要 PostgreSQL 版本 >= 9",
-    "Please upgrade your database version." : "請升級您數據庫的版本。",
     "Your data directory is readable by other users." : "您的資料目錄可以被其他用戶讀取。",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他用戶讀取目錄列表"
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他用戶讀取目錄列表",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個 \"。ocdata\" 檔案"
 },
 "nplurals=1; plural=0;");
